@@ -61,20 +61,20 @@ void nextstateupdate(int * lcptr)
   /* can be avoided by looping through MAXTABLESTATE tables,  */
   /* or by storing table width in iline.                      */
 
-  z[lc++]="    oldstate = nextstate;";
-  z[lc++]="    nextstate = (nextstate+1) % MAXSTATE;";
-  z[lc++]="    while ((oldstate != nextstate) && ";
-  z[lc++]="           (ninstr[nextstate].iline != NULL))";
-  z[lc++]="      nextstate = (nextstate+1) % MAXSTATE;";
-  z[lc++]="    if (oldstate == nextstate)";
+  z[lc++]="    EV(oldstate) = EV(nextstate);";
+  z[lc++]="    EV(nextstate) = (EV(nextstate)+1) % MAXSTATE;";
+  z[lc++]="    while ((EV(oldstate) != EV(nextstate)) && ";
+  z[lc++]="           (EV(ninstr)[EV(nextstate)].iline != NULL))";
+  z[lc++]="      EV(nextstate) = (EV(nextstate)+1) % MAXSTATE;";
+  z[lc++]="    if (EV(oldstate) == EV(nextstate))";
   z[lc++]="    {";
-  z[lc++]="      nextstate = (nextstate+1) % MAXSTATE;";
-  z[lc++]="      while ((oldstate != nextstate) && ";
-  z[lc++]="          (ninstr[nextstate].iline->time == 0.0F) &&";
-  z[lc++]="          (ninstr[nextstate].iline->noteon == PLAYING))";
-  z[lc++]="        nextstate = (nextstate+1) % MAXSTATE;";
-  z[lc++]="      ninstr[nextstate].iline->noteon = ALLDONE;";
-  z[lc++]="      ninstr[nextstate].iline = NULL;";
+  z[lc++]="      EV(nextstate) = (EV(nextstate)+1) % MAXSTATE;";
+  z[lc++]="      while ((EV(oldstate) != EV(nextstate)) && ";
+  z[lc++]="          (EV(ninstr)[EV(nextstate)].iline->time == 0.0F) &&";
+  z[lc++]="          (EV(ninstr)[EV(nextstate)].iline->noteon == PLAYING))";
+  z[lc++]="        EV(nextstate) = (EV(nextstate)+1) % MAXSTATE;";
+  z[lc++]="      EV(ninstr)[EV(nextstate)].iline->noteon = ALLDONE;";
+  z[lc++]="      EV(ninstr)[EV(nextstate)].iline = NULL;";
   z[lc++]="    }";
 
   if (lcptr)
@@ -326,7 +326,7 @@ void tmapidxcode(tnode * tptr)
 
   /* table name is the K_INTERNAL pointer */
 
-  sprintf(tablename,"NVI(%s_%s)", currinstancename,
+  sprintf(tablename,"NVPS(%s_%s)", currinstancename,
 	  tptr->down->next->next->val);
 
   printtmapcase(tptr->down->next, tptr->down->next->next->next, tablename);
@@ -366,8 +366,8 @@ void extendcode(tnode * tbranch)
   fprintf(outfile,"   (NS(iline->turnoff)&&NS(iline->released)))\n");
   
   fprintf(outfile,"  {\n");
-  fprintf(outfile,"    NS(iline->endtime) = scorebase;\n");
-  fprintf(outfile,"    NS(iline->endabs) = (kbase - 1)*KTIME;\n");
+  fprintf(outfile,"    NS(iline->endtime) = EV(scorebase);\n");
+  fprintf(outfile,"    NS(iline->endabs) = (EV(kbase) - 1)*EV(KTIME);\n");
   fprintf(outfile,"    NS(iline->sdur) = 0.0F;\n");
   fprintf(outfile,"  }\n");
   fprintf(outfile,"  NS(iline->abstime) += \n"); 
@@ -387,11 +387,23 @@ void printfcode(tnode * tbranch)
 {                  /* PRINTF LP exprstrlist RP SEM */
   tnode * tptr;
 
+  if (wiretap_logging(aout))
+    {
+      fprintf(outfile, "\n#if (ASYS_AUDIOUNIT_DEBUG_LEVEL >= 1)\n");
+      fprintf(outfile, 
+      "  asysn_audiounit_logfile = fopen(ASYS_AUDIOUNIT_LOGFILE_NAME, \"a\");\n");
+    }
+
   tptr = tbranch->down->next->next->down;
+
   if (stdoutused(aout))
     fprintf(outfile,"  fprintf(stderr, \"%s\"", tptr->val);
   else
-    fprintf(outfile,"  fprintf(stdout, \"%s\"", tptr->val);
+    if (wiretap_logging(aout))
+      fprintf(outfile,"  fprintf(asysn_audiounit_logfile, \"%s\"", tptr->val);
+    else
+      fprintf(outfile,"  fprintf(stdout, \"%s\"", tptr->val);
+
   tptr = tptr->next;
   while (tptr)
     {
@@ -408,6 +420,11 @@ void printfcode(tnode * tbranch)
     }
   fprintf(outfile,");\n");
 
+  if (wiretap_logging(aout))
+    {
+      fprintf(outfile, "  fclose(asysn_audiounit_logfile);\n");
+      fprintf(outfile, "#endif /* (ASYS_AUDIOUNIT_DEBUG_LEVEL >= 1) */\n");
+    }
 }
 
 /****************************************************************/
@@ -478,7 +495,7 @@ void ifslowercode(tnode * tptr, tnode * ifptr)
 
   if (ifptr->inwidth & KRATESECTION)
     {
-      fprintf(outfile, "   if (NVI(%s__sym_if%i) != kcycleidx)\n",
+      fprintf(outfile, "   if (NVI(%s__sym_if%i) != EV(kcycleidx))\n",
 	      currinstancename, ifptr->arrayidx);
       fprintf(outfile, "   {\n");
     }
@@ -495,7 +512,7 @@ void ifslowercode(tnode * tptr, tnode * ifptr)
       currblockrate = currblocksafe;
 
       if ((ifptr->inwidth & KRATESECTION) == 0)
-	fprintf(outfile, "   NVI(%s__sym_if%i) = kcycleidx;\n",
+	fprintf(outfile, "   NVI(%s__sym_if%i) = EV(kcycleidx);\n",
 		currinstancename, ifptr->arrayidx);
       fprintf(outfile, "   }\n");
     }
@@ -507,7 +524,7 @@ void ifslowercode(tnode * tptr, tnode * ifptr)
       blocktree(tptr->down, PRINTKPASS); 
       currblockrate = currblocksafe;
 
-      fprintf(outfile, "   NVI(%s__sym_if%i) = kcycleidx;\n",
+      fprintf(outfile, "   NVI(%s__sym_if%i) = EV(kcycleidx);\n",
 	      currinstancename, ifptr->arrayidx);
       fprintf(outfile, "   }\n");
     }
@@ -701,7 +718,7 @@ void returncode(tnode * tbranch)
 	  if ((sptr->vartype != TABLETYPE) && 
 	      (sptr->tref->mirror != GLOBALMIRROR))
 	    fprintf(outfile,
-		    "   memcpy(&(NG(GBL_%s)), &(NV(%s_%s)), %i*sizeof(float));\n",
+		    "   memcpy(&(NGU(GBL_%s)), &(NVU(%s_%s)), %i*sizeof(NGU(0)));\n",
 		    sptr->val,currinstancename,sptr->val,
 		    truewidth(sptr->width));
 	}
@@ -733,10 +750,11 @@ void returncode(tnode * tbranch)
 		    i++, currinstancename, fptr->down->next->down->val);
 
 	  if (stname_cbr(aptr))
-	    {			  
-	      fprintf(outfile,"   memcpy(&(");
+	    {
+	      fprintf(outfile,"   for(stidx = 0; stidx < 128; stidx++)\n");
+	      fprintf(outfile,"     *(&(");
 	      blocktree(aptr->down,PRINTTOKENS);
-	      fprintf(outfile,"), &(NP(%s_%s)), sizeof(float)*128);\n",
+	      fprintf(outfile,") + stidx) = NP(%s_%s + stidx);\n",
 		      currinstancename, fptr->down->next->down->val);
 	    }
 
@@ -797,22 +815,22 @@ void instrcode(tnode * tbranch)
   
   /* code generation begins */
 
-  fprintf(outfile,"   if ( d_%snext == NULL)\n",val);
-  fprintf(outfile,"     d_%snext = d_%sfirst = d_%slast;\n",val,val,val);
+  fprintf(outfile,"   if ( EV(d_%snext) == NULL)\n",val);
+  fprintf(outfile,"     EV(d_%snext) = EV(d_%sfirst) = EV(d_%slast);\n",val,val,val);
   fprintf(outfile,"   else\n");
   fprintf(outfile,"   {\n");
-  fprintf(outfile,"    d_%snext = d_%sfirst;\n",val,val);
-  fprintf(outfile,"    while (d_%snext < d_%send)\n",val,val);
+  fprintf(outfile,"    EV(d_%snext) = EV(d_%sfirst);\n",val,val);
+  fprintf(outfile,"    while (EV(d_%snext) < EV(d_%send))\n",val,val);
   fprintf(outfile,"     {\n");
-  fprintf(outfile,"       if ((d_%snext->noteon == ALLDONE)||\n",val);
-  fprintf(outfile,"           (d_%snext->noteon == NOTUSEDYET))\n",val); 
+  fprintf(outfile,"       if ((EV(d_%snext)->noteon == ALLDONE)||\n",val);
+  fprintf(outfile,"           (EV(d_%snext)->noteon == NOTUSEDYET))\n",val); 
   fprintf(outfile,"        break;\n");
-  fprintf(outfile,"       d_%snext++;\n",val);
+  fprintf(outfile,"       EV(d_%snext)++;\n",val);
   fprintf(outfile,"     }\n");
-  fprintf(outfile,"    if ((d_%snext != d_%send) && (d_%snext > d_%slast))\n",val,val,val,val);
-  fprintf(outfile,"      d_%slast = d_%snext;\n",val,val);
+  fprintf(outfile,"    if ((EV(d_%snext) != EV(d_%send)) && (EV(d_%snext) > EV(d_%slast)))\n",val,val,val,val);
+  fprintf(outfile,"      EV(d_%slast) = EV(d_%snext);\n",val,val);
   fprintf(outfile,"   }\n");
-  fprintf(outfile,"   if (d_%snext != d_%send)\n",val,val);
+  fprintf(outfile,"   if (EV(d_%snext) != EV(d_%send))\n",val,val);
   fprintf(outfile,"    {\n");
 
   /* compute all return values */
@@ -822,18 +840,18 @@ void instrcode(tnode * tbranch)
 
   /* first, set start time  */
 
-  fprintf(outfile,"   d_%snext->starttime = scorebeats + (",val);
+  fprintf(outfile,"   EV(d_%snext)->starttime = EV(scorebeats) + (",val);
   blocktree(aptr->down,PRINTTOKENS);
   fprintf(outfile,");\n");
   aptr = aptr->next->next;
 
   /* then, set duration */
 
-  fprintf(outfile,"   d_%snext->sdur = ",val);
+  fprintf(outfile,"   EV(d_%snext)->sdur = ",val);
   blocktree(aptr->down,PRINTTOKENS);
   fprintf(outfile,";\n");
-  fprintf(outfile,"   if (d_%snext->sdur < 0.0F)\n",val);
-  fprintf(outfile,"     d_%snext->sdur = -1.0F;\n",val);
+  fprintf(outfile,"   if (EV(d_%snext)->sdur < 0.0F)\n",val);
+  fprintf(outfile,"     EV(d_%snext)->sdur = -1.0F;\n",val);
   
   aptr = aptr->next;
   if (aptr != NULL)
@@ -843,7 +861,7 @@ void instrcode(tnode * tbranch)
     {
       if (aptr->ttype == S_EXPR)
 	{
-	  fprintf(outfile,"   d_%snext->p[%s_%s] = ",
+	  fprintf(outfile,"   EV(d_%snext)->p[%s_%s] = ",
 		  val,origval,dptr->val);
 	  blocktree(aptr->down,PRINTTOKENS);
 	  fprintf(outfile,";\n");
@@ -852,50 +870,50 @@ void instrcode(tnode * tbranch)
       dptr = dptr->next;
     }
 
-  fprintf(outfile,"   d_%snext->abstime = 0.0F;\n",val);
-  fprintf(outfile,"   d_%snext->endtime = MAXENDTIME;\n",val);
-  fprintf(outfile,"   d_%snext->released = 0;\n",val);
-  fprintf(outfile,"   d_%snext->turnoff = 0;\n",val);
-  fprintf(outfile,"   d_%snext->launch = NOTLAUNCHED;\n",val);
-  fprintf(outfile,"   d_%snext->numchan = NS(iline->numchan);\n",val);
-  fprintf(outfile,"   d_%snext->notenum = 255 & (NS(iline->notenum));\n",val);
-  fprintf(outfile,"   d_%snext->preset  = NS(iline->preset);\n",val);
+  fprintf(outfile,"   EV(d_%snext)->abstime = 0.0F;\n",val);
+  fprintf(outfile,"   EV(d_%snext)->endtime = MAXENDTIME;\n",val);
+  fprintf(outfile,"   EV(d_%snext)->released = 0;\n",val);
+  fprintf(outfile,"   EV(d_%snext)->turnoff = 0;\n",val);
+  fprintf(outfile,"   EV(d_%snext)->launch = NOTLAUNCHED;\n",val);
+  fprintf(outfile,"   EV(d_%snext)->numchan = NS(iline->numchan);\n",val);
+  fprintf(outfile,"   EV(d_%snext)->notenum = 255 & (NS(iline->notenum));\n",val);
+  fprintf(outfile,"   EV(d_%snext)->preset  = NS(iline->preset);\n",val);
 
-  fprintf(outfile,"   if (d_%snext->starttime <= (scorebeats+scoremult))\n",val);
+  fprintf(outfile,"   if (EV(d_%snext)->starttime <= (EV(scorebeats)+EV(scoremult)))\n",val);
   fprintf(outfile,"   {\n");
-  fprintf(outfile,"    d_%snext->notestate = nextstate;\n",val);
-  fprintf(outfile,"    d_%snext->nstate = &ninstr[nextstate];\n",val);
+  fprintf(outfile,"    EV(d_%snext)->notestate = EV(nextstate);\n",val);
+  fprintf(outfile,"    EV(d_%snext)->nstate = &(EV(ninstr)[EV(nextstate)]);\n",val);
 
-  fprintf(outfile,"    ninstr[nextstate].iline = d_%snext;\n",val);
-  fprintf(outfile,"    d_%snext->time = (kcycleidx-1)*KTIME;\n",val);
-  fprintf(outfile,"    if (d_%snext->sdur >= 0.0F)\n",val);
-  fprintf(outfile,"      d_%snext->endtime = scorebeats + d_%snext->sdur;\n"
+  fprintf(outfile,"    EV(ninstr)[EV(nextstate)].iline = EV(d_%snext);\n",val);
+  fprintf(outfile,"    EV(d_%snext)->time = (EV(kcycleidx)-1)*EV(KTIME);\n",val);
+  fprintf(outfile,"    if (EV(d_%snext)->sdur >= 0.0F)\n",val);
+  fprintf(outfile,"      EV(d_%snext)->endtime = EV(scorebeats) + EV(d_%snext)->sdur;\n"
 	  ,val,val);
-  fprintf(outfile,"    d_%snext->kbirth = kcycleidx;\n",val);
-  fprintf(outfile,"    d_%snext->noteon = PLAYING;\n",val);
+  fprintf(outfile,"    EV(d_%snext)->kbirth = EV(kcycleidx);\n",val);
+  fprintf(outfile,"    EV(d_%snext)->noteon = PLAYING;\n",val);
   nextstateupdate(NULL);
-  fprintf(outfile,"    if (pass == KPASS)\n");
+  fprintf(outfile,"    if (EV(pass) == KPASS)\n");
   fprintf(outfile,"     {\n");
-  fprintf(outfile,"      pass = IPASS;\n");
-  fprintf(outfile,"      %s_ipass(d_%snext->nstate);\n",origval,val);
-  fprintf(outfile,"      pass = KPASS;\n");
+  fprintf(outfile,"      EV(pass) = IPASS;\n");
+  fprintf(outfile,"      %s_ipass(ENGINE_PTR_COMMA EV(d_%snext)->nstate);\n",origval,val);
+  fprintf(outfile,"      EV(pass) = KPASS;\n");
   if (before)
     {
-      fprintf(outfile,"    d_%snext->noteon = PAUSED;\n",val);
+      fprintf(outfile,"    EV(d_%snext)->noteon = PAUSED;\n",val);
     }
   fprintf(outfile,"     }\n");
   fprintf(outfile,"    else\n");
   fprintf(outfile,"     {\n");
-  fprintf(outfile,"     %s_ipass(d_%snext->nstate);\n",origval,val);
+  fprintf(outfile,"     %s_ipass(ENGINE_PTR_COMMA EV(d_%snext)->nstate);\n",origval,val);
   if (before)
     {
-      fprintf(outfile,"    d_%snext->noteon = PAUSED;\n",val);
+      fprintf(outfile,"    EV(d_%snext)->noteon = PAUSED;\n",val);
     }
   fprintf(outfile,"     }\n");
 
   fprintf(outfile,"   }\n");
   fprintf(outfile,"   else\n");
-  fprintf(outfile,"    d_%snext->noteon = TOBEPLAYED;\n",val);
+  fprintf(outfile,"    EV(d_%snext)->noteon = TOBEPLAYED;\n",val);
   fprintf(outfile,"  }\n");
 
   free(val);
@@ -1009,7 +1027,7 @@ void opcallcode(tnode * tptr)
 	      fprintf(outfile, "%sNV(%s_%s%i_return) : (",
 		      (currintprint == ASINT) ? "(int)" : "",
 		      currinstancename, tptr->val, tptr->optr->arrayidx);
-	      fprintf(outfile, "(NVI(%s_%s%i__sym_ocstate) = kcycleidx), ",
+	      fprintf(outfile, "(NVI(%s_%s%i__sym_ocstate) = EV(kcycleidx)), ",
 		      currinstancename, tptr->val, tptr->optr->arrayidx);
 	      opcallprint(tptr, SLOWRATETYPE);
 	      fprintf(outfile, "))");
@@ -1018,7 +1036,7 @@ void opcallcode(tnode * tptr)
 	    {
 	      if (sptr->cref->callswitch == 0)
 		{
-		  fprintf(outfile, "(acycleidx ? %sNV(%s_%s%i_return) : ",
+		  fprintf(outfile, "(EV(acycleidx) ? %sNV(%s_%s%i_return) : ",
 			  (currintprint == ASINT) ? "(int)" : "",
 			  currinstancename, tptr->val, tptr->optr->arrayidx);
 		  opcallprint(tptr, SLOWRATETYPE);
@@ -1026,12 +1044,12 @@ void opcallcode(tnode * tptr)
 		}
 	      else
 		{
-		  fprintf(outfile, "( (NVI(%s_%s%i__sym_ocstate) == kcycleidx) ? ",
+		  fprintf(outfile, "( (NVI(%s_%s%i__sym_ocstate) == EV(kcycleidx)) ? ",
 			  currinstancename, tptr->val, tptr->optr->arrayidx);
 		  fprintf(outfile, "%sNV(%s_%s%i_return) : ",
 			  (currintprint == ASINT) ? "(int)" : "",
 			  currinstancename, tptr->val, tptr->optr->arrayidx);
-		  fprintf(outfile, "((NVI(%s_%s%i__sym_ocstate) = kcycleidx), ",
+		  fprintf(outfile, "((NVI(%s_%s%i__sym_ocstate) = EV(kcycleidx)), ",
 			  currinstancename, tptr->val, tptr->optr->arrayidx);
 		  opcallprint(tptr, SLOWRATETYPE);
 		  fprintf(outfile, "))");
@@ -1344,7 +1362,7 @@ void blocktree(tnode * tbranch, int mode)
 		    fprintf(outfile," (%sF) ",tptr->val);
 		  break;
 		case S_INTGR:
-		  if (atol(tptr->val) >= 0)
+		  if (atoi(tptr->val) >= 0)
 		    {
 		      if (currintprint == ASFLOAT)
 			fprintf(outfile," %s.0F ",tptr->val);
