@@ -194,7 +194,7 @@ int co_unarycollapse(tnode * tptr)
       }
     else
       {
-	sprintf(name, "%li", - atol(t_two->down->val));
+	sprintf(name, "%i", - atoi(t_two->down->val));
 	t_two->ttype = S_INTGR;
       }
     break;
@@ -299,7 +299,7 @@ int co_multicollapse(tnode * tptr)
   int asafloat = 0;
   int tot = 0;
   float fval = 0.0F;
-  long lval = 0;
+  int ival = 0;
 
   if ((tptr->down == NULL) || (tptr->down->ttype != S_EXPR) ||
       (tptr->down->next == NULL) ||
@@ -333,7 +333,7 @@ int co_multicollapse(tnode * tptr)
   if (asafloat)
     fval = (float)atof(first->down->val);
   else
-    lval = atol(first->down->val);
+    ival = atoi(first->down->val);
   if (tptr->down != first)
     {
       eptr = tptr->down;
@@ -346,7 +346,7 @@ int co_multicollapse(tnode * tptr)
 	  if (asafloat)
 	    fval = - fval;
 	  else
-	    lval = - lval;
+	    ival = - ival;
 	}
     }
 
@@ -361,19 +361,19 @@ int co_multicollapse(tnode * tptr)
 	    if (asafloat)
 	      fval *= (float)atof(eptr->next->next->down->val);
 	    else
-	      lval *= atol(eptr->next->next->down->val);
+	      ival *= atoi(eptr->next->next->down->val);
 	    break;
 	  case S_PLUS:
 	    if (asafloat)
 	      fval += (float)atof(eptr->next->next->down->val);
 	    else
-	      lval += atol(eptr->next->next->down->val);
+	      ival += atoi(eptr->next->next->down->val);
 	    break;
 	  case S_MINUS:
 	    if (asafloat)
 	      fval -= (float)atof(eptr->next->next->down->val);
 	    else
-	      lval -= atol(eptr->next->next->down->val);
+	      ival -= atoi(eptr->next->next->down->val);
 	    break;
 	  }
 	  eptr->next = eptr->next->next->next;
@@ -401,7 +401,7 @@ int co_multicollapse(tnode * tptr)
     {
       eptr->ttype = S_INTGR;
       eptr->res = ASINT;
-      sprintf(name, "%li", lval);
+      sprintf(name, "%i", ival);
     }
   eptr->vol = CONSTANT;
   eptr->val = dupval(name);
