@@ -428,14 +428,14 @@ void coreopcodedoinline(tnode * ident)
       }
     if (!(strcmp(ident->val,"cpsmidi")))
       {
-	fprintf(outfile,"globaltune*(float)(pow(2.0F, 8.333334e-02F*(-69.0F + ");
+	fprintf(outfile,"EV(globaltune)*(float)(pow(2.0F, 8.333334e-02F*(-69.0F + ");
 	blocktree(tptr->down,PRINTTOKENS);
 	fprintf(outfile,")))");
 	return;
       }
     if (!(strcmp(ident->val,"cpsoct")))
       {	
-	fprintf(outfile,"globaltune*(float)pow(2.0F, (-8.75F + ");
+	fprintf(outfile,"EV(globaltune)*(float)pow(2.0F, (-8.75F + ");
 	blocktree(tptr->down,PRINTTOKENS);
 	fprintf(outfile,"))");
 	return;
@@ -467,7 +467,7 @@ void coreopcodedoinline(tnode * ident)
       {
 	fprintf(outfile,"(float)(modf(");
 	blocktree(tptr->down,PRINTTOKENS);
-	fprintf(outfile,", &fracdummy))");
+	fprintf(outfile,", &EV(fracdummy)))");
 	return;
       }
     if (!(strcmp(ident->val,"ftbasecps"))) 
@@ -509,12 +509,12 @@ void coreopcodedoinline(tnode * ident)
   case 'g':
     if (!(strcmp(ident->val,"gettune")))
       {
-	fprintf(outfile,"globaltune");
+	fprintf(outfile,"EV(globaltune)");
 	return;
       }
     if (!(strcmp(ident->val,"gettempo")))
       {
-	fprintf(outfile,"tempo");
+	fprintf(outfile,"EV(tempo)");
 	return;
       }
     return;
@@ -603,7 +603,7 @@ void coreopcodedoinline(tnode * ident)
   case 'm':
     if (!(strcmp(ident->val,"midicps")))
       {	
-	fprintf(outfile,"(int)(69.5F + 1.731234e+01F*log(invglobaltune*");
+	fprintf(outfile,"(int)(69.5F + 1.731234e+01F*log(EV(invglobaltune)*");
 	blocktree(tptr->down,PRINTTOKENS);
 	fprintf(outfile,"))");
 	return;
@@ -621,7 +621,7 @@ void coreopcodedoinline(tnode * ident)
   case 'o':
     if (!(strcmp(ident->val,"octcps")))
       {
-	fprintf(outfile,"8.75F + 1.442695F*(float)log(invglobaltune*");
+	fprintf(outfile,"8.75F + 1.442695F*(float)log(EV(invglobaltune)*");
 	blocktree(tptr->down, PRINTTOKENS);
 	fprintf(outfile,")");
 	return;
