@@ -56,12 +56,12 @@
 
 FILE * asyso_fd;     /* output file pointer */
 char * asyso_name;   /* name of file  */        
-long asyso_srate;    /* sampling rate */
-long asyso_channels; /* number of channels */
-long asyso_size;     /* number of samples in a buffer */
-long asyso_nsamp;    /* total number of shorts written */
-long asyso_bps;      /* number of bytes per sample, 1-3 */
-long asyso_doswap;   /* needs byteswap on write */
+int asyso_srate;     /* sampling rate */
+int asyso_channels;  /* number of channels */
+int asyso_size;      /* number of samples in a buffer */
+int asyso_nsamp;     /* total number of shorts written */
+int asyso_bps;       /* number of bytes per sample, 1-3 */
+int asyso_doswap;    /* needs byteswap on write */
 float * asyso_buf;   /* output floats from sfront */ 
 unsigned char * asyso_cbuf;  /* output chars to file */
 #endif
@@ -82,12 +82,12 @@ unsigned char * asyso_cbuf;  /* output chars to file */
 
 FILE * asysi_fd;     /* input file pointer */
 char * asysi_name;   /* name of file  */        
-long asysi_srate;    /* sampling rate */
-long asysi_channels; /* number of channels */
-long asysi_nsamp;    /* total number of shorts read */
-long asysi_bytes;    /* number of bytes in a buffer */
-long asysi_bps;      /* number of bytes per sample, 1-3 */
-long asysi_doswap;   /* needs byteswap on read */
+int asysi_srate;     /* sampling rate */
+int asysi_channels;  /* number of channels */
+int asysi_nsamp;     /* total number of shorts read */
+int asysi_bytes;     /* number of bytes in a buffer */
+int asysi_bps;       /* number of bytes per sample, 1-3 */
+int asysi_doswap;    /* needs byteswap on read */
 unsigned char * asysi_cbuf;  /* buffer of AIFF file bytes */
 float * asysi_buf;   /* float buffer for sfront */ 
 
@@ -108,10 +108,10 @@ int asyso_putbytes(unsigned char * c, int numbytes)
 }
 
 /*********************************************************/
-/*        writes unsigned long to a AIFF files            */
+/*        writes unsigned int to an AIFF file            */
 /*********************************************************/
 
-int asyso_putlong(unsigned long val, int numbytes)
+int asyso_putint(unsigned int val, int numbytes)
 
 {
   unsigned char c[4];
@@ -147,13 +147,13 @@ int asyso_putlong(unsigned long val, int numbytes)
 /*        core routine for audio output setup                   */
 /****************************************************************/
 
-int asyso_setup(long srate, long ochannels, long osize, char * name)
+int asyso_setup(int srate, int ochannels, int osize, char * name)
 
 
 {
   short swaptest = 0x0001;
   int e;
-  unsigned long m;
+  unsigned int m;
   unsigned char c[10];
   char * val;
 
@@ -183,13 +183,13 @@ int asyso_setup(long srate, long ochannels, long osize, char * name)
   /* preamble for wav file */
 
   asyso_putbytes((unsigned char *) "FORM",4);
-  asyso_putlong(0,4);       /* length, patched later */
+  asyso_putint(0,4);       /* length, patched later */
   asyso_putbytes((unsigned char *) "AIFFCOMM",8);
-  asyso_putlong(18,4);                 /* 18 bytes */
-  asyso_putlong(ochannels,2);          /* number of channels */
-  asyso_putlong(0,4);                  /* frames, patched later */
-  asyso_putlong(8*asyso_bps, 2);       /* bits per sample */
-  m = (unsigned long)floor(ldexp(frexp((double)srate, &e),32));
+  asyso_putint(18,4);                 /* 18 bytes */
+  asyso_putint(ochannels,2);          /* number of channels */
+  asyso_putint(0,4);                  /* frames, patched later */
+  asyso_putint(8*asyso_bps, 2);       /* bits per sample */
+  m = (unsigned int)floor(ldexp(frexp((double)srate, &e),32));
   e += 16382;
   c[0] = e >> 8;
   c[1] = e;
@@ -200,9 +200,9 @@ int asyso_setup(long srate, long ochannels, long osize, char * name)
   c[6] = c[7] = c[8] = c[9] = 0;
   asyso_putbytes((unsigned char *)&c[0],10); /* srate */
   asyso_putbytes((unsigned char *) "SSND",4);
-  asyso_putlong(0,4);       /* length, patched later */
-  asyso_putlong(0,4);       /* offset = 0 */           
-  asyso_putlong(0,4);       /* block size */           
+  asyso_putint(0,4);       /* length, patched later */
+  asyso_putint(0,4);       /* offset = 0 */           
+  asyso_putint(0,4);       /* block size */           
 
   asyso_srate = srate;
   asyso_channels = ochannels;
@@ -234,7 +234,7 @@ int asyso_setup(long srate, long ochannels, long osize, char * name)
 #if defined(ASYS_HASINPUT)
 
 /*********************************************************/
-/*            gets next block of AIFF bytes               */
+/*           gets next block of AIFF bytes               */
 /*********************************************************/
 
 int asysi_getbytes(unsigned char * c, int numbytes)
@@ -246,7 +246,7 @@ int asysi_getbytes(unsigned char * c, int numbytes)
 }
 
 /*********************************************************/
-/*        flushes next block of AIFF bytes                */
+/*       flushes next block of AIFF bytes                */
 /*********************************************************/
 
 int asysi_flushbytes(int numbytes)
@@ -265,10 +265,10 @@ int asysi_flushbytes(int numbytes)
 }
 
 /*********************************************************/
-/*     converts byte stream to an unsigned long          */
+/*     converts byte stream to an unsigned int           */
 /*********************************************************/
 
-long asysi_getlong(int numbytes,  unsigned long * ret)
+int asysi_getint(int numbytes,  unsigned int * ret)
 
 {
   unsigned char c[4];
@@ -279,22 +279,22 @@ long asysi_getlong(int numbytes,  unsigned long * ret)
     return ASYS_ERROR;
   switch (numbytes) {
   case 4:
-    *ret  =  (unsigned long)c[3];
-    *ret |=  (unsigned long)c[2] << 8;
-    *ret |=  (unsigned long)c[1] << 16;
-    *ret |=  (unsigned long)c[0] << 24;
+    *ret  =  (unsigned int)c[3];
+    *ret |=  (unsigned int)c[2] << 8;
+    *ret |=  (unsigned int)c[1] << 16;
+    *ret |=  (unsigned int)c[0] << 24;
     return ASYS_DONE;
   case 3:
-    *ret  =  (unsigned long)c[2];
-    *ret |=  (unsigned long)c[1] << 8;
-    *ret |=  (unsigned long)c[0] << 16;
+    *ret  =  (unsigned int)c[2];
+    *ret |=  (unsigned int)c[1] << 8;
+    *ret |=  (unsigned int)c[0] << 16;
     return ASYS_DONE;
   case 2:
-    *ret  =  (unsigned long)c[1];
-    *ret |=  (unsigned long)c[0] << 8;
+    *ret  =  (unsigned int)c[1];
+    *ret |=  (unsigned int)c[0] << 8;
     return ASYS_DONE;
   case 1:
-    *ret = (unsigned long)c[0];
+    *ret = (unsigned int)c[0];
     return ASYS_DONE;
   default:
     return ASYS_ERROR;
@@ -303,10 +303,10 @@ long asysi_getlong(int numbytes,  unsigned long * ret)
 }
     
 /*********************************************************/
-/*     converts byte stream to an long          */
+/*         converts byte stream to an int                */
 /*********************************************************/
 
-long asysi_getslong(int numbytes, long * ret)
+int asysi_getsint(int numbytes, int * ret)
 
 {
   unsigned char c[4];
@@ -317,22 +317,22 @@ long asysi_getslong(int numbytes, long * ret)
     return ASYS_ERROR;
   switch (numbytes) {
   case 4:
-    *ret  =  (long)c[3];
-    *ret |=  (long)c[2] << 8;
-    *ret |=  (long)c[1] << 16;
-    *ret |=  (long)c[0] << 24;
+    *ret  =  (int)c[3];
+    *ret |=  (int)c[2] << 8;
+    *ret |=  (int)c[1] << 16;
+    *ret |=  (int)c[0] << 24;
     return ASYS_DONE;
   case 3:
-    *ret  =  (long)c[2];
-    *ret |=  (long)c[1] << 8;
-    *ret |=  (long)c[0] << 16;
+    *ret  =  (int)c[2];
+    *ret |=  (int)c[1] << 8;
+    *ret |=  (int)c[0] << 16;
     return ASYS_DONE;
   case 2:
-    *ret  =  (long)c[1];
-    *ret |=  (long)c[0] << 8;
+    *ret  =  (int)c[1];
+    *ret |=  (int)c[0] << 8;
     return ASYS_DONE;
   case 1:
-    *ret = (long)c[0];
+    *ret = (int)c[0];
     return ASYS_DONE;
   default:
     return ASYS_ERROR;
@@ -360,13 +360,13 @@ int asysi_soundtypecheck(char * d)
 /*        core routine for audio input setup                   */
 /****************************************************************/
 
-int asysi_setup(long srate, long ichannels, long isize, char * name)
+int asysi_setup(int srate, int ichannels, int isize, char * name)
 
 
 {
   short swaptest = 0x0001;
-  unsigned long i, m, commlen;
-  long e, len;
+  unsigned int i, m, commlen;
+  int e, len;
   unsigned char c[4];
   char * val;
 
@@ -392,16 +392,16 @@ int asysi_setup(long srate, long ichannels, long isize, char * name)
     {
       if (strncmp((char *) c,"COMM",4))
 	{
-	  if (asysi_getlong(4, &i) != ASYS_DONE)
+	  if (asysi_getint(4, &i) != ASYS_DONE)
 	    return ASYS_ERROR;
 	  if (asysi_flushbytes(i + (i % 2))!= ASYS_DONE)
 	    return ASYS_ERROR;
 	}
       else
 	{
-	  if (asysi_getlong(4, &commlen) != ASYS_DONE)
+	  if (asysi_getint(4, &commlen) != ASYS_DONE)
 	    return ASYS_ERROR;
-	  if (asysi_getlong(2, &i) != ASYS_DONE)
+	  if (asysi_getint(2, &i) != ASYS_DONE)
 	    return ASYS_ERROR;
 	  if (i != ichannels)
 	    {
@@ -410,7 +410,7 @@ int asysi_setup(long srate, long ichannels, long isize, char * name)
 	    }
 	  if (asysi_flushbytes(4)!= ASYS_DONE) /* frames */
 	    return ASYS_ERROR;
-	  if (asysi_getlong(2, &i) != ASYS_DONE)
+	  if (asysi_getint(2, &i) != ASYS_DONE)
 	    return ASYS_ERROR;
 	  if ((i < 8) || (i > 24))
 	    {
@@ -418,13 +418,13 @@ int asysi_setup(long srate, long ichannels, long isize, char * name)
 	      return ASYS_ERROR;
 	    }
 	  asysi_bps = i/8;
-	  if (asysi_getslong(2, &e) != ASYS_DONE)
+	  if (asysi_getsint(2, &e) != ASYS_DONE)
 	    return ASYS_ERROR;
-	  if (asysi_getlong(4, &m) != ASYS_DONE)
+	  if (asysi_getint(4, &m) != ASYS_DONE)
 	    return ASYS_ERROR;
 	  if (asysi_flushbytes(4)!= ASYS_DONE) /* unneeded precision */
 	    return ASYS_ERROR;
-	  i = (unsigned long)(0.5+(m*exp(log(2)*(e - 16414.0F))));
+	  i = (unsigned int)(0.5+(m*exp(log(2)*(e - 16414.0F))));
 	  if (srate != i)
 	    fprintf(stderr,"Warning: SAOL srate %i mismatches AIFF file srate %i\n",
 		    srate, i);
@@ -435,7 +435,7 @@ int asysi_setup(long srate, long ichannels, long isize, char * name)
       if (asysi_getbytes(&c[0],4)!= ASYS_DONE)
 	return ASYS_ERROR;
     }
-  if (asysi_getlong(4, &i) != ASYS_DONE)
+  if (asysi_getint(4, &i) != ASYS_DONE)
     return ASYS_ERROR;
   if (asysi_flushbytes(8)!= ASYS_DONE) 
     return ASYS_ERROR;
@@ -473,11 +473,11 @@ int asysi_setup(long srate, long ichannels, long isize, char * name)
 /*        sets up audio output for a given srate/channels       */
 /****************************************************************/
 
-int asys_osetup(long srate, long ochannels, long osample, 
-		char * oname, long toption)
+int asys_osetup(int srate, int ochannels, int osample, 
+		char * oname, int toption)
 
 {
-  return asyso_setup(srate, ochannels, ASYS_OCHAN*ACYCLE, oname);
+  return asyso_setup(srate, ochannels, ASYS_OCHAN*EV(ACYCLE), oname);
 }
 
 #endif
@@ -489,11 +489,11 @@ int asys_osetup(long srate, long ochannels, long osample,
 /*        sets up audio input for a given srate/channels       */
 /****************************************************************/
 
-int asys_isetup(long srate, long ichannels, long isample, 
-		char * iname, long toption)
+int asys_isetup(int srate, int ichannels, int isample, 
+		char * iname, int toption)
 
 {
-  return asysi_setup(srate, ichannels, ASYS_ICHAN*ACYCLE, iname);
+  return asysi_setup(srate, ichannels, ASYS_ICHAN*EV(ACYCLE), iname);
 }
 
 #endif
@@ -505,14 +505,14 @@ int asys_isetup(long srate, long ichannels, long isample,
 /*   sets up audio input and output for a given srate/channels  */
 /****************************************************************/
 
-int asys_iosetup(long srate, long ichannels, long ochannels,
-		 long isample, long osample, 
-		 char * iname, char * oname, long toption)
+int asys_iosetup(int srate, int ichannels, int ochannels,
+		 int isample, int osample, 
+		 char * iname, char * oname, int toption)
 {
 
-  if (asysi_setup(srate, ichannels, ASYS_ICHAN*ACYCLE, iname) != ASYS_DONE)
+  if (asysi_setup(srate, ichannels, ASYS_ICHAN*EV(ACYCLE), iname) != ASYS_DONE)
     return ASYS_ERROR;
-  return asyso_setup(srate, ochannels, ASYS_OCHAN*ACYCLE, oname);
+  return asyso_setup(srate, ochannels, ASYS_OCHAN*EV(ACYCLE), oname);
 
 }
 
@@ -529,11 +529,11 @@ void asyso_shutdown(void)
 {
 
   fseek(asyso_fd, 4, SEEK_SET);
-  asyso_putlong(asyso_bps*asyso_nsamp+46, 4);
+  asyso_putint(asyso_bps*asyso_nsamp+46, 4);
   fseek(asyso_fd, 22, SEEK_SET); /* bugfix by Richard Dobson */
-  asyso_putlong(asyso_nsamp/asyso_channels, 4);
+  asyso_putint(asyso_nsamp/asyso_channels, 4);
   fseek(asyso_fd, 16, SEEK_CUR);
-  asyso_putlong(8 + asyso_bps*asyso_nsamp, 4);
+  asyso_putint(8 + asyso_bps*asyso_nsamp, 4);
   fclose(asyso_fd);
 }
 
@@ -605,7 +605,7 @@ void asys_ioshutdown(void)
 /*        creates buffer, and generates starting silence        */
 /****************************************************************/
 
-int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_preamble(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   int i;
@@ -619,21 +619,21 @@ int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
 /*               sends one frame of audio to output             */
 /****************************************************************/
 
-int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_putbuf(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   float * buf = *asys_obuf;
   float fval;
-  long val;
-  long i = 0;
-  long j = 0;
+  int val;
+  int i = 0;
+  int j = 0;
 
   switch (asyso_bps) {
   case 3:
     while (i < *osize)
       {
 	fval = ((float)(pow(2, 23) - 1))*buf[i++];
-	val = (long)((fval >= 0.0F) ? (fval + 0.5F) : (fval - 0.5F));
+	val = (int)((fval >= 0.0F) ? (fval + 0.5F) : (fval - 0.5F));
 	asyso_cbuf[j++] = (unsigned char)((val >> 16) & 0x000000FF);
 	asyso_cbuf[j++] = (unsigned char)((val >> 8) & 0x000000FF);
 	asyso_cbuf[j++] = (unsigned char) (val & 0x000000FF);
@@ -643,7 +643,7 @@ int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
     while (i < *osize)
       {
 	fval = ((float)(pow(2, 15) - 1))*buf[i++];
-	val = (long)((fval >= 0.0F) ? (fval + 0.5F) : (fval - 0.5F));
+	val = (int)((fval >= 0.0F) ? (fval + 0.5F) : (fval - 0.5F));
 	asyso_cbuf[j++] = (unsigned char)((val >> 8) & 0x000000FF);
 	asyso_cbuf[j++] = (unsigned char) (val & 0x000000FF);
       }
@@ -674,11 +674,11 @@ int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
 /*               get one frame of audio from input              */
 /****************************************************************/
 
-int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
+int asys_getbuf(ASYS_ITYPE * asys_ibuf[], int * isize)
 
 {
-  long i = 0;
-  long j = 0;
+  int i = 0;
+  int j = 0;
 
   if (*asys_ibuf == NULL)
     *asys_ibuf = asysi_buf;
@@ -689,7 +689,7 @@ int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
       return ASYS_DONE;
     }
 
-  *isize = (long)rread(asysi_cbuf, sizeof(unsigned char), asysi_bytes, asysi_fd);
+  *isize = (int)rread(asysi_cbuf, sizeof(unsigned char), asysi_bytes, asysi_fd);
 
   switch (asysi_bps) {
   case 1:                              /* 8-bit  */
@@ -703,8 +703,8 @@ int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
     *isize = (*isize) / 2;
     while (i < *isize)
       {
-	asysi_buf[i] = ((float)pow(2, -15))*((long)(asysi_cbuf[j+1]) + 
-				    (((long)((char)(asysi_cbuf[j]))) << 8)); 
+	asysi_buf[i] = ((float)pow(2, -15))*((int)(asysi_cbuf[j+1]) + 
+				    (((int)((char)(asysi_cbuf[j]))) << 8)); 
 	i++;
 	j += 2;
       }
@@ -713,9 +713,9 @@ int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
     *isize = (*isize) / 3;
     while (i < *isize)
       {
-	asysi_buf[i] = ((float)pow(2, -23))*((long)(asysi_cbuf[j+2]) + 
-				    (((long)(asysi_cbuf[j+1])) << 8) + 
-				    (((long)((char) asysi_cbuf[j])) << 16));
+	asysi_buf[i] = ((float)pow(2, -23))*((int)(asysi_cbuf[j+2]) + 
+				    (((int)(asysi_cbuf[j+1])) << 8) + 
+				    (((int)((char) asysi_cbuf[j])) << 16));
 	i++; 
 	j += 3;
       }
