@@ -102,8 +102,9 @@
 
 /* for printout -- paging */
 
-#define ASYSN_COREAUDIO_SHORTRAM 1   /* not enough RAM          */
-#define ASYSN_COREAUDIO_PAGEIN   0   /* successful page-in      */
+#define ASYSN_COREAUDIO_NOPRINT   2   /* don't print paging info */
+#define ASYSN_COREAUDIO_SHORTRAM  1   /* not enough RAM          */
+#define ASYSN_COREAUDIO_PAGEIN    0   /* successful page-in      */
 #define ASYSN_COREAUDIO_STATFAIL -1  /* Host_statistics failed  */
 
 int asysn_coreaudio_pageinfo;       /* codes success of page-in  */
@@ -802,6 +803,11 @@ OSStatus asysn_coreaudio_only_input(AudioDeviceID inDevice,
 /*   setup function suite  */
 /*-------------------------*/
 
+/* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
+/* todo: rework this function for x86/lion. */
+/*       for now, we "if 0" the entire body */
+/* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
+ 
 /********************************************************************/
 /*                    page in working set                           */
 /********************************************************************/
@@ -817,6 +823,8 @@ void asysn_coreaudio_page()
   vm_address_t raddr;
   vm_size_t rsize;
 
+#if 0
+
   /**********************************/
   /* get current system paging info */
   /**********************************/
@@ -850,9 +858,9 @@ void asysn_coreaudio_page()
       asysn_coreaudio_pageinfo = ASYSN_COREAUDIO_SHORTRAM;
     }
   
-  /**********************************/
-  /* touch every page except page 0 */
-  /**********************************/
+  /***********************************************************/
+  /* touch every page except page 0 -- we crash in this loop */
+  /***********************************************************/
 
   for (addrtop = touchtop*psize; addrtop >= psize; addrtop -= psize)
     asysn_coreaudio_touch ^= *((int *) addrtop);
@@ -898,6 +906,15 @@ void asysn_coreaudio_page()
 
   asysn_coreaudio_pagelock = (err == 0);
   asysn_coreaudio_pagetot  = pagetop;
+
+#else
+
+  /* don't print a paging-info banner */
+
+  asysn_coreaudio_pageinfo = ASYSN_COREAUDIO_NOPRINT;
+
+#endif
+
 }
 
 /********************************************************************/
@@ -1092,7 +1109,13 @@ int asysn_coreaudio_iodevicesetup(void)
 				&size, &asysi_aid) && (asysi_aid == asyso_aid))
     asysn_coreaudio_instatus = ASYSN_COREAUDIO_INPUT_IDEF;
 
-  asysi_aid = asyso_aid;
+
+  if (asysi_aid != asyso_aid)
+    {
+      message = "Driver requires the default device to do input AND output.\n"
+	"         Create an aggregate device w/ Audio MIDI Setup; make it the default";
+      ASYSIO_ERROR_RETURN(message);
+    }
 
   /* see if device is ready to use */
 
@@ -1357,8 +1380,9 @@ void asysn_coreaudio_printbanner(void)
 #endif
 
   printf("\n");
-  printf("Buffer latency: %lfs [%u frames]. Adjust with sfront -latency option.\n",
-	 asysn_coreaudio_frame_seconds, asysn_coreaudio_frame_samples);
+  printf("Buffer latency: %fs [%u frames]. Adjust with sfront -latency option.\n",
+	  asysn_coreaudio_frame_seconds, 
+	 (unsigned int) asysn_coreaudio_frame_samples);
 
   if (asysn_coreaudio_pagelock)
     printf("%i pages locked into RAM.\n", asysn_coreaudio_pagetot);
@@ -1500,8 +1524,8 @@ int asys_osetup(int srate, int ochannels, int osample,
 
       if (((int) core_srate) != srate)
 	{
-	  printf("Error: CoreAudio cannot handle SAOL srate %li\n",srate);
-	  printf("       Change SAOL program srate to %li\n", (int) core_srate);
+	  printf("Error: CoreAudio cannot handle SAOL srate %i\n", (int) srate);
+	  printf("       Change SAOL program srate to %i\n", (int) core_srate);
 	  return ASYS_ERROR;
 	}
 
@@ -1563,8 +1587,8 @@ int asys_isetup(int srate, int ichannels, int isample,
 
       if (((int) in_srate) != srate)
 	{
-	  printf("Error: CoreAudio cannot handle SAOL srate %li\n",srate);
-	  printf("       Change SAOL program srate to %li\n", (int) in_srate);
+	  printf("Error: CoreAudio cannot handle SAOL srate %i\n",srate);
+	  printf("       Change SAOL program srate to %i\n", (int) in_srate);
 	  return ASYS_ERROR;
 	}
 
