@@ -55,10 +55,10 @@
 
 Audio *asyso_a;                  /* audio ptr                     */
 ATransID asyso_x;                /* audio stream                  */
-long asyso_s;                    /* socket for audio stream       */
-long asyso_pflag;                /* flag for hardware head start  */
-long asyso_pidx;                 /* number of bytes of head start */
-long asyso_size;                 /* number of shorts in a buffer  */
+int asyso_s;                    /* socket for audio stream       */
+int asyso_pflag;                /* flag for hardware head start  */
+int asyso_pidx;                 /* number of bytes of head start */
+int asyso_size;                 /* number of shorts in a buffer  */
 short * asyso_buf;               /* location for output buffer    */
  
 #endif
@@ -67,13 +67,13 @@ short * asyso_buf;               /* location for output buffer    */
 
 Audio    *asysi_a;      /* audio ptr                     */
 ATransID asysi_x;       /* audio stream                  */
-long     asysi_s;       /* socket for audio stream       */
-long     asysi_size;    /* number of shorts in a buffer  */
+int     asysi_s;       /* socket for audio stream       */
+int     asysi_size;    /* number of shorts in a buffer  */
 short    *asysi_buf;    /* location for output buffer    */
 fd_set   asysi_selFD;   /* select file descriptor        */
 fd_set   asysi_redFD;   /* ready file descriptor         */
-long     asysi_stdFD;   /* stdin file descriptor         */
-long     asysi_maxFD;   /* max-numbered file descriptor  */
+int     asysi_stdFD;   /* stdin file descriptor         */
+int     asysi_maxFD;   /* max-numbered file descriptor  */
 
 #endif
 
@@ -84,8 +84,8 @@ long     asysi_maxFD;   /* max-numbered file descriptor  */
 /*        sets up audio system for a given srate/channels       */
 /****************************************************************/
 
-int asyso_setup(long srate, long ochannels, long osize, char * oname,
-		long toption)
+int asyso_setup(int srate, int ochannels, int osize, char * oname,
+		int toption)
 
 {
   AudioAttributes aa;
@@ -164,7 +164,7 @@ int asyso_setup(long srate, long ochannels, long osize, char * oname,
 /*              initializes audio input                         */
 /****************************************************************/
 
-int asysi_setup(long srate, long ichannels, long isize, char * iname)
+int asysi_setup(int srate, int ichannels, int isize, char * iname)
 
 {
   AudioAttributes rr;
@@ -241,8 +241,8 @@ int asysi_setup(long srate, long ichannels, long isize, char * iname)
 /*              initializes audio input                         */
 /****************************************************************/
 
-int asys_isetup(long srate, long ichannels, long isample, 
-                char * iname, long toption)
+int asys_isetup(int srate, int ichannels, int isample, 
+                char * iname, int toption)
 
 {
   return asysi_setup(srate, ichannels, ASYS_ICHAN*ACYCLE, iname);
@@ -256,8 +256,8 @@ int asys_isetup(long srate, long ichannels, long isample,
 /*        sets up audio system for a given srate/channels       */
 /****************************************************************/
 
-int asys_osetup(long srate, long ochannels, long osample, 
-                char * oname, long toption)
+int asys_osetup(int srate, int ochannels, int osample, 
+                char * oname, int toption)
 
 {
   return asyso_setup(srate, ochannels, ASYS_OCHAN*ACYCLE, oname, toption);
@@ -271,9 +271,9 @@ int asys_osetup(long srate, long ochannels, long osample,
 /*        initializes bidirectional audio flows                 */
 /****************************************************************/
 
-int asys_iosetup(long srate, long ichannels, long ochannels,
-                 long isample, long osample, 
-                 char * iname, char * oname, long toption)
+int asys_iosetup(int srate, int ichannels, int ochannels,
+                 int isample, int osample, 
+                 char * iname, char * oname, int toption)
 
 
 {
@@ -372,7 +372,7 @@ void asys_ioshutdown(void)
 /*        creates buffer, and generates starting silence        */
 /****************************************************************/
 
-int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_preamble(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   int i;
@@ -387,7 +387,7 @@ int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
 /*               sends one frame of audio to output             */
 /****************************************************************/
 
-int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_putbuf(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   int bsize, bwrite;
@@ -418,7 +418,7 @@ int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
 /*               gets one frame of audio from input             */
 /****************************************************************/
 
-int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
+int asys_getbuf(ASYS_ITYPE * asys_ibuf[], int * isize)
 
 {
 
