@@ -61,9 +61,9 @@ volatile int asysn_portaudio_done;
 #if (defined(ASYS_ACTIVE_IO) && !defined(ASYS_HASINPUT))
 
 ASYS_ITYPE * asysn_portaudio_ibuf;
-long asysn_portaudio_iptr;
-long asysn_portaudio_ilast;
-long asysn_portaudio_ileft;
+int asysn_portaudio_iptr;
+int asysn_portaudio_ilast;
+int asysn_portaudio_ileft;
 
 #endif
 
@@ -72,9 +72,9 @@ long asysn_portaudio_ileft;
 #if (defined(ASYS_ACTIVE_IO) && !defined(ASYS_HASOUTPUT))
 
 ASYS_OTYPE * asysn_portaudio_obuf;
-long asysn_portaudio_optr;
-long asysn_portaudio_olast;
-long asysn_portaudio_oleft;
+int asysn_portaudio_optr;
+int asysn_portaudio_olast;
+int asysn_portaudio_oleft;
 
 #endif
 
@@ -93,10 +93,10 @@ int asysn_portaudio_callback(void * inputBuffer, void * outputBuffer,
 			     unsigned long framesPerBuffer, 
 			     PaTimestamp outTime, void *userData)
 {
-  long optr = 0;
-  long oleft = (long) (framesPerBuffer * ASYS_OCHAN);
+  int optr = 0;
+  int oleft = (int) (framesPerBuffer * ASYS_OCHAN);
   float * obuf = (float *) outputBuffer;
-  long osize;
+  int osize;
 
   if ((asysn_portaudio_done == ASYS_DONE) && (asysn_portaudio_silence == 0))
     {
@@ -137,11 +137,11 @@ int asysn_portaudio_callback(void * inputBuffer, void * outputBuffer,
 			     unsigned long framesPerBuffer, 
 			     PaTimestamp outTime, void *userData)
 {
-  long ileft = (long) (framesPerBuffer * ASYS_ICHAN);
-  long oleft = (long) (framesPerBuffer * ASYS_OCHAN);
+  int ileft = (int) (framesPerBuffer * ASYS_ICHAN);
+  int oleft = (int) (framesPerBuffer * ASYS_OCHAN);
   float * ibuf = (float *) inputBuffer;
   float * obuf = (float *) outputBuffer;
-  long isize, osize;
+  int isize, osize;
 
   isize = ileft;
   osize = oleft;
@@ -176,9 +176,9 @@ int asysn_portaudio_callback(void * inputBuffer, void * outputBuffer,
 			     unsigned long framesPerBuffer, 
 			     PaTimestamp outTime, void *userData)
 {
-  long isize, osize;
-  long optr = 0;
-  long oleft = (long) (framesPerBuffer * ASYS_OCHAN);
+  int isize, osize;
+  int optr = 0;
+  int oleft = (int) (framesPerBuffer * ASYS_OCHAN);
   float * obuf = (float *) outputBuffer;
 
   if ((asysn_portaudio_done == ASYS_DONE) && (asysn_portaudio_silence == 0))
@@ -236,9 +236,9 @@ int asysn_portaudio_callback(void * inputBuffer, void * outputBuffer,
 			     unsigned long framesPerBuffer, 
 			     PaTimestamp outTime, void *userData)
 {
-  long isize, osize;
-  long iptr = 0;
-  long ileft = (long) (framesPerBuffer * ASYS_ICHAN);
+  int isize, osize;
+  int iptr = 0;
+  int ileft = (int) (framesPerBuffer * ASYS_ICHAN);
   float * ibuf = (float *) inputBuffer;
 
   while ((asysn_portaudio_done == ASYS_DONE) && ileft)
@@ -307,7 +307,7 @@ int asysn_portaudio_init(void)
 /*              check default output suitability                */
 /****************************************************************/
 
-int asysn_portaudio_outcheck(double * srate, long ochannels, PaDeviceID * pid)
+int asysn_portaudio_outcheck(double * srate, int ochannels, PaDeviceID * pid)
 
 {  
   const PaDeviceInfo * pidinfo;
@@ -375,7 +375,7 @@ int asysn_portaudio_outcheck(double * srate, long ochannels, PaDeviceID * pid)
 /*              check default input suitability                 */
 /****************************************************************/
 
-int asysn_portaudio_incheck(double * srate, long ichannels, PaDeviceID * pid)
+int asysn_portaudio_incheck(double * srate, int ichannels, PaDeviceID * pid)
 
 {  
   const PaDeviceInfo * pidinfo;
@@ -513,8 +513,8 @@ int asysn_portaudio_buffparam(unsigned long * framesPerBuffer,
 /*  portaudio output only: a ASYS_ACTIVE_IO, all ASYS_ACTIVE_O  */
 /****************************************************************/
 
-int asys_osetup(long srate, long ochannels, long osample, 
-		char * oname, long toption)
+int asys_osetup(int srate, int ochannels, int osample, 
+		char * oname, int toption)
 
 {
   double samplerate = (double) srate;
@@ -564,8 +564,8 @@ int asys_osetup(long srate, long ochannels, long osample,
 /* portaudio input only: a ASYS_ACTIVE_IO case                  */
 /****************************************************************/
 
-int asys_isetup(long srate, long ichannels, long isample, 
-		char * iname, long toption)
+int asys_isetup(int srate, int ichannels, int isample, 
+		char * iname, int toption)
 
 {
   double samplerate = (double) srate;
@@ -609,9 +609,9 @@ int asys_isetup(long srate, long ichannels, long isample,
 /*   portaudio input and output: a ASYS_ACTIVE_IO case          */
 /****************************************************************/
 
-int asys_iosetup(long srate, long ichannels, long ochannels,
-		 long isample, long osample, 
-		 char * iname, char * oname, long toption)
+int asys_iosetup(int srate, int ichannels, int ochannels,
+		 int isample, int osample, 
+		 char * iname, char * oname, int toption)
 
 {
   double osamplerate = (double) srate;
