@@ -54,12 +54,12 @@
 
 FILE * asyso_fd;     /* output file pointer */
 char * asyso_name;   /* name of file  */        
-long asyso_srate;    /* sampling rate */
-long asyso_channels; /* number of channels */
-long asyso_size;     /* number of float samples _buf */
-long asyso_nsamp;    /* total number of samples written */
-long asyso_bps;      /* number of bytes per sample, 1-3 */
-long asyso_doswap;   /* needs byteswap on write */
+int asyso_srate;    /* sampling rate */
+int asyso_channels; /* number of channels */
+int asyso_size;     /* number of float samples _buf */
+int asyso_nsamp;    /* total number of samples written */
+int asyso_bps;      /* number of bytes per sample, 1-3 */
+int asyso_doswap;   /* needs byteswap on write */
 float * asyso_buf;   /* output floats from sfront */ 
 unsigned char * asyso_cbuf;  /* output chars to file */
 #endif
@@ -80,12 +80,12 @@ unsigned char * asyso_cbuf;  /* output chars to file */
 
 FILE * asysi_fd;     /* input file pointer */
 char * asysi_name;   /* name of file  */        
-long asysi_srate;    /* sampling rate */
-long asysi_channels; /* number of channels */
-long asysi_bytes;     /* number of bytes in a buffer */
-long asysi_nsamp;    /* total number of samples read */
-long asysi_bps;      /* number of bytes per sample, 1-3 */
-long asysi_doswap;   /* needs byteswap on read */
+int asysi_srate;    /* sampling rate */
+int asysi_channels; /* number of channels */
+int asysi_bytes;     /* number of bytes in a buffer */
+int asysi_nsamp;    /* total number of samples read */
+int asysi_bps;      /* number of bytes per sample, 1-3 */
+int asysi_doswap;   /* needs byteswap on read */
 unsigned char * asysi_cbuf;  /* buffer of WAV file bytes */
 float * asysi_buf;   /* float buffer for sfront */ 
 
@@ -106,10 +106,10 @@ int asyso_putbytes(unsigned char * c, int numbytes)
 }
 
 /*********************************************************/
-/*        writes unsigned long to a WAV files            */
+/*        writes unsigned int to a WAV files             */
 /*********************************************************/
 
-int asyso_putlong(unsigned long val, int numbytes)
+int asyso_putint(unsigned int val, int numbytes)
 
 {
   unsigned char c[4];
@@ -145,7 +145,7 @@ int asyso_putlong(unsigned long val, int numbytes)
 /*        core routine for audio output setup                   */
 /****************************************************************/
 
-int asyso_setup(long srate, long ochannels, long osize, char * name)
+int asyso_setup(int srate, int ochannels, int osize, char * name)
 
 
 {
@@ -178,17 +178,17 @@ int asyso_setup(long srate, long ochannels, long osize, char * name)
   /* preamble for wav file */
 
   asyso_putbytes((unsigned char *) "RIFF",4);
-  asyso_putlong(0,4);       /* patched later */
+  asyso_putint(0,4);       /* patched later */
   asyso_putbytes((unsigned char *) "WAVEfmt ",8);
-  asyso_putlong(16,4);
-  asyso_putlong(1,2);                          /* PCM  */
-  asyso_putlong(ochannels,2);                  /* number of channels */
-  asyso_putlong(srate,4);                      /* srate */
-  asyso_putlong(srate*ochannels*asyso_bps, 4); /* bytes/sec */
-  asyso_putlong(ochannels*asyso_bps, 2);       /* block align */
-  asyso_putlong(8*asyso_bps, 2);               /* bits per sample */
+  asyso_putint(16,4);
+  asyso_putint(1,2);                          /* PCM  */
+  asyso_putint(ochannels,2);                  /* number of channels */
+  asyso_putint(srate,4);                      /* srate */
+  asyso_putint(srate*ochannels*asyso_bps, 4); /* bytes/sec */
+  asyso_putint(ochannels*asyso_bps, 2);       /* block align */
+  asyso_putint(8*asyso_bps, 2);               /* bits per sample */
   asyso_putbytes((unsigned char *) "data",4);
-  asyso_putlong(0,4);                          /* patched later */
+  asyso_putint(0,4);                          /* patched later */
 
   asyso_srate = srate;
   asyso_channels = ochannels;
@@ -251,10 +251,10 @@ int asysi_flushbytes(int numbytes)
 }
 
 /*********************************************************/
-/*     converts byte stream to an unsigned long          */
+/*     converts byte stream to an unsigned int           */
 /*********************************************************/
 
-long asysi_getlong(int numbytes, unsigned long * ret)
+int asysi_getint(int numbytes, unsigned int * ret)
 
 {
   unsigned char c[4];
@@ -265,22 +265,22 @@ long asysi_getlong(int numbytes, unsigned long * ret)
     return ASYS_ERROR;
   switch (numbytes) {
   case 4:
-    *ret  =  (unsigned long)c[0];
-    *ret |=  (unsigned long)c[1] << 8;
-    *ret |=  (unsigned long)c[2] << 16;
-    *ret |=  (unsigned long)c[3] << 24;
+    *ret  =  (unsigned int)c[0];
+    *ret |=  (unsigned int)c[1] << 8;
+    *ret |=  (unsigned int)c[2] << 16;
+    *ret |=  (unsigned int)c[3] << 24;
     return ASYS_DONE;
   case 3:
-    *ret  =  (unsigned long)c[0];
-    *ret |=  (unsigned long)c[1] << 8;
-    *ret |=  (unsigned long)c[2] << 16;
+    *ret  =  (unsigned int)c[0];
+    *ret |=  (unsigned int)c[1] << 8;
+    *ret |=  (unsigned int)c[2] << 16;
     return ASYS_DONE;
   case 2:
-    *ret  =  (unsigned long)c[0];
-    *ret |=  (unsigned long)c[1] << 8;
+    *ret  =  (unsigned int)c[0];
+    *ret |=  (unsigned int)c[1] << 8;
     return ASYS_DONE;
   case 1:
-    *ret = (unsigned long)c[0];
+    *ret = (unsigned int)c[0];
     return ASYS_DONE;
   default:
     return ASYS_ERROR;
@@ -308,13 +308,13 @@ int asysi_soundtypecheck(char * d)
 /*        core routine for audio input setup                   */
 /****************************************************************/
 
-int asysi_setup(long srate, long ichannels, long isize, char * name)
+int asysi_setup(int srate, int ichannels, int isize, char * name)
 
 
 {
   short swaptest = 0x0100;
-  unsigned long i, cookie;
-  long len;
+  unsigned int i, cookie;
+  int len;
   char * val;
 
   asysi_doswap = *((char *)&swaptest);
@@ -338,37 +338,37 @@ int asysi_setup(long srate, long ichannels, long isize, char * name)
     {
       if (cookie == ASYSI_EOF)
 	return ASYS_ERROR;
-      if (asysi_getlong(4, &i) != ASYS_DONE)
+      if (asysi_getint(4, &i) != ASYS_DONE)
 	return ASYS_ERROR;
       if (asysi_flushbytes(i + (i % 2))!= ASYS_DONE)
 	return ASYS_ERROR;
     }
-  if (asysi_getlong(4, &i) != ASYS_DONE)
+  if (asysi_getint(4, &i) != ASYS_DONE)
     return ASYS_ERROR;
   len = i;
   if ((len -= 16) < 0)
     return ASYS_ERROR;
-  if (asysi_getlong(2, &i) != ASYS_DONE)
+  if (asysi_getint(2, &i) != ASYS_DONE)
     return ASYS_ERROR;
   if (i != 1)
     {
       fprintf(stderr,"Error: Can only handle PCM WAV files\n");
       return ASYS_ERROR;
     }
-  if (asysi_getlong(2, &i) != ASYS_DONE)
+  if (asysi_getint(2, &i) != ASYS_DONE)
     return ASYS_ERROR;
   if (i != ichannels)
     {
       fprintf(stderr,"Error: Inchannels doesn't match WAV file\n");
       return ASYS_ERROR;
     }
-  if (asysi_getlong(4, &i) != ASYS_DONE)
+  if (asysi_getint(4, &i) != ASYS_DONE)
     return ASYS_ERROR;
   if (srate != i)
     fprintf(stderr,"Warning: SAOL srate %i mismatches WAV file srate %i\n",
 	    srate,i);
   asysi_flushbytes(6);
-  if (asysi_getlong(2, &i) != ASYS_DONE)
+  if (asysi_getint(2, &i) != ASYS_DONE)
     return ASYS_ERROR;
   if ((i < 8) || (i > 24))
     {
@@ -382,12 +382,12 @@ int asysi_setup(long srate, long ichannels, long isize, char * name)
     {
       if (cookie == ASYSI_EOF)
 	return ASYS_ERROR;
-      if (asysi_getlong(4, &i) != ASYS_DONE)
+      if (asysi_getint(4, &i) != ASYS_DONE)
 	return ASYS_ERROR;
       if (asysi_flushbytes(i + (i % 2))!= ASYS_DONE)
 	return ASYS_ERROR;
     }
-  if (asysi_getlong(4, &i) != ASYS_DONE)
+  if (asysi_getint(4, &i) != ASYS_DONE)
     return ASYS_ERROR;
 
   asysi_nsamp = i/asysi_bps;
@@ -423,11 +423,11 @@ int asysi_setup(long srate, long ichannels, long isize, char * name)
 /*        sets up audio output for a given srate/channels       */
 /****************************************************************/
 
-int asys_osetup(long srate, long ochannels, long osample, 
-		char * oname, long toption)
+int asys_osetup(int srate, int ochannels, int osample, 
+		char * oname, int toption)
 
 {
-  return asyso_setup(srate, ochannels, ASYS_OCHAN*ACYCLE, oname);
+  return asyso_setup(srate, ochannels, ASYS_OCHAN*EV(ACYCLE), oname);
 }
 
 #endif
@@ -439,11 +439,11 @@ int asys_osetup(long srate, long ochannels, long osample,
 /*        sets up audio input for a given srate/channels       */
 /****************************************************************/
 
-int asys_isetup(long srate, long ichannels, long isample, 
-		char * iname, long toption)
+int asys_isetup(int srate, int ichannels, int isample, 
+		char * iname, int toption)
 
 {
-  return asysi_setup(srate, ichannels, ASYS_ICHAN*ACYCLE, iname);
+  return asysi_setup(srate, ichannels, ASYS_ICHAN*EV(ACYCLE), iname);
 }
 
 #endif
@@ -455,15 +455,15 @@ int asys_isetup(long srate, long ichannels, long isample,
 /*   sets up audio input and output for a given srate/channels  */
 /****************************************************************/
 
-int asys_iosetup(long srate, long ichannels, long ochannels,
-		 long isample, long osample, 
-		 char * iname, char * oname, long toption)
+int asys_iosetup(int srate, int ichannels, int ochannels,
+		 int isample, int osample, 
+		 char * iname, char * oname, int toption)
 
 {
 
-  if (asysi_setup(srate, ichannels, ASYS_ICHAN*ACYCLE, iname) != ASYS_DONE)
+  if (asysi_setup(srate, ichannels, ASYS_ICHAN*EV(ACYCLE), iname) != ASYS_DONE)
     return ASYS_ERROR;
-  return asyso_setup(srate, ochannels, ASYS_OCHAN*ACYCLE, oname);
+  return asyso_setup(srate, ochannels, ASYS_OCHAN*EV(ACYCLE), oname);
 
 }
 
@@ -480,9 +480,9 @@ void asyso_shutdown(void)
 {
 
   fseek(asyso_fd, 4, SEEK_SET);
-  asyso_putlong(asyso_bps*(unsigned long)asyso_nsamp+36,4);
+  asyso_putint(asyso_bps*(unsigned int)asyso_nsamp+36,4);
   fseek(asyso_fd, 32, SEEK_CUR);
-  asyso_putlong(asyso_bps*(unsigned long)asyso_nsamp,4);
+  asyso_putint(asyso_bps*(unsigned int)asyso_nsamp,4);
   fclose(asyso_fd);
 
 }
@@ -556,7 +556,7 @@ void asys_ioshutdown(void)
 /*        creates buffer, and generates starting silence        */
 /****************************************************************/
 
-int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_preamble(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   *asys_obuf = asyso_buf;
@@ -568,21 +568,21 @@ int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
 /*               sends one frame of audio to output             */
 /****************************************************************/
 
-int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_putbuf(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   float * buf = *asys_obuf;
   float fval;
-  long val;
-  long i = 0;
-  long j = 0;
+  int val;
+  int i = 0;
+  int j = 0;
 
   switch (asyso_bps) {
   case 3:
     while (i < *osize)
       {
 	fval = ((float)(pow(2, 23) - 1))*buf[i++];
-	val = (long)((fval >= 0.0F) ? (fval + 0.5F) : (fval - 0.5F));
+	val = (int)((fval >= 0.0F) ? (fval + 0.5F) : (fval - 0.5F));
 	asyso_cbuf[j++] = (unsigned char) (val & 0x000000FF);
 	asyso_cbuf[j++] = (unsigned char)((val >> 8) & 0x000000FF);
 	asyso_cbuf[j++] = (unsigned char)((val >> 16) & 0x000000FF);
@@ -592,7 +592,7 @@ int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
     while (i < *osize)
       {
 	fval = ((float)(pow(2, 15) - 1))*buf[i++];
-	val = (long)((fval >= 0.0F) ? (fval + 0.5F) : (fval - 0.5F));
+	val = (int)((fval >= 0.0F) ? (fval + 0.5F) : (fval - 0.5F));
 	asyso_cbuf[j++] = (unsigned char) (val & 0x000000FF);
 	asyso_cbuf[j++] = (unsigned char)((val >> 8) & 0x000000FF);
       }
@@ -624,11 +624,11 @@ int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
 /*               get one frame of audio from input              */
 /****************************************************************/
 
-int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
+int asys_getbuf(ASYS_ITYPE * asys_ibuf[], int * isize)
 
 {
-  long i = 0;
-  long j = 0;
+  int i = 0;
+  int j = 0;
 
   if (*asys_ibuf == NULL)
     *asys_ibuf = asysi_buf;
@@ -639,7 +639,7 @@ int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
       return ASYS_DONE;
     }
 
-  *isize = (long)rread(asysi_cbuf, sizeof(unsigned char), asysi_bytes, asysi_fd);
+  *isize = (int)rread(asysi_cbuf, sizeof(unsigned char), asysi_bytes, asysi_fd);
 
   switch (asysi_bps) {
   case 1:                              /* 8-bit  */
@@ -653,8 +653,8 @@ int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
     *isize = (*isize) / 2;
     while (i < *isize)
       {
-	asysi_buf[i] = ((float)pow(2, -15))*((long)(asysi_cbuf[j]) + 
-				    (((long)((char)(asysi_cbuf[j+1]))) << 8)); 
+	asysi_buf[i] = ((float)pow(2, -15))*((int)(asysi_cbuf[j]) + 
+				    (((int)((char)(asysi_cbuf[j+1]))) << 8)); 
 	i++;
 	j += 2;
       }
@@ -663,9 +663,9 @@ int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
     *isize = (*isize) / 3;
     while (i < *isize)
       {
-	asysi_buf[i] = ((float)pow(2, -23))*((long)(asysi_cbuf[j]) + 
-				    (((long)(asysi_cbuf[j+1])) << 8) + 
-				    (((long)((char) asysi_cbuf[j+2])) << 16));
+	asysi_buf[i] = ((float)pow(2, -23))*((int)(asysi_cbuf[j]) + 
+				    (((int)(asysi_cbuf[j+1])) << 8) + 
+				    (((int)((char) asysi_cbuf[j+2])) << 16));
 	i++; 
 	j += 3;
       }
