@@ -40,62 +40,61 @@
 
 #if defined(ASYS_ACTIVE_O)
 
-int asys_orun(ASYS_OTYPE obuf[], long * osize)
+int asys_orun(ASYS_OTYPE obuf[], int * osize)
 
 {
   int obusidx = 0;
   int busidx;
 
-  if (asys_exit_status == ASYS_EXIT)
+  if (EV(asys_exit_status) == ASYS_EXIT)
     return ASYS_EXIT;
 
   while (obusidx < *osize)
-    if (acycleidx < ACYCLE)
+    if (EV(acycleidx) < EV(ACYCLE))
       {
-	for (busidx=0; busidx<ENDBUS;busidx++)
-	  bus[busidx]=0.0F;
-	main_apass();
+	memset(&(TB(0)), 0, sizeof(TB(0))*ENDBUS);
+	main_apass(ENGINE_PTR);
 	for (busidx=BUS_output_bus; busidx<ENDBUS_output_bus;busidx++)
 	  {
-	    bus[busidx] = (bus[busidx] >  1.0F) ?  1.0F : bus[busidx];
+	    TB(busidx) = (TB(busidx) >  1.0F) ?  1.0F : TB(busidx);
 
 #if (ASYS_OTYPENAME == ASYS_SHORT)
-	    bus[busidx] = (bus[busidx] < -1.0F) ? -1.0F : bus[busidx];
-	    obuf[obusidx++] = (short) (32767.0F * bus[busidx]);
+	    TB(busidx) = (TB(busidx) < -1.0F) ? -1.0F : TB(busidx);
+	    obuf[obusidx++] = (short) (32767.0F * TB(busidx));
 #endif
 
 #if (ASYS_OTYPENAME == ASYS_FLOAT)
-	    obuf[obusidx++] = (bus[busidx] < -1.0F) ? -1.0F : bus[busidx];
+	    obuf[obusidx++] = (TB(busidx) < -1.0F) ? -1.0F : TB(busidx);
 #endif
 
 	  }
-	acycleidx++;
+	EV(acycleidx)++;
       }
     else
       {
-	acycleidx = 0;
-	if (pass == APASS)
+	EV(acycleidx) = 0;
+	if (EV(pass) == APASS)
 	  {      
-	    cpuload = ksync();
-	    kcycleidx++;
+	    EV(cpuload) = ksync();
+	    EV(kcycleidx)++;
 	  }
-	if (kcycleidx > endkcycle)
+	if (EV(kcycleidx) > EV(endkcycle))
 	  {
 	    *osize = obusidx;
-	    return (asys_exit_status = ASYS_EXIT);
+	    return (EV(asys_exit_status) = ASYS_EXIT);
 	  }
-	pass = IPASS;
-	scorebeats = scoremult*(kcycleidx - kbase) + scorebase;
-	absolutetime = (kcycleidx - 1)*KTIME;
-	main_ipass();
-	pass = KPASS;
-	main_control();
-	if (main_kpass())
+	EV(pass) = IPASS;
+	EV(scorebeats) = EV(scoremult)*(EV(kcycleidx) - EV(kbase)) + EV(scorebase);
+	EV(absolutetime) = (EV(kcycleidx) - 1)*EV(KTIME);
+	main_ipass(ENGINE_PTR);
+	EV(pass) = KPASS;
+	main_control(ENGINE_PTR);
+	if (main_kpass(ENGINE_PTR))
 	  {
 	    *osize = obusidx;
-	    return (asys_exit_status = ASYS_EXIT);
+	    return (EV(asys_exit_status) = ASYS_EXIT);
 	  }
-	pass = APASS;
+	EV(pass) = APASS;
       }
 
   return ASYS_DONE;
@@ -106,75 +105,74 @@ int asys_orun(ASYS_OTYPE obuf[], long * osize)
 
 #if defined(ASYS_ACTIVE_IO)
 
-int asys_iorun(ASYS_ITYPE ibuf[], long * isize,ASYS_OTYPE obuf[], long * osize)
+int asys_iorun(ASYS_ITYPE ibuf[], int * isize,ASYS_OTYPE obuf[], int * osize)
 
 {  
   int ibusidx = 0;
   int obusidx = 0;
   int busidx;
 
-  if (asys_exit_status == ASYS_EXIT)
+  if (EV(asys_exit_status) == ASYS_EXIT)
     return ASYS_EXIT;
 
   while ((obusidx < *osize) && (ibusidx < *isize))
-    if (acycleidx < ACYCLE)
+    if (EV(acycleidx) < EV(ACYCLE))
       {
-	for (busidx=0; busidx<ENDBUS;busidx++)
-	  bus[busidx] = 0.0F;
+	memset(&(TB(0)), 0, sizeof(TB(0))*ENDBUS);
 
 #if (ASYS_ITYPENAME == ASYS_SHORT)
 	for(busidx=BUS_input_bus;busidx<ENDBUS_input_bus;busidx++)
-	  bus[busidx] = 3.051851e-5F*ibuf[ibusidx++];
+	  TB(busidx) = 3.051851e-5F*ibuf[ibusidx++];
 #endif
 
 #if (ASYS_ITYPENAME == ASYS_FLOAT)
 	for(busidx=BUS_input_bus;busidx<ENDBUS_input_bus;busidx++)
-	  bus[busidx] = ibuf[ibusidx++];
+	  TB(busidx) = ibuf[ibusidx++];
 #endif
 
-	main_apass();
+	main_apass(ENGINE_PTR);
 	for (busidx=BUS_output_bus; busidx<ENDBUS_output_bus;busidx++)
 	  {
-	    bus[busidx] = (bus[busidx] >  1.0F) ?  1.0F : bus[busidx];
+	    TB(busidx) = (TB(busidx) >  1.0F) ?  1.0F : TB(busidx);
 
 #if (ASYS_OTYPENAME == ASYS_SHORT)
-	    bus[busidx] = (bus[busidx] < -1.0F) ? -1.0F : bus[busidx];
-	    obuf[obusidx++] = (short) (32767.0F * bus[busidx]);
+	    TB(busidx) = (TB(busidx) < -1.0F) ? -1.0F : TB(busidx);
+	    obuf[obusidx++] = (short) (32767.0F * TB(busidx));
 #endif
 
 #if (ASYS_OTYPENAME == ASYS_FLOAT)
-	    obuf[obusidx++] = (bus[busidx] < -1.0F) ? -1.0F : bus[busidx];
+	    obuf[obusidx++] = (TB(busidx) < -1.0F) ? -1.0F : TB(busidx);
 #endif
 	  }
-	acycleidx++;
+	EV(acycleidx)++;
       }
     else
       {
-	acycleidx = 0;
-	if (pass == APASS)
+	EV(acycleidx) = 0;
+	if (EV(pass) == APASS)
 	  {      
-	    cpuload = ksync();
-	    kcycleidx++;
+	    EV(cpuload) = ksync();
+	    EV(kcycleidx)++;
 	  }
-	if (kcycleidx > endkcycle)
+	if (EV(kcycleidx) > EV(endkcycle))
 	  {
 	    *osize = obusidx;
 	    *isize = ibusidx;
-	    return (asys_exit_status = ASYS_EXIT);
+	    return (EV(asys_exit_status) = ASYS_EXIT);
 	  }
-	pass = IPASS;
-	scorebeats = scoremult*(kcycleidx - kbase) + scorebase;
-	absolutetime = (kcycleidx - 1)*KTIME;
-	main_ipass();
-	pass = KPASS;
-	main_control();
-	if (main_kpass())
+	EV(pass) = IPASS;
+	EV(scorebeats) = EV(scoremult)*(EV(kcycleidx) - EV(kbase)) + EV(scorebase);
+	EV(absolutetime) = (EV(kcycleidx) - 1)*EV(KTIME);
+	main_ipass(ENGINE_PTR);
+	EV(pass) = KPASS;
+	main_control(ENGINE_PTR);
+	if (main_kpass(ENGINE_PTR))
 	  {
 	    *osize = obusidx;
 	    *isize = ibusidx;
-	    return (asys_exit_status = ASYS_EXIT);
+	    return (EV(asys_exit_status) = ASYS_EXIT);
 	  }
-	pass = APASS;
+	EV(pass) = APASS;
       }
 
   if (obusidx < *osize)
@@ -190,16 +188,16 @@ int asys_iorun(ASYS_ITYPE ibuf[], long * isize,ASYS_OTYPE obuf[], long * osize)
 int main(int argc, char *argv[])
 
 {
-  system_init(argc, argv);
-  effects_init();
-  main_initpass();
+  system_init(argc, argv, SAOL_SRATE);
+  effects_init(ENGINE_PTR);
+  main_initpass(ENGINE_PTR);
 
-  kcycleidx = kbase;
-  acycleidx = ACYCLE;
-  pass = IPASS;
+  EV(kcycleidx) = EV(kbase);
+  EV(acycleidx) = EV(ACYCLE);
+  EV(pass) = IPASS;
 
   asys_main();
-  shut_down();
+  shut_down(ENGINE_PTR);
   return 0;
 }
 
