@@ -1,7 +1,7 @@
 
 /*
 #    Sfront, a SAOL to C translator    
-#    This file: Robust file I/O, termination function
+#    This file: Robust file I/O
 #
 # Copyright (c) 1999-2006, Regents of the University of California
 # All rights reserved.
@@ -37,32 +37,14 @@
 */
 
 
-/* handles termination in case of error */
-
-void epr(int linenum, char * filename, char * token, char * message)
-
-{
-
-  fprintf(stderr, "\nRuntime Error.\n");
-  if (filename != NULL)
-    fprintf(stderr, "Location: File %s near line %i.\n",filename, linenum);
-  if (token != NULL)
-    fprintf(stderr, "While executing: %s.\n",token);
-  if (message != NULL)
-    fprintf(stderr, "Potential problem: %s.\n",message);
-  fprintf(stderr, "Exiting program.\n\n");
-  exit(-1);
-
-}
-
 /* robust replacement for fread() */
 
 size_t rread(void * ptr, size_t size, size_t nmemb, FILE * stream)
 
 {
-  long recv;
-  long len;
-  long retry;
+  int recv;
+  int len;
+  int retry;
   char * c;
 
   /* fast path */
@@ -108,9 +90,9 @@ size_t rread(void * ptr, size_t size, size_t nmemb, FILE * stream)
 size_t rwrite(void * ptr, size_t size, size_t nmemb, FILE * stream)
 
 {
-  long recv;
-  long len;
-  long retry;
+  int recv;
+  int len;
+  int retry;
   char * c;
 
   /* fast path */
