@@ -83,8 +83,8 @@ void picola(struct tableinfo * in, struct tableinfo * out,
   factor = 1/factor;
 
   over = p1 = p0 = 0;
-  pmin = 5.0e-3F*ARATE;
-  pmax = 2.0e-2F*ARATE;
+  pmin = 5.0e-3F*EV(ARATE);
+  pmax = 2.0e-2F*EV(ARATE);
   while (!over)
   {
     i = pmin;
@@ -215,7 +215,7 @@ void picola(struct tableinfo * in, struct tableinfo * out,
     {
       out->len = p1;
       out->lenf = (float)p1;
-      out->oconst = ((float)p1)*ATIME;
+      out->oconst = ((float)p1)*EV(ATIME);
     }
   out->t[out->len] = out->t[0]; 
   out->base = in->base;
