@@ -67,8 +67,8 @@ int csysi_error = 0;
 
 unsigned char csysi_hold[CSYSI_BUFFSIZE];
 unsigned char csysi_data[CSYSI_BUFFSIZE];
-long csysi_len;
-long csysi_cnt;
+int csysi_len;
+int csysi_cnt;
 unsigned char csysi_cmd;
 unsigned char csysi_num;
 unsigned short csysi_extchan;
