@@ -133,20 +133,20 @@ int csys_setup(void)
   csysi_init_maps();
   
   /* Command line processing */
-  for (arg=1; arg<csys_argc; arg++) {
-    if (strcmp(csys_argv[arg],"-csys_alsaseq_subscribe"))
+  for (arg=1; arg<EV(csys_argc); arg++) {
+    if (strcmp(EV(csys_argv[arg]),"-csys_alsaseq_subscribe"))
       continue;
-    while ((arg+1)<csys_argc && csys_argv[arg+1][0] != '-') {
+    while ((arg+1)<EV(csys_argc) && EV(csys_argv[arg+1])[0] != '-') {
       arg++;
-      if ((addr = csysi_parse_address(csys_argv[arg])) < 0) {
+      if ((addr = csysi_parse_address(EV(csys_argv[arg]))) < 0) {
 	fprintf(stderr,"ALSASEQ: Warning: Invalid ALSA address: %s\n\n",
-		csys_argv[arg]);
+		EV(csys_argv[arg]));
 	continue;
       }
       if (csysi_new_ext_channel_device(addr) < 0) {
 	fprintf(stderr,"ALSASEQ: Warning: Ignored subscription to %s:\n"
 		"         Too many extended channel devices in use.\n\n",
-		csys_argv[arg]);
+		EV(csys_argv[arg]));
 	continue;
       }
       if ((res = snd_seq_connect_from(csysi_handle,
@@ -157,7 +157,7 @@ int csys_setup(void)
 	fprintf(stderr,
 		"ALSASEQ: Warning: Could not connect"
 		"to the given address: %s\n\n",
-		csys_argv[arg]);
+		EV(csys_argv[arg]));
       }
     }
   }
