@@ -384,6 +384,7 @@ int csys_newdata(void)
     return CSYS_NONE;
 
   csysi_len = 0;
+  retry = 0;
 
   do 
     {
@@ -431,7 +432,7 @@ int csys_midievent(unsigned char * cmd,   unsigned char * ndata,
     {
       csysi_graceful_exit = CSYSI_GE_EXITED;
       *cmd = CSYS_MIDI_ENDTIME;
-      *fval = scorebeats;
+      *fval = EV(scorebeats);
       return CSYS_NONE;
     }
 
