@@ -125,7 +125,7 @@ typedef struct csysi_sevent {
   unsigned short id;
   unsigned short label;
   float fval;
-  unsigned long pnum;
+  unsigned int pnum;
   float * p;
 } csysi_sevent;
 
@@ -189,10 +189,10 @@ void csysi_readnextbyte(void)
 /******************************************************************/
 
 
-unsigned long csysi_readbit(unsigned long numbits)
+unsigned int csysi_readbit(unsigned int numbits)
 
 {
-  unsigned long ret = 0;
+  unsigned int ret = 0;
 
   while (numbits > 0)
     {
@@ -215,7 +215,7 @@ int csysi_readaccesstime()
 
 {
   int numbits = 32;
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   int retry = 0;
 
   u.l = 0;
@@ -251,7 +251,7 @@ int csysi_readaccesstime()
 /******************************************************************/
 
 
-void csysi_readflush(unsigned long numbits)
+void csysi_readflush(unsigned int numbits)
 
 {
 
@@ -398,7 +398,7 @@ void csysi_scorelineflush(void)
 void csysi_scorefileflush(void)
 
 {
-  unsigned long numlines;
+  unsigned int numlines;
 
   numlines = csysi_readbit(20);
   while (numlines > 0)
@@ -417,7 +417,7 @@ void csysi_sampleflush(void)
 
 {
 
-  unsigned long len;
+  unsigned int len;
 
   csysi_readflush(16);       /* symbol */
   len = csysi_readbit(24);   
@@ -474,7 +474,7 @@ void csysi_flushconfig(void)
 void csysi_scorelinefill(void)
 
 {
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   int sym, i, j, sampletoken, size, skip;
   csysi_sampleunit * sidx;
   csysi_sevent * cq;
@@ -683,7 +683,7 @@ void csysi_sampleread(void)
 {
   int sym, i, len;
   csysi_sampleunit * sidx, * newsamp;
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   union { unsigned short us; signed short ss ; } s;
 
   sidx = (csysi_sampleunit *) malloc(sizeof(csysi_sampleunit));
@@ -695,7 +695,7 @@ void csysi_sampleread(void)
   if (csysi_readbit(1))  /* sampling rate */
     sidx->p[len - SAMP_SR] = csysi_readbit(17);
   else
-    sidx->p[len - SAMP_SR] = ARATE;
+    sidx->p[len - SAMP_SR] = EV(ARATE);
 
   if (csysi_readbit(1))  /* loop points */
     {
@@ -984,16 +984,16 @@ void csysi_openfile(void)
 
   /* first search ./sa file command line for .mp4 file */
 
-  for (i=1;i<csys_argc; i++)
-    if (!strcmp(csys_argv[i],"-csys_fstr_file"))
+  for (i=1;i<EV(csys_argc); i++)
+    if (!strcmp(EV(csys_argv[i]),"-csys_fstr_file"))
       {
 	i++;
-	if (i == csys_argc)
+	if (i == EV(csys_argc))
 	  csys_terminate(".mp4 file not specified");
-	if (!(csysi_bitfile = fopen(csys_argv[i],"rb")))
+	if (!(csysi_bitfile = fopen(EV(csys_argv[i]),"rb")))
 	  {
-	    name = (char *) calloc(strlen(csys_argv[i])+5, sizeof(char));
-	    sprintf(name,"%s.mp4",csys_argv[i]);
+	    name = (char *) calloc(strlen(EV(csys_argv[i]))+5, sizeof(char));
+	    sprintf(name,"%s.mp4",EV(csys_argv[i]));
 	    if (!(csysi_bitfile = fopen(name,"rb")))
 	      csys_terminate(".mp4 file not found");
 	  }
@@ -1030,7 +1030,7 @@ void csysi_openfile(void)
 
   if (!(CSYS_GIVENENDTIME))
     {
-      csysi_compendtime = endtime;
+      csysi_compendtime = EV(endtime);
       if (!csysi_setendtime(CSYSI_MAXENDTIME))
 	csys_terminate("problem setting init endtime");
     }
@@ -1075,7 +1075,7 @@ int csys_newdata(void)
   found = ((i = csysi_tailsco) < 0);
   while (csysi_numscotime && !found)
     {
-      if (csysi_scoqueue[i].stime <= scorebeats)
+      if (csysi_scoqueue[i].stime <= EV(scorebeats))
 	csysi_scoready++;
       else
 	found = 1;
@@ -1088,7 +1088,7 @@ int csys_newdata(void)
   found = ((i = csysi_tailabs) < 0);
   while (csysi_numabstime && !found)
     {
-      if (csysi_absqueue[i].atime < absolutetime)
+      if (csysi_absqueue[i].atime < EV(absolutetime))
 	csysi_absready++;
       else
 	found = 1;
@@ -1101,7 +1101,7 @@ int csys_newdata(void)
   found = ((i = csysi_tailmidi) < 0);
   while (csysi_nummidi && !found)
     {
-      if (csysi_midiqueue[i].atime < absolutetime)
+      if (csysi_midiqueue[i].atime < EV(absolutetime))
 	csysi_midiready++;
       else
 	found = 1;
@@ -1166,7 +1166,7 @@ int csys_saslevent(unsigned char * cmd, unsigned char * priority,
 
   switch (*cmd = cq->cmd) {
   case CSYS_SASL_ENDTIME :  
-    *fval = scorebeats;
+    *fval = EV(scorebeats);
     break;
   case CSYS_SASL_NOOP :
   case CSYS_SASL_TEMPO : 
@@ -1267,7 +1267,7 @@ int csys_midievent(unsigned char * cmd,   unsigned char * ndata,
   *fval = csysi_midiqueue[i].fval;
 
   if (*cmd == CSYS_MIDI_ENDTIME)
-    *fval = (*fval > scorebeats + 5.0F) ? *fval : scorebeats + 5.0F;
+    *fval = (*fval > EV(scorebeats) + 5.0F) ? *fval : EV(scorebeats) + 5.0F;
 
   csysi_midiready--;
   csysi_nummidi--;
