@@ -125,6 +125,10 @@
 /* default system parameters */
 /*****************************/
 
+#ifndef EV
+#define EV(x)   x
+#endif
+
 #if defined(__APPLE__)          /* variable-length ifconf */
 #define NSYS_IFCONF_VARLEN 1
 #else
