@@ -243,7 +243,7 @@ nsys_source * nsys_netin_rtcp(unsigned char * packet, int len,
 	  }
 	else
 	  {
-	    sptr->tm_margin = nsys_lateplay ? 0 : ARATE*nsys_latetime;
+	    sptr->tm_margin = nsys_lateplay ? 0 : EV(ARATE)*nsys_latetime;
 	    sptr->tm_convert = (new_stamp - nsys_netout_tstamp -
 				sptr->tm_margin);
 	    if (NSYS_LATENOTES_DEBUG == NSYS_LATENOTES_DEBUG_ON)
@@ -882,7 +882,7 @@ void nsys_netin_rtcp_display(unsigned char * packet, int len,
 	  printf("highest sequence number received %lu\n", (unsigned long)
 		 ntohl(*((unsigned long *)
 			 &(packet[offset+NSYS_RTCPLOC_RR_HISEQ]))));
-	  printf("jitter: %f ms\n", (1000/ARATE)*(unsigned long)
+	  printf("jitter: %f ms\n", (1000/EV(ARATE))*(unsigned long)
 		 ntohl(*((unsigned long *)
 			 &(packet[offset + NSYS_RTCPLOC_RR_JITTER]))));
 
@@ -1309,7 +1309,7 @@ void nsys_late_windowcheck(nsys_source * sptr, unsigned long tstamp)
   if (sptr->tm_lateflag)
     {
       tdiff = nsys_netout_tstamp - sptr->tm_latetime;
-      if (tdiff > (unsigned long)(ARATE*NSYS_SM_LATEWINDOW))
+      if (tdiff > (unsigned long)(EV(ARATE)*NSYS_SM_LATEWINDOW))
 	{
 	  sptr->tm_lateflag = 0;
 	  sptr->tm_convert = tstamp - nsys_netout_tstamp - sptr->tm_margin;
