@@ -195,6 +195,9 @@ int nsys_setup(int block)
   /* create digest sessionname, initialize authentication key */
   /************************************************************/
 
+  if (nsys_sessionname == NULL)
+    nsys_sessionname = "test_session";
+
   nsys_msession = !strcmp(NSYS_MSESSION_NAME, nsys_sessionname);
   nsys_msessionmirror = nsys_msession && !strcmp("mirror", APPNAME);
 
