@@ -739,7 +739,7 @@ void nsys_createsip(int fd, char * method, unsigned char * sip,
 
 	/* tsmode line */
 
-	(unsigned long) ACYCLE,
+	(unsigned long) EV(ACYCLE),
 
 	/* rtp_ptime line */
 
@@ -748,7 +748,7 @@ void nsys_createsip(int fd, char * method, unsigned char * sip,
 
 	/* guardtime line */
 
-	(unsigned long)(NSYS_SM_GUARD_MAXTIME*ARATE + 0.5F)
+	(unsigned long)(NSYS_SM_GUARD_MAXTIME*EV(ARATE) + 0.5F)
 
 	);
 
