@@ -320,7 +320,7 @@ void ifoptconst(int passrate, tnode ** lptr)
       /* consider ways to handle this problem.    */
 
       if (((gptr->down->ttype == S_INTGR) &&
-	   (atol(gptr->down->val) == 0)) ||
+	   (atoi(gptr->down->val) == 0)) ||
 	  ((gptr->down->ttype == S_NUMBER) &&
 	   ((float)atof(gptr->down->val) == 0.0F)))
 	{
@@ -433,7 +433,7 @@ void ifelseoptconst(int passrate, tnode ** lptr)
   if ((gptr->vol == CONSTANT) && (iflags == 0) && (eflags == 0))
     {
       if (((gptr->down->ttype == S_INTGR) &&
-	   (atol(gptr->down->val) == 0)) ||
+	   (atoi(gptr->down->val) == 0)) ||
 	  ((gptr->down->ttype == S_NUMBER) &&
 	   ((float)atof(gptr->down->val) == 0.0F)))
 	{
@@ -594,7 +594,7 @@ void whileoptconst(int passrate, tnode ** lptr)
 
   if ((gptr->vol == CONSTANT) && 
       ( ((gptr->down->ttype == S_INTGR) &&
-	 (atol(gptr->down->val) == 0)) ||
+	 (atoi(gptr->down->val) == 0)) ||
 	((gptr->down->ttype == S_NUMBER) &&
 	 ((float)atof(gptr->down->val) == 0.0F))))
     {
@@ -787,7 +787,7 @@ int unarycollapse(int passrate, tnode * tptr)
       }
     else
       {
-	sprintf(name, "%li", - atol(t_two->down->val));
+	sprintf(name, "%i", - atoi(t_two->down->val));
 	t_two->ttype = S_INTGR;
 	t_two->res = ASINT;
       }
@@ -905,7 +905,7 @@ int multicollapse(int passrate, tnode * tptr)
   int tot = 0;
   int res = ASINT;
   float fval = 0.0F;
-  long lval = 0;
+  int lval = 0;
 
   if ((tptr->down == NULL) || (tptr->down->ttype != S_EXPR) ||
       (tptr->down->next == NULL) ||
@@ -950,7 +950,7 @@ int multicollapse(int passrate, tnode * tptr)
 
   fval = (float)atof(first->down->val);
   if (asanint)
-    lval = atol(first->down->val);
+    lval = atoi(first->down->val);
 
   if (tptr->down != first)
     {
@@ -979,17 +979,17 @@ int multicollapse(int passrate, tnode * tptr)
 	  case S_STAR:
 	    fval *= (float)atof(eptr->next->next->down->val);
 	    if (asanint)
-	      lval *= atol(eptr->next->next->down->val);
+	      lval *= atoi(eptr->next->next->down->val);
 	    break;
 	  case S_PLUS:
 	    fval += (float)atof(eptr->next->next->down->val);
 	    if (asanint)
-	      lval += atol(eptr->next->next->down->val);
+	      lval += atoi(eptr->next->next->down->val);
 	    break;
 	  case S_MINUS:
 	    fval -= (float)atof(eptr->next->next->down->val);
 	    if (asanint)
-	      lval -= atol(eptr->next->next->down->val);
+	      lval -= atoi(eptr->next->next->down->val);
 	    break;
 	  }
 	  eptr->next = eptr->next->next->next;
@@ -1011,7 +1011,7 @@ int multicollapse(int passrate, tnode * tptr)
     {
       eptr->ttype = S_INTGR;
       eptr->res = ASINT;
-      sprintf(name, "%li", lval);
+      sprintf(name, "%i", lval);
     }
   else
     {
@@ -1415,7 +1415,7 @@ void tablemapcollapse(tnode * tptr)
   if ((iptr->ttype != S_INTGR) && (iptr->ttype != S_NUMBER))
     internalerror("optconst.c", "tmapcollapse -- 1");
 
-  if ((index = make_long(iptr)) < 0)
+  if ((index = make_int(iptr)) < 0)
     {
       printf("Error: Tablemap constant index is negative.\n\n");
       showerrorplace(tptr->down->next->linenum, tptr->down->next->filename);
