@@ -758,12 +758,19 @@ void globalrefer(sigsym * iptr)
 		}
 	    }
 
+	  /* update global variable access info */
+
+	  if (((sptr->kind == K_IMPORT) || (sptr->kind == K_IMPORTEXPORT)) 
+	      && sptr->tref->accesstot && 
+	      ((!skip) || (sptr->tref->accessrate == KRATETYPE) ||
+	       (sptr->tref->accessrate == ARATETYPE)))
+	      gptr->tref->accesstot++;
+
 	  /* update local variable status */
 
 	  sptr->tref->totimport = gptr->tref->totimport;
 	  sptr->tref->totexport = gptr->tref->totexport;
 	  sptr->tref->dynaccess = gptr->tref->dynaccess;
-
 	}
 	
       sptr = sptr->next;
