@@ -160,7 +160,6 @@ void globalparamcheck(void)
 
 {
   int i, driver_srate, driver_inchannels;
-  int old_krate = -1;
 
   if ((srate < 0) || (inchannels < 0))
     {
@@ -178,9 +177,6 @@ void globalparamcheck(void)
 	srate = (driver_srate > 0) ? driver_srate : 32000;
     }
 
-  if (krate < 0)
-    krate = 100;
-
   if (outchannels <= 0)
     {
       if (outchannels == 0)
@@ -194,20 +190,23 @@ void globalparamcheck(void)
     if (interp < 0)
       interp = INTERP_LINEAR;   /* SA default is linear interpolation */
 
+  if (krate < 0)
+    krate = 100;
+
   if (krate > srate)
     {
       printf("Error: Global parameter krate > srate.\n");
       noerrorplace();
     }
-  if (srate % krate)
-    {
-      old_krate = krate;
-      while (srate % (++krate));
-    }
 
-  if (old_krate > 0)
+  saol_krate = krate;
+
+  if (srate % krate)
+    while (srate % (++krate));
+
+  if (saol_krate != krate)
     printf("Warning: krate changed from %i to %i to evenly divide srate.\n",
-	   old_krate, krate);
+	   saol_krate, krate);
 
   /* computes next power of two above acycle, < 8192 */
 
@@ -643,7 +642,7 @@ void mainscoreread(void)
 	  if (sstrmidi->midinumchan > 16)
 	    {
 	      printf("Warning: Too many -mstr MIDI channels, using\n");
-	      printf("         first 16 out of %li\n\n",sstrmidi->midinumchan);
+	      printf("         first 16 out of %i\n\n",sstrmidi->midinumchan);
 	    }
 	}
     }
