@@ -765,7 +765,7 @@ void endnote(midata * mdata, unsigned int chan, unsigned int note)
 void midicleanup(midata * mdata)
 
 {
-  int i, j, k;
+  volatile int i, j, k;   /* avoid gcc 4.2.1 optimizer bug */
 
   for (i = 0; i < MCHAN; i++)
     for (j = 0; j < MNOTE; j++)
