@@ -553,27 +553,137 @@ void initendtime(void)
   fprintf(outfile,"#define MAXENDTIME 1E+37\n\n");
 
   if (abssasl->endtimeval)
-    fprintf(outfile,"int endkinit = %i;\n", 2 + (int)
+    fprintf(outfile,"int endkinit;\n");
+
+  if (allsasl->endtimeval || abssasl->endtimeval)
+    fprintf(outfile,"float endtime;\n");
+  else
+    internalerror("readscore.c", "initendtime tail");
+}
+
+/*************************************************************/
+/* initialize endkinit and endtime. prints in engine_init() */
+/*************************************************************/
+
+void initendtimeassign(void)
+
+{
+  if (abssasl->endtimeval)
+    fprintf(outfile,"  EV(endkinit) = %i;\n", 2 + (int)
 	    (krate*atof(abssasl->endtimeval)));
 
   if (allsasl->endtimeval)
-    fprintf(outfile,"float endtime = %sF;\n",allsasl->endtimeval);
+    fprintf(outfile,"  EV(endtime) = %sF;\n",allsasl->endtimeval);
   else
     {
       if (abssasl->endtimeval)
-	fprintf(outfile,"float endtime = %fF;\n", 
+	fprintf(outfile,"  EV(endtime) = %fF;\n", 
 		(1.0F/krate)*((2 + (int)(krate*atof(abssasl->endtimeval)))));
       else 
 	internalerror("readscore.c", "initendtime tail");
     }
+  fprintf(outfile,"\n");
+}
+
+
+/*********************************************************/
+/*       declarations for the score instr variables      */
+/*********************************************************/
+
+void initscoreinstr(int type, sigsym * sptr)
+
+{
+  int score;
+  char * prefix;
+  char * val;
+
+  if (type == RELTSTAMP)
+    {
+      if (!( allsasl->instrroot))
+	return;
+      prefix = "s";
+      score = sptr->score;
+    }
+  else
+    {
+      if (!(abssasl->instrroot))
+	return;
+      prefix = "sa";
+      score = sptr->ascore;
+    }
+
+  fprintf(outfile,"instr_line %s_%s[%i];\n",prefix,sptr->val, score);
+
+  if ((score > 1) || csasl)
+    {
+      val = dupunderscore(sptr->val);
+      fprintf(outfile,"instr_line * %s_%sfirst;\n", prefix, val);
+      fprintf(outfile,"instr_line * %s_%slast;\n", prefix, val);
+      fprintf(outfile,"instr_line * %s_%send;\n\n", prefix,val);
+      free(val);
+    }
 
 }
 
 /*********************************************************/
-/*     initializes score instr variables             */
+/*   engine_init() assignments for instr variables      */
 /*********************************************************/
 
-void initscoreinstr(int type, sigsym * sptr)
+void initscoreinstrassign(int type, sigsym * sptr)
+
+{
+  int i, score;
+  tnode * tptr;
+  char * prefix;
+  char * val;
+
+  if (type == RELTSTAMP)
+    {
+      if (!(tptr = allsasl->instrroot))
+	return;
+      prefix = "s";
+      score = sptr->score;
+    }
+  else
+    {
+      if (!(tptr = abssasl->instrroot))
+	return;
+      prefix = "sa";
+      score = sptr->ascore;
+    }
+
+  fprintf(outfile,"  memcpy(EV(%s_%s), %s_%s_init, sizeof EV(%s_%s));\n",
+	  prefix, sptr->val, prefix, sptr->val, prefix, sptr->val);
+
+  i = -1;
+  while (tptr != NULL)
+    {
+      if (tptr->sptr == sptr)
+	{
+	  i++;
+	}
+      tptr= tptr->next;
+    }
+
+  if ((score > 1) || csasl)
+    {
+      val = dupunderscore(sptr->val);
+      fprintf(outfile,"  EV(%s_%sfirst) = &EV(%s_%s)[0];\n",
+	      prefix,val,prefix,sptr->val);
+      fprintf(outfile,"  EV(%s_%slast) = &EV(%s_%s)[0];\n",
+	      prefix,val,prefix,sptr->val);
+      fprintf(outfile,"  EV(%s_%send) = &EV(%s_%s)[%i];\n\n",
+	      prefix,val,prefix,sptr->val,i);
+      free(val);
+    }
+}
+
+
+/*********************************************************/
+/* declare and init true constant vars for score instrs  */
+/*********************************************************/
+
+void initscoreinstrconstant(int type, sigsym * sptr)
 
 {
 
@@ -581,7 +691,6 @@ void initscoreinstr(int type, sigsym * sptr)
   tnode * tptr;
   tnode * pvalptr;
   char * prefix;
-  char * val;
   sigsym * label;
 
   if (type == RELTSTAMP)
@@ -599,7 +708,7 @@ void initscoreinstr(int type, sigsym * sptr)
       score = sptr->ascore;
     }
 
-  fprintf(outfile,"struct instr_line %s_%s[%i] = {\n",prefix,sptr->val,
+  fprintf(outfile,"instr_line %s_%s_init[%i] = {\n",prefix,sptr->val,
 	  score);
 
   i = -1;
@@ -683,22 +792,11 @@ void initscoreinstr(int type, sigsym * sptr)
     }
   fprintf(outfile,"};\n\n");
 
-  if ((score > 1) || csasl)
-    {
-      val = dupunderscore(sptr->val);
-      fprintf(outfile,"struct instr_line * %s_%sfirst = &%s_%s[0];\n",
-	      prefix,val,prefix,sptr->val);
-      fprintf(outfile,"struct instr_line * %s_%slast = &%s_%s[0];\n",
-	      prefix,val,prefix,sptr->val);
-      fprintf(outfile,"struct instr_line * %s_%send = &%s_%s[%i];\n\n",
-	      prefix,val,prefix,sptr->val,i);
-      free(val);
-    }
-
 }
 
+
 /*********************************************************/
-/*       initializes score control variables             */
+/*       declarations for the score control variables    */
 /*********************************************************/
 
 void initscorecontrol(int type)
@@ -706,10 +804,8 @@ void initscorecontrol(int type)
 {
   char * prefix;
   sasdata * sdata;
-  int i;
   tnode * tptr;
   tnode * lptr;
-  sigsym * sptr; 
   sigsym * psptr;
   sigsym * label;
 
@@ -762,7 +858,155 @@ void initscorecontrol(int type)
   if (sdata->numcontrol == 0)
     return;
 
-  fprintf(outfile, "struct scontrol_lines %scontrol[%i] = {\n", 
+  fprintf(outfile, "scontrol_lines %scontrol[%i];\n", prefix, sdata->numcontrol);
+  fprintf(outfile, "scontrol_lines * %scontrolidx;\n", prefix);
+  fprintf(outfile, "scontrol_lines * end%scontrol;\n\n", prefix);
+}
+
+/*********************************************************/
+/*   content_init() assignments for control variables    */
+/*********************************************************/
+
+void initscorecontrolassign(int type)
+
+{
+  char * prefix;
+  sasdata * sdata;
+  sigsym * sptr; 
+  tnode * tptr;
+  tnode * lptr;
+  sigsym * psptr;
+  sigsym * label;
+  int i;
+
+  if (type == RELTSTAMP)
+    {
+      sdata = allsasl;
+      prefix = "s";
+    }
+  else
+    {
+      sdata = abssasl;
+      prefix = "sa";
+    }
+
+  if (sdata->numcontrol == 0)
+    return;
+
+  fprintf(outfile,"  memcpy(EV(%scontrol), %scontrol_init, sizeof EV(%scontrol));\n",
+	  prefix, prefix, prefix);
+
+  i = 0;
+  tptr = sdata->controlroot;
+  while (tptr != NULL)
+    {
+      if (tptr->ttype == S_LCONTROL)
+	{
+
+	  label = getsym(&(allsasl->labeltable), tptr->down->next);
+	  if (label == NULL)
+	    {
+	      printf("Error: Unknown score label %s.\n",tptr->down->next->val);
+	      showbadline(tptr->down);
+	    }
+	  lptr = label->defnode;
+	  while (lptr != NULL)
+	    {
+	      sptr = lptr->down->sptr; 
+	      psptr = getsym(&(lptr->down->sptr->defnode->sptr),
+			     tptr->down->next->next->next);
+	      if ((psptr != NULL) && (psptr->kind == K_IMPORT))
+		{
+		  fprintf(outfile, "  EV(%scontrol)[%i].iline = &EV(%s_%s)[%i];\n", 
+			  prefix, i, prefix, sptr->val, 
+			  lptr->down->arrayidx);
+		  i++;
+		}
+	      lptr = lptr->next;
+	    }
+	}
+      else
+	{
+	  psptr = getsym(&globalsymtable,tptr->down->next->next);
+	  if ((psptr != NULL) ||
+	      (!strcmp("MIDIctrl",tptr->down->next->next->val)) ||
+	      (!strcmp("MIDIbend",tptr->down->next->next->val)) ||
+	      (!strcmp("MIDItouch",tptr->down->next->next->val)) )
+	    i++;
+	}
+      tptr = tptr->next;
+    }
+
+  fprintf(outfile, "  EV(%scontrolidx) = &EV(%scontrol)[0];\n", prefix, prefix);
+  fprintf(outfile, "  EV(end%scontrol) = &EV(%scontrol)[%i];\n\n",
+	  prefix, prefix, sdata->numcontrol-1);
+}
+
+/*********************************************************/
+/* declare and init true constant vars for score control */
+/*********************************************************/
+
+void initscorecontrolconstant(int type)
+
+{
+  char * prefix;
+  sasdata * sdata;
+  int i;
+  tnode * tptr;
+  tnode * lptr;
+  sigsym * psptr;
+  sigsym * label;
+
+  if (type == RELTSTAMP)
+    {
+      sdata = allsasl;
+      prefix = "s";
+    }
+  else
+    {
+      sdata = abssasl;
+      prefix = "sa";
+    }
+
+  sdata->numcontrol = 0;
+  tptr = sdata->controlroot;
+  while (tptr != NULL)
+    {
+      if (tptr->ttype == S_LCONTROL)
+	{
+
+	  label = getsym(&(allsasl->labeltable), tptr->down->next);
+	  if (label == NULL)
+	    {
+	      printf("Error: Unknown score label %s.\n",tptr->down->next->val);
+	      showbadline(tptr->down);
+	    }
+	  lptr = label->defnode;
+	  while (lptr != NULL)
+	    {
+	      psptr = getsym(&(lptr->down->sptr->defnode->sptr),
+			     tptr->down->next->next->next);
+	      if ((psptr != NULL) && (psptr->kind == K_IMPORT))
+		sdata->numcontrol++;
+	      lptr = lptr->next;
+	    }
+	}
+      else
+	{
+	  psptr = getsym(&globalsymtable,tptr->down->next->next);
+	  if ((psptr != NULL) ||
+	      (!strcmp("MIDIctrl",tptr->down->next->next->val)) ||
+	      (!strcmp("MIDIbend",tptr->down->next->next->val)) ||
+	      (!strcmp("MIDItouch",tptr->down->next->next->val)) )
+	    sdata->numcontrol++;
+	}
+      tptr = tptr->next;
+    }
+
+  if (sdata->numcontrol == 0)
+    return;
+
+  fprintf(outfile, "scontrol_lines %scontrol_init[%i] = {\n", 
 	  prefix, sdata->numcontrol);
   i = -1;
   tptr = sdata->controlroot;
@@ -775,7 +1019,6 @@ void initscorecontrol(int type)
 	  lptr = label->defnode;
 	  while (lptr != NULL)
 	    {
-	      sptr = lptr->down->sptr; 
 	      psptr = getsym(&(lptr->down->sptr->defnode->sptr),
 			     tptr->down->next->next->next);
 	      if ((psptr != NULL) && (psptr->kind == K_IMPORT))
@@ -784,14 +1027,13 @@ void initscorecontrol(int type)
 		  if (i != 0)
 		    fprintf(outfile,",\n");
 		  fprintf(outfile,"{");
-		  fprintf(outfile," %sF,", tptr->val);            /* t */
-		  fprintf(outfile," %i,", label->special + 1);    /* label */
+		  fprintf(outfile," %sF,", tptr->val);           /* t */
+		  fprintf(outfile," %i,", label->special + 1);   /* label */
 		  fprintf(outfile," %i, ",lptr->down->arrayidx); /* siptr */
-		  fprintf(outfile," &%s_%s[%i], ",                /* iline */
-			  prefix, sptr->val,lptr->down->arrayidx);
-		  fprintf(outfile," %s_%s, ",                    /* imptr */
+		  fprintf(outfile," NULL, ");                    /* iline */
+		  fprintf(outfile,"%s_%s, ",                    /* imptr */
 			  lptr->down->sptr->val,psptr->val);
-		  fprintf(outfile," %sF ",                        /* imval */
+		  fprintf(outfile,"%sF ",                       /* imval */
 			  tptr->down->next->next->next->next->val);
 		  fprintf(outfile,"}");
 		}
@@ -844,22 +1086,77 @@ void initscorecontrol(int type)
       tptr = tptr->next;
     }
 
-  fprintf(outfile,"\n};\n");
-  fprintf(outfile, "struct scontrol_lines * %scontrolidx = &%scontrol[0];\n",
-	  prefix, prefix);
-  fprintf(outfile,
-	  "struct scontrol_lines * end%scontrol = &%scontrol[%i];\n\n",
-	  prefix, prefix, sdata->numcontrol-1);
-
-
+  fprintf(outfile,"\n};\n\n");
 }
 
+
 /*********************************************************/
-/*       initializes score tempo variables             */
+/*       declarations for the score tempo variables      */
 /*********************************************************/
 
 void initscoretempo(int type)
 
+{
+  char * prefix;
+
+  if (type == RELTSTAMP)
+    {
+      if (!(allsasl->temporoot))
+	return;
+      prefix = "s";
+    }
+  else
+    {
+      if (!(abssasl->temporoot))
+	return;
+      prefix = "sa";
+    }
+  
+  fprintf(outfile,"int end%stempo;\n", prefix);
+  fprintf(outfile,"int %stempoidx;\n\n", prefix);
+}
+
+/*********************************************************/
+/*   content_init() assignments for the tempo variables  */
+/*********************************************************/
+
+void initscoretempoassign(int type)
+
+{
+  char * prefix;
+  tnode * tptr;
+  int i;
+  
+  if (type == RELTSTAMP)
+    {
+      if (!(tptr = allsasl->temporoot))
+	return;
+      prefix = "s";
+    }
+  else
+    {
+      if (!(tptr = abssasl->temporoot))
+	return;
+      prefix = "sa";
+    }
+
+  i = 0;
+  while (tptr != NULL)
+    {
+      i++;
+      tptr = tptr->next;
+    }
+  
+  fprintf(outfile,"  EV(end%stempo) = %i;\n",prefix,i-1);
+}
+
+
+/*********************************************************/
+/* declare and init "true constant" vars for score tempo */
+/*********************************************************/
+
+void initscoretempoconstant(int type)
+
 {
   char * prefix;
   int i,  numtempo;
@@ -881,8 +1178,7 @@ void initscoretempo(int type)
       prefix = "sa";
     }
 
-  fprintf(outfile,
-	      "struct stempo_lines %stempo[%i] = {\n", prefix, numtempo + 1);
+  fprintf(outfile, "stempo_lines %stempo[%i] = {\n", prefix, numtempo + 1);
 
   i = 0;
   while (tptr != NULL)
@@ -895,17 +1191,74 @@ void initscoretempo(int type)
       tptr = tptr->next;
     }
   fprintf(outfile,"};\n\n");
-  
-  fprintf(outfile,"int end%stempo = %i;\n",prefix,i-1);
-  fprintf(outfile,"int %stempoidx = 0;\n\n",prefix);
-
 }
 
 /*********************************************************/
-/*       initializes score table variables             */
+/*       declarations for the score table variables      */
 /*********************************************************/
 
-void initscoretable(int type)
+void initscoretablevars(int type)
+
+{
+  char * prefix;
+
+  if (type == RELTSTAMP)
+    {
+      if (!(allsasl->tableroot))
+	return;
+      prefix = "s";
+    }
+  else
+    {
+      if (!(abssasl->tableroot))
+	return;
+      prefix = "sa";
+    }
+
+  fprintf(outfile,"int end%stable;\n\n", prefix);
+  fprintf(outfile,"int %stableidx;\n\n", prefix);
+}  
+
+/*********************************************************/
+/*   content_init() assignments for the table variables  */
+/*********************************************************/
+
+void initscoretableassign(int type)
+
+{
+  int i;
+  tnode * tptr;
+  char * prefix;
+
+  if (type == RELTSTAMP)
+    {
+      if (!(tptr = allsasl->tableroot))
+	return;
+      prefix = "s";
+    }
+  else
+    {
+      if (!(tptr = abssasl->tableroot))
+	return;
+      prefix = "sa";
+    }
+
+  i = 0;
+  while (tptr != NULL)
+    {
+      i++;
+      tptr = tptr->next;
+    }
+
+  fprintf(outfile,"  EV(end%stable) = %i;\n\n",prefix,i-1);
+}  
+
+
+/*********************************************************/
+/* declare and init true constant vars for score tables  */
+/*********************************************************/
+
+void initscoretableconstant(int type)
 
 {
   int i, numtable;
@@ -928,18 +1281,7 @@ void initscoretable(int type)
       prefix = "sa";
     }
 
-  i = 0;
-  while (i < numtable)
-    {
-      fprintf(outfile, "void score_%stable%i(void);", prefix,i);
-      fprintf(outfile, "extern %s score_%stdata%i[];", 
-	      hexstrings ? "char" : "float", prefix, i);
-      fprintf(outfile, "\n");
-      i++;
-    }
-  fprintf(outfile, "\n");
-
-  fprintf(outfile,"struct stable_lines %stable[%i] = {\n", 
+  fprintf(outfile,"stable_lines %stable[%i] = {\n", 
 	  prefix, numtable+1);
 
   i = 0;
@@ -966,9 +1308,45 @@ void initscoretable(int type)
       tptr = tptr->next;
     }
   fprintf(outfile,"};\n\n");
-  fprintf(outfile,"int end%stable = %i;\n\n",prefix,i-1);
-  fprintf(outfile,"int %stableidx = 0;\n\n",prefix);
+}  
 
+
+/*********************************************************/
+/*       initializes score table externs             */
+/*********************************************************/
+
+void initscoretableexterns(int type)
+
+{
+  int i, numtable;
+  tnode * tptr;
+  char * prefix;
+
+  if (type == RELTSTAMP)
+    {
+      if (!(tptr = allsasl->tableroot))
+	return;
+      numtable = allsasl->numtable;
+      prefix = "s";
+    }
+  else
+    {
+      if (!(tptr = abssasl->tableroot))
+	return;
+      numtable = abssasl->numtable;
+      prefix = "sa";
+    }
+
+  i = 0;
+  while (i < numtable)
+    {
+      fprintf(outfile, "extern void score_%stable%i(ENGINE_PTR_TYPE);\n", prefix,i);
+      fprintf(outfile, "extern %s score_%stdata%i[];\n", 
+	      hexstrings ? "char" : "float", prefix, i);
+      fprintf(outfile, "\n");
+      i++;
+    }
+  fprintf(outfile, "\n");
 }  
 
 
@@ -1004,7 +1382,7 @@ void printtablefunctions(void)
 	}
       else
 	{
-	  fprintf(outfile,"\n\nvoid score_stable%i(void)\n{\n\n",i);
+	  fprintf(outfile,"\n\nvoid score_stable%i(ENGINE_PTR_DECLARE)\n{\n\n",i);
 	  if (wavegeneratorname(tptr->down->next->next->next))
 	    {
 	      wavegeneratorvar(tptr->sptr);
@@ -1029,7 +1407,7 @@ void printtablefunctions(void)
 	}
       else
 	{
-	  fprintf(outfile,"\n\nvoid score_satable%i(void)\n{\n\n",i);
+	  fprintf(outfile,"\n\nvoid score_satable%i(ENGINE_PTR_DECLARE)\n{\n\n",i);
 	  if (wavegeneratorname(tptr->down->next->next->next))
 	    {
 	      wavegeneratorvar(tptr->sptr);
