@@ -1147,7 +1147,7 @@ int oneparamflags(char * s1, char * s2)
 
       au_manu_url = dupval(s2);
 
-      if ((sptr = strcasestr(au_manu_url, ".audiounit")))
+      if ((sptr = strstr(au_manu_url, ".audiounit")))
 	*sptr = '\0';
 
       return 1;
@@ -1190,7 +1190,7 @@ int oneparamflags(char * s1, char * s2)
 
       au_view_bundlename = dupval(s2);
 
-      if ((sptr = strcasestr(au_view_bundlename, ".bundle")))
+      if ((sptr = strstr(au_view_bundlename, ".bundle")))
 	*sptr = '\0';
 
       return 1;
