@@ -524,7 +524,7 @@ int standardcollapse(tnode * ident)
 {
   char name[128];
 
-  if (!(strcmp(ident->val,"k_rate")))
+  if ((!(strcmp(ident->val,"k_rate"))) && (!reentrant))
     {
       ident->vol   = CONSTANT;
       ident->ttype = S_INTGR;
@@ -534,7 +534,7 @@ int standardcollapse(tnode * ident)
       ident->val = dupval(name);
       return CONSTANT;
     }
-  if (!(strcmp(ident->val,"s_rate")))
+  if ((!(strcmp(ident->val,"s_rate"))) && (!reentrant))
     {
       ident->vol   = CONSTANT;
       ident->ttype = S_INTGR;
@@ -659,9 +659,9 @@ void constbus(tnode ** ident, int group)
   tnode * bptr = currinstance->ibus;
   int i = 0;
   int gcount = 1;
-  long idxval;
+  int idxval;
 
-  if ((idxval = make_long(tptr->next->next->down)) < 0)
+  if ((idxval = make_int(tptr->next->next->down)) < 0)
     {	
       printf("Error: %s[] constant index < 0.\n\n", tptr->val);
       showerrorplace(tptr->linenum, tptr->filename);
@@ -674,7 +674,7 @@ void constbus(tnode ** ident, int group)
 	  if (group)
 	    fprintf(outfile," %i ",gcount);
 	  else
-	    fprintf(outfile," %s(BUS_%s + %li)", inputbusmacro(),
+	    fprintf(outfile," %s(BUS_%s + %i)", inputbusmacro(),
 		    bptr->val, idxval - i);
 	  *ident = tptr->next->next->next;
 	  return;
@@ -791,24 +791,24 @@ void printaudiobiffarray(tnode * tptr, tnode ** ident)
 
   if (tptr->next == NULL)  /* unindexed array */
     {
-      fprintf(outfile," %s[%i] ", tptr->val, currarrayindex);
+      fprintf(outfile," EV(%s[%i]) ", tptr->val, currarrayindex);
     }
   else                    /* indexed array */
     {
       currintstack = currintprint;
-      fprintf(outfile," %s[", tptr->val);
+      fprintf(outfile," EV(%s[", tptr->val);
       if (tptr->next->next->res == ASINT)
 	{
 	  currintprint = ASINT;
 	  blocktree(tptr->next->next->down, PRINTTOKENS);
-	  fprintf(outfile," ] ");
+	  fprintf(outfile," ]) ");
 	}
       else
 	{
 	  currintprint = ASFLOAT;
 	  fprintf(outfile, " (int)(0.5F + (");
 	  blocktree(tptr->next->next->down, PRINTTOKENS);
-	      fprintf(outfile," ))] ");
+	      fprintf(outfile," ))]) ");
 	}
       *ident = tptr->next->next->next;  /* skip to end  */
       currintprint = currintstack;
@@ -833,18 +833,38 @@ void printstandardname(tnode ** ident)
     return;
   if (!(strcmp(tptr->val,"k_rate")))
     {
-      if (currintprint == ASFLOAT)
-	fprintf(outfile," %i.0F ", krate);
+      if (reentrant)
+	{
+	  if (currintprint == ASFLOAT)
+	    fprintf(outfile," EV(KRATE) ");
+	  else
+	    fprintf(outfile," ((int)(EV(KRATE))) ");
+	}
       else
-	fprintf(outfile," %i ", krate);
+	{
+	  if (currintprint == ASFLOAT)
+	    fprintf(outfile," %i.0F ", krate);
+	  else
+	    fprintf(outfile," %i ", krate);
+	}
       return;
     }
   if (!(strcmp(tptr->val,"s_rate")))
     {
-      if (currintprint == ASFLOAT)
-	fprintf(outfile," %i.0F ", srate);
+      if (reentrant)
+	{
+	  if (currintprint == ASFLOAT)
+	    fprintf(outfile," EV(ARATE) ");
+	  else
+	    fprintf(outfile," ((int)(EV(ARATE))) ");
+	}
       else
-	fprintf(outfile," %i ", srate);
+	{
+	  if (currintprint == ASFLOAT)
+	    fprintf(outfile," %i.0F ", srate);
+	  else
+	    fprintf(outfile," %i ", srate);
+	}
       return;
     }
   if (!(strcmp(tptr->val,"inchan")))
@@ -916,7 +936,7 @@ void printstandardname(tnode ** ident)
 	    fprintf(outfile," NG(%i*NS(iline->numchan) + %i + %i) ",
 		    MIDIFRAMELEN,MIDICTRLPOS,currarrayindex);
 	  else
-	    fprintf(outfile," fakeMIDIctrl[%i] ", currarrayindex);
+	    fprintf(outfile," EV(fakeMIDIctrl[%i]) ", currarrayindex);
 	}
       else                    /* indexed array */
 	{
@@ -926,7 +946,7 @@ void printstandardname(tnode ** ident)
 	    fprintf(outfile," NG(%i*NS(iline->numchan) + %i + ",
 		    MIDIFRAMELEN,MIDICTRLPOS);
 	  else
-	    fprintf(outfile," fakeMIDIctrl[( ");
+	    fprintf(outfile," EV(fakeMIDIctrl[( ");
 
 	  if (tptr->next->next->res == ASINT)
 	    {
@@ -943,7 +963,7 @@ void printstandardname(tnode ** ident)
 	    }
 
 	  if (!totmidichan)
-	    fprintf(outfile, " ] ");
+	    fprintf(outfile, " ]) ");
 
 	  *ident = tptr->next->next->next;  /* skip to end  */
 	  currintprint = currintstack;
@@ -1036,7 +1056,7 @@ void printstandardname(tnode ** ident)
     }
   if (!(strcmp(tptr->val,"cpuload")))
     {
-      fprintf(outfile," cpuload ");
+      fprintf(outfile," EV(cpuload) ");
       return;
     }
   if (!(strcmp(tptr->val,"position")))
@@ -1118,9 +1138,9 @@ void printdurassign(void)
 	{
 	  fprintf(outfile,"   ((NS(iline->sdur) < 0.0F) ? -1.0F :\n");
 	  fprintf(outfile,"   (NS(iline->abstime) + \n");
-	  fprintf(outfile,"   (kcycleidx-1)*KTIME - NS(iline->time) + \n");
-	  fprintf(outfile,"   POS((60/tempo)*(NS(iline->endtime) - \n");
-	  fprintf(outfile,"   scorebeats))));\n\n");
+	  fprintf(outfile,"   (EV(kcycleidx)-1)*EV(KTIME) - NS(iline->time) + \n");
+	  fprintf(outfile,"   POS((60/EV(tempo))*(NS(iline->endtime) - \n");
+	  fprintf(outfile,"   EV(scorebeats)))));\n\n");
 	}
     }
 }
