@@ -192,23 +192,27 @@ void redefglobal(void)
   fprintf(outfile,"#undef NS\n");
   fprintf(outfile,"#define NS(x) 0\n");
   fprintf(outfile,"#undef NSP\n");
-  fprintf(outfile,"#define NSP NULL\n");
+  fprintf(outfile,"#define NSP  ENGINE_PTR_COMMA NULL\n");
   fprintf(outfile,"#undef NT\n");
-  fprintf(outfile,"#define NT(x)  gtables[x]\n");
+  fprintf(outfile,"#define NT(x)  EV(gtables)[x]\n");
   fprintf(outfile,"#undef NV\n");
-  fprintf(outfile,"#define NV(x)  global[x].f\n");
+  fprintf(outfile,"#define NV(x)  EV(global)[x].f\n");
   fprintf(outfile,"#undef NVI\n");
-  fprintf(outfile,"#define NVI(x)  global[x].i\n");
+  fprintf(outfile,"#define NVI(x)  EV(global)[x].i\n");
   fprintf(outfile,"#undef NVUI\n");
-  fprintf(outfile,"#define NVUI(x)  global[x].ui\n");
+  fprintf(outfile,"#define NVUI(x)  EV(global)[x].ui\n");
+  fprintf(outfile,"#undef NVPS\n");
+  fprintf(outfile,"#define NVPS(x)  EV(global)[x].ps\n");
   fprintf(outfile,"#undef NVU\n");
-  fprintf(outfile,"#define NVU(x)  global[x]\n");
+  fprintf(outfile,"#define NVU(x)  EV(global)[x]\n");
   fprintf(outfile,"#undef NP\n");
-  fprintf(outfile,"#define NP(x)  global[x].f\n");
+  fprintf(outfile,"#define NP(x)  EV(global)[x].f\n");
   fprintf(outfile,"#undef NPI\n");
-  fprintf(outfile,"#define NPI(x)  global[x].i\n");
+  fprintf(outfile,"#define NPI(x)  EV(global)[x].i\n");
   fprintf(outfile,"#undef NPUI\n");
-  fprintf(outfile,"#define NPUI(x)  global[x].ui\n");
+  fprintf(outfile,"#define NPUI(x)  EV(global)[x].ui\n");
+  fprintf(outfile,"#undef NPPS\n");
+  fprintf(outfile,"#define NPPS(x)  EV(global)[x].ps\n");
   fprintf(outfile,"\n");
 }
 
@@ -224,7 +228,7 @@ void redefnormal(void)
   fprintf(outfile,"#undef NS\n");
   fprintf(outfile,"#define NS(x) nstate->x\n");
   fprintf(outfile,"#undef NSP\n");
-  fprintf(outfile,"#define NSP nstate\n");
+  fprintf(outfile,"#define NSP  ENGINE_PTR_COMMA nstate\n");
   fprintf(outfile,"#undef NT\n");
   fprintf(outfile,"#define NT(x)  nstate->t[x]\n");
   fprintf(outfile,"#undef NV\n");
@@ -233,6 +237,8 @@ void redefnormal(void)
   fprintf(outfile,"#define NVI(x)  nstate->v[x].i\n");
   fprintf(outfile,"#undef NVUI\n");
   fprintf(outfile,"#define NVUI(x)  nstate->v[x].ui\n");
+  fprintf(outfile,"#undef NVPS\n");
+  fprintf(outfile,"#define NVPS(x)  nstate->v[x].ps\n");
   fprintf(outfile,"#undef NVU\n");
   fprintf(outfile,"#define NVU(x)  nstate->v[x]\n");
   fprintf(outfile,"#undef NP\n");
@@ -241,6 +247,8 @@ void redefnormal(void)
   fprintf(outfile,"#define NPI(x)  nstate->v[x].i\n");
   fprintf(outfile,"#undef NPUI\n");
   fprintf(outfile,"#define NPUI(x)  nstate->v[x].ui\n");
+  fprintf(outfile,"#undef NPPS\n");
+  fprintf(outfile,"#define NPPS(x)  nstate->v[x].ps\n");
   fprintf(outfile,"\n");
 }
 
@@ -254,25 +262,29 @@ void redefstatic(int i)
 {
   fprintf(outfile,"\n");
   fprintf(outfile,"#undef NS\n");
-  fprintf(outfile,"#define NS(x)  ninstr[%i].x\n",i);
+  fprintf(outfile,"#define NS(x)  EV(ninstr)[%i].x\n",i);
   fprintf(outfile,"#undef NSP\n");
-  fprintf(outfile,"#define NSP  /* void */\n");
+  fprintf(outfile,"#define NSP  ENGINE_PTR \n");
   fprintf(outfile,"#undef NT\n");
-  fprintf(outfile,"#define NT(x)  ninstr[%i].t[x]\n",i);
+  fprintf(outfile,"#define NT(x)  EV(ninstr)[%i].t[x]\n",i);
   fprintf(outfile,"#undef NV\n");
-  fprintf(outfile,"#define NV(x)  ninstr[%i].v[x].f\n",i);
+  fprintf(outfile,"#define NV(x)  EV(ninstr)[%i].v[x].f\n",i);
   fprintf(outfile,"#undef NVI\n");
-  fprintf(outfile,"#define NVI(x)  ninstr[%i].v[x].i\n",i);
+  fprintf(outfile,"#define NVI(x)  EV(ninstr)[%i].v[x].i\n",i);
   fprintf(outfile,"#undef NVUI\n");
-  fprintf(outfile,"#define NVUI(x)  ninstr[%i].v[x].ui\n",i);
+  fprintf(outfile,"#define NVUI(x)  EV(ninstr)[%i].v[x].ui\n",i);
+  fprintf(outfile,"#undef NVPS\n");
+  fprintf(outfile,"#define NVPS(x)  EV(ninstr)[%i].v[x].ps\n",i);
   fprintf(outfile,"#undef NVU\n");
-  fprintf(outfile,"#define NVU(x)  ninstr[%i].v[x]\n",i);
+  fprintf(outfile,"#define NVU(x)  EV(ninstr)[%i].v[x]\n",i);
   fprintf(outfile,"#undef NP\n");
-  fprintf(outfile,"#define NP(x)  ninstr[%i].v[x].f\n",i);
+  fprintf(outfile,"#define NP(x)  EV(ninstr)[%i].v[x].f\n",i);
   fprintf(outfile,"#undef NPI\n");
-  fprintf(outfile,"#define NPI(x)  ninstr[%i].v[x].i\n",i);
+  fprintf(outfile,"#define NPI(x)  EV(ninstr)[%i].v[x].i\n",i);
   fprintf(outfile,"#undef NPUI\n");
-  fprintf(outfile,"#define NPUI(x)  ninstr[%i].v[x].ui\n",i);
+  fprintf(outfile,"#define NPUI(x)  EV(ninstr)[%i].v[x].ui\n",i);
+  fprintf(outfile,"#undef NPPS\n");
+  fprintf(outfile,"#define NPPS(x)  EV(ninstr)[%i].v[x].ps\n",i);
   fprintf(outfile,"\n");
 }
 
@@ -337,10 +349,11 @@ void printopcall(tnode * tptr)
   /*  function header */
 
   if (currinstance == NULL)
-    fprintf(outfile,"\n\n%s %s%s(struct ninstr_types * nstate)\n{\n",
+    fprintf(outfile,"\n\n%s %s%s(ENGINE_PTR_DECLARE_COMMA " 
+	    "struct ninstr_types * nstate)\n{\n",
 	    retvartype, newname, specfix);
   else
-    fprintf(outfile,"\n\n%s %s%s(void)\n{\n", retvartype,newname,specfix);
+    fprintf(outfile,"\n\n%s %s%s(ENGINE_PTR_DECLARE)\n{\n", retvartype,newname,specfix);
 
   /* local variables for core opcodes and tables */
 
@@ -417,10 +430,11 @@ void printoparraycall(tnode * tptr)
 
   if (currinstance == NULL)
     fprintf(outfile,
-	    "\n\n%s %s__sym_%s%i%s(struct ninstr_types * nstate)\n{\n",
+	    "\n\n%s %s__sym_%s%i%s(ENGINE_PTR_DECLARE_COMMA "
+	    "struct ninstr_types * nstate)\n{\n",
 	    retvartype, curropcodeprefix, tptr->val, tptr->arrayidx,specfix);
   else
-    fprintf(outfile, "\n\n%s %s__sym_%s%i%s(void)\n{\n", 
+    fprintf(outfile, "\n\n%s %s__sym_%s%i%s(ENGINE_PTR_DECLARE)\n{\n", 
 	    retvartype, curropcodeprefix, tptr->val, tptr->arrayidx, specfix);
   printlocals(tptr);
 
@@ -550,8 +564,13 @@ void printopargs(tnode * tcall, tnode * aptr, tnode * fptr,
 	      if (core)
 		sprintf(tablename,"%s",fptr->down->next->down->val);
 	      else
-		sprintf(tablename,"NPI(%s_%s)", newfix,
-			fptr->down->next->down->val);
+		if (aptr->down->vartype == TMAPTYPE)
+		  sprintf(tablename,"NPPS(%s_%s)", newfix,
+			  fptr->down->next->down->val);
+		else
+		  sprintf(tablename,"NPI(%s_%s)", newfix,
+			  fptr->down->next->down->val);
+
 	      if (aptr->down->vartype == TMAPTYPE)
 		{
 		  /* tablemaps */
@@ -609,10 +628,11 @@ void printopargs(tnode * tcall, tnode * aptr, tnode * fptr,
 			  currarrayindex = 0;
 			  currscalarflag = 0;
 
-			  fprintf(outfile,"   memcpy(&(NP(%s_%s)), &(",
+			  fprintf(outfile,"   for(stidx = 0; stidx < 128; stidx++)\n");
+			  fprintf(outfile,"     NP(%s_%s + stidx) = *(&(",
 				  newfix, fptr->down->next->down->val);
 			  blocktree(aptr->down,PRINTTOKENS);
-			  fprintf(outfile,"), sizeof(float)*128);\n");
+			  fprintf(outfile,") + stidx);\n");
 
 			  currarrayindex = 0;
 			  currscalarflag = 1;
@@ -810,7 +830,7 @@ void printopimports(tnode * tptr, char * newfix)
 	      if (sptr->tref->mirror != GLOBALMIRROR)
 		{
 		  fprintf(outfile,
-	  "   memcpy(&(NV(%s_%s)), &(NG(GBL_%s)), %i*sizeof(float));\n",
+	  "   memcpy(&(NVU(%s_%s)), &(NGU(GBL_%s)), %i*sizeof(NGU(0)));\n",
 			  newfix,sptr->val,sptr->val,
 			  truewidth(sptr->width));
 		}
@@ -840,7 +860,7 @@ void printopimports(tnode * tptr, char * newfix)
 		   (sptr->tref->varstate)))
 		{
 		  fprintf(outfile,
-			  "   memset(&(NG(GBL_%s)), 0, %i*sizeof(float));\n",
+			  "   memset(&(NGU(GBL_%s)), 0, %i*sizeof(NGU(0)));\n",
 			  sptr->val, truewidth(sptr->width));
 		}
 	    }
@@ -920,7 +940,7 @@ void printopbody_ki(tnode * tptr)
 
   currblockrate = currblocksafe;
   
-  fprintf(outfile, "  NVI(%s__sym_opstate) = kcycleidx;\n", currinstancename);
+  fprintf(outfile, "  NVI(%s__sym_opstate) = EV(kcycleidx);\n", currinstancename);
   fprintf(outfile, "   } while (1);\n\n");
 
 }
@@ -939,7 +959,7 @@ void printopbody_aki(tnode * tptr)
   fprintf(outfile, "   do {\n");
 
   if (tptr->sptr->cref->klines)
-    fprintf(outfile, "    if (NVI(%s__sym_opstate) == kcycleidx)\n",
+    fprintf(outfile, "    if (NVI(%s__sym_opstate) == EV(kcycleidx))\n",
 	    currinstancename);
   else
     fprintf(outfile, "    if (NVI(%s__sym_opstate))\n", currinstancename);
@@ -989,7 +1009,7 @@ void printopbody_aki(tnode * tptr)
       currblockrate = currblocksafe;
     }
 
-  fprintf(outfile, "  NVI(%s__sym_opstate) = kcycleidx;\n", 
+  fprintf(outfile, "  NVI(%s__sym_opstate) = EV(kcycleidx);\n", 
 	  currinstancename);
   fprintf(outfile, "   } while (1);\n\n");
 
@@ -1052,7 +1072,7 @@ void printoparraygeneral(tnode * tptr)
   if (currinstrument)
     fprintf(outfile, "   NS(vstate[%i]) ", curroparraydepth);
   else
-    fprintf(outfile, "   globalvstate[%i] ", curroparraydepth);
+    fprintf(outfile, "   EV(globalvstate)[%i] ", curroparraydepth);
 
   fprintf(outfile, "= &(NVU(%s_%sopbase + arrayswitch*%s_%sopsize));\n",
 	  currinstancename, tptr->val, currinstancename, tptr->val);
@@ -1062,7 +1082,7 @@ void printoparraygeneral(tnode * tptr)
   if (currinstrument)
     fprintf(outfile, "   NS(tstate[%i]) ", curroparraydepth);
   else
-    fprintf(outfile, "   globaltstate[%i] ", curroparraydepth);
+    fprintf(outfile, "   EV(globaltstate)[%i] ", curroparraydepth);
 
   fprintf(outfile, "= &(NT(TBL_%s_%sopbase + arrayswitch*TBL_%s_%sopsize));\n",
 	  currinstancename, tptr->val, currinstancename, tptr->val);
@@ -1130,7 +1150,7 @@ void printoparrayconst(tnode * tptr)
   char newpfix[STRSIZE];   /* replace w/ char *    */
   sigsym opstack;          /* opcode stack element */
 
-  opnum = (int) make_long(tptr->optr->down->next->next->down);
+  opnum = make_int(tptr->optr->down->next->next->down);
 
   if ((opnum < 0) || (opnum >= truewidth(tptr->ibus->opwidth)))
     internalerror("writeop.c", "oparray range error -- printoparrayconst()");
@@ -1209,7 +1229,7 @@ void printoparraychildren(tnode * tptr, int optype)
 
   if (optype == OPARRAY_CONSTANT)
     {
-      opnum = (int) make_long(tptr->optr->down->next->next->down);
+      opnum = make_int(tptr->optr->down->next->next->down);
 
       opstack.numinst = opnum + 1;
       sprintf(newifix,"%s_%soparray%i", currinstancename, tptr->val, (opnum+1));
@@ -1251,6 +1271,7 @@ void redefoparrayargs(void)
   fprintf(outfile,"#undef NP\n");
   fprintf(outfile,"#undef NPI\n");
   fprintf(outfile,"#undef NPUI\n");
+  fprintf(outfile,"#undef NPPS\n");
 
   fprintf(outfile,"#define NP(x) %s \n", 
 	  (pstr = stackstring(S_NUMBER, curroparraydepth, "x")));
@@ -1264,6 +1285,9 @@ void redefoparrayargs(void)
 	  (pstr = stackstring(S_FREE1, curroparraydepth, "x")));
   free(pstr);
 
+  fprintf(outfile,"#define NPPS(x) %s \n\n", 
+	  (pstr = stackstring(S_FREE2, curroparraydepth, "x")));
+  free(pstr);
 }
 
 
@@ -1281,6 +1305,7 @@ void redefoparraybody(void)
   fprintf(outfile,"#undef NV\n");
   fprintf(outfile,"#undef NVI\n");
   fprintf(outfile,"#undef NVUI\n");
+  fprintf(outfile,"#undef NVPS\n");
   fprintf(outfile,"#undef NVU\n");
 
   fprintf(outfile,"#define NV(x) %s \n", 
@@ -1295,6 +1320,10 @@ void redefoparraybody(void)
 	  (pstr = stackstring(S_FREE1, curroparraydepth, "x")));
   free(pstr);
 
+  fprintf(outfile,"#define NVPS(x) %s \n", 
+	  (pstr = stackstring(S_FREE2, curroparraydepth, "x")));
+  free(pstr);
+
   fprintf(outfile,"#define NVU(x) %s \n", 
 	  (pstr = stackstring(S_UNION, curroparraydepth, "x")));
   free(pstr);
@@ -1403,13 +1432,23 @@ void callbyrefvars(tnode * aptr, tnode * fptr)
 
 {
   int i = 1;
+  int needs_stidx = 0;
+
   while (aptr)
     {
       if (indexed_cbr(aptr) && fptr->sptr->tref->assigntot)
 	fprintf(outfile,"   float * cbr%i;\n",i++);
+      needs_stidx |= (stname_cbr(aptr) || ((aptr->down != NULL) && 
+					 (aptr->down->ttype == S_IDENT) && 
+					 (aptr->down->next == NULL) &&
+					 (aptr->down->sptr == NULL)));
       aptr = aptr->next;
     }
-  if (i > 1)
+
+  if (needs_stidx)
+    fprintf(outfile,"   int stidx;\n");
+
+  if ((i > 1) || needs_stidx)
     fprintf(outfile,"\n");
 }
 
@@ -1585,11 +1624,11 @@ void printtabledefine(int num, char * tablename, int type, int depth)
     break;
   case S_IMPORTS:
     fprintf(outfile, "\n#undef AP%i\n",num);
-    fprintf(outfile, "#define AP%i gtables[%s]\n\n",num,tablename);
+    fprintf(outfile, "#define AP%i EV(gtables)[%s]\n\n",num,tablename);
     break;
   case S_TABLEMAP:
     fprintf(outfile, "\n#undef AP%i\n",num);
-    fprintf(outfile, "#define AP%i (*((struct tableinfo *)(%s)))\n\n",
+    fprintf(outfile, "#define AP%i (*((tableinfo *)(%s)))\n\n",
 	    num, tablename);
     break;
   }
@@ -1613,10 +1652,10 @@ void printinlinetable(tnode * tptr)
     free(pstr);
     break;
   case S_IMPORTS:
-    fprintf(outfile, "gtables[%s]", idxstr);
+    fprintf(outfile, "EV(gtables)[%s]", idxstr);
     break;
   case S_TABLEMAP:
-    fprintf(outfile, "(*((struct tableinfo *)(%s)))",idxstr);
+    fprintf(outfile, "(*((tableinfo *)(%s)))",idxstr);
     break;
   }
 
@@ -1638,11 +1677,11 @@ void printtableindirect(tnode * tptr, char * tablename)
   switch(maketableindex(tptr, curropcodestack, &idxstr, &depth)) {
   case S_TABLE:
     pstr = stackstring(S_TABLE, depth, idxstr);
-    fprintf(outfile,"     %s = (int)(&(%s));\n", tablename, pstr);
+    fprintf(outfile,"     %s = (PSIZE)(&(%s));\n", tablename, pstr);
     free(pstr);
     break;
   case S_IMPORTS:
-    fprintf(outfile,"     %s = (int)(&(gtables[%s]));\n", tablename, idxstr);
+    fprintf(outfile,"     %s = (PSIZE)(&(EV(gtables)[%s]));\n", tablename, idxstr);
     break;
   case S_TABLEMAP:
     fprintf(outfile,"     %s = %s;\n", tablename, idxstr);
@@ -1799,7 +1838,7 @@ int maketableindex(tnode * aptr, sigsym * opstack,
     vmcheck(astr = calloc(1 + strlen("_") + strlen(prefix)
 			  + strlen(aptr->sptr->val), sizeof(char)));
     sprintf(astr, "%s_%s", prefix, aptr->sptr->val);
-    *retstr = stackstring(S_INTGR, *depth, astr);
+    *retstr = stackstring(S_FREE2, *depth, astr);
     free(astr);
 
     if (opstack != curropcodestack)
@@ -1865,7 +1904,7 @@ int maketableindex(tnode * aptr, sigsym * opstack,
       vmcheck(astr = calloc(1 + strlen("_") + strlen(prefix)
 			    + strlen(aptr->sptr->val), sizeof(char)));
       sprintf(astr, "%s_%s", prefix, aptr->sptr->val);
-      *retstr = stackstring(S_INTGR, *depth, astr);
+      *retstr = stackstring(S_FREE2, *depth, astr);
 
       free(astr);
       free(prefix);
@@ -1905,19 +1944,22 @@ char * stackstring(int type, int depth, char * idxstr)
 	{
 	  switch (type) {
 	  case S_NUMBER:
-	    sprintf(retstr, "ninstr[%i].v[%s].f", i, idxstr);
+	    sprintf(retstr, "EV(ninstr)[%i].v[%s].f", i, idxstr);
 	    break;
 	  case S_INTGR:
-	    sprintf(retstr, "ninstr[%i].v[%s].i", i, idxstr);
+	    sprintf(retstr, "EV(ninstr)[%i].v[%s].i", i, idxstr);
 	    break;
 	  case S_FREE1:
-	    sprintf(retstr, "ninstr[%i].v[%s].ui", i, idxstr);
+	    sprintf(retstr, "EV(ninstr)[%i].v[%s].ui", i, idxstr);
+	    break;
+	  case S_FREE2:
+	    sprintf(retstr, "EV(ninstr)[%i].v[%s].ps", i, idxstr);
 	    break;
 	  case S_UNION:
-	    sprintf(retstr, "ninstr[%i].v[%s]", i, idxstr);
+	    sprintf(retstr, "EV(ninstr)[%i].v[%s]", i, idxstr);
 	    break;
 	  case S_TABLE:
-	    sprintf(retstr, "ninstr[%i].t[%s]", i, idxstr);
+	    sprintf(retstr, "EV(ninstr)[%i].t[%s]", i, idxstr);
 	    break;
 	  default:
 	    internalerror("writeop.c", "bad type given to stackstring 1");
@@ -1927,19 +1969,22 @@ char * stackstring(int type, int depth, char * idxstr)
 	{
 	  switch (type) {
 	  case S_NUMBER:
-	    sprintf(retstr, "(ninstr[%i].vstate)[%i][%s].f", i, depth, idxstr);
+	    sprintf(retstr, "(EV(ninstr)[%i].vstate)[%i][%s].f", i, depth, idxstr);
 	    break;
 	  case S_INTGR:
-	    sprintf(retstr, "(ninstr[%i].vstate)[%i][%s].i", i, depth, idxstr);
+	    sprintf(retstr, "(EV(ninstr)[%i].vstate)[%i][%s].i", i, depth, idxstr);
 	    break;
 	  case S_FREE1:
-	    sprintf(retstr, "(ninstr[%i].vstate)[%i][%s].ui", i, depth, idxstr);
+	    sprintf(retstr, "(EV(ninstr)[%i].vstate)[%i][%s].ui", i, depth, idxstr);
+	    break;
+	  case S_FREE2:
+	    sprintf(retstr, "(EV(ninstr)[%i].vstate)[%i][%s].ps", i, depth, idxstr);
 	    break;
 	  case S_UNION:
-	    sprintf(retstr, "(ninstr[%i].vstate)[%i][%s]", i, depth, idxstr);
+	    sprintf(retstr, "(EV(ninstr)[%i].vstate)[%i][%s]", i, depth, idxstr);
 	    break;
 	  case S_TABLE:
-	    sprintf(retstr, "(ninstr[%i].tstate)[%i][%s]", i, depth, idxstr);
+	    sprintf(retstr, "(EV(ninstr)[%i].tstate)[%i][%s]", i, depth, idxstr);
 	    break;
 	  default:
 	    internalerror("writeop.c", "bad type given to stackstring 2");
@@ -1962,6 +2007,9 @@ char * stackstring(int type, int depth, char * idxstr)
 	      case S_FREE1:
 		sprintf(retstr, "nstate->v[%s].ui", idxstr);
 		break;
+	      case S_FREE2:
+		sprintf(retstr, "nstate->v[%s].ps", idxstr);
+		break;
 	      case S_UNION:
 		sprintf(retstr, "nstate->v[%s]", idxstr);
 		break;
@@ -1984,6 +2032,9 @@ char * stackstring(int type, int depth, char * idxstr)
 	      case S_FREE1:
 		sprintf(retstr, "(nstate->vstate)[%i][%s].ui", depth, idxstr);
 		break;
+	      case S_FREE2:
+		sprintf(retstr, "(nstate->vstate)[%i][%s].ps", depth, idxstr);
+		break;
 	      case S_UNION:
 		sprintf(retstr, "(nstate->vstate)[%i][%s]", depth, idxstr);
 		break;
@@ -2001,19 +2052,22 @@ char * stackstring(int type, int depth, char * idxstr)
 	    {
 	      switch (type) {
 	      case S_NUMBER:
-		sprintf(retstr, "global[%s].f", idxstr);
+		sprintf(retstr, "EV(global)[%s].f", idxstr);
 		break;
 	      case S_INTGR:
-		sprintf(retstr, "global[%s].i", idxstr);
+		sprintf(retstr, "EV(global)[%s].i", idxstr);
 		break;
 	      case S_FREE1:
-		sprintf(retstr, "global[%s].ui", idxstr);
+		sprintf(retstr, "EV(global)[%s].ui", idxstr);
+		break;
+	      case S_FREE2:
+		sprintf(retstr, "EV(global)[%s].ps", idxstr);
 		break;
 	      case S_UNION:
-		sprintf(retstr, "global[%s]", idxstr);
+		sprintf(retstr, "EV(global)[%s]", idxstr);
 		break;
 	      case S_TABLE:
-		sprintf(retstr, "gtables[%s]", idxstr);
+		sprintf(retstr, "EV(gtables)[%s]", idxstr);
 		break;
 	      default:
 		internalerror("writeop.c", "bad type given to stackstring 5");
@@ -2023,19 +2077,22 @@ char * stackstring(int type, int depth, char * idxstr)
 	    {
 	      switch (type) {
 	      case S_NUMBER:
-		sprintf(retstr, "globalvstate[%i][%s].f", depth, idxstr);
+		sprintf(retstr, "EV(globalvstate)[%i][%s].f", depth, idxstr);
 		break;
 	      case S_INTGR:
-		sprintf(retstr, "globalvstate[%i][%s].i", depth, idxstr);
+		sprintf(retstr, "EV(globalvstate)[%i][%s].i", depth, idxstr);
 		break;
 	      case S_FREE1:
-		sprintf(retstr, "globalvstate[%i][%s].ui", depth, idxstr);
+		sprintf(retstr, "EV(globalvstate)[%i][%s].ui", depth, idxstr);
+		break;
+	      case S_FREE2:
+		sprintf(retstr, "EV(globalvstate)[%i][%s].ps", depth, idxstr);
 		break;
 	      case S_UNION:
-		sprintf(retstr, "globalvstate[%i][%s]", depth, idxstr);
+		sprintf(retstr, "EV(globalvstate)[%i][%s]", depth, idxstr);
 		break;
 	      case S_TABLE:
-		sprintf(retstr, "globaltstate[%i][%s]", depth, idxstr);
+		sprintf(retstr, "EV(globaltstate)[%i][%s]", depth, idxstr);
 		break;
 	      default:
 		internalerror("writeop.c", "bad type given to stackstring 6");
