@@ -42,7 +42,7 @@
 
 
 /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
-/*         void toptree(int) andnd void postscript(void)        */
+/*         void toptree(int) and void postscript(void)          */
 /*                                                              */
 /* These two top-level functions are called by the main() of    */
 /* sfront (located in sfmain.c). Toptree() prints out the       */
@@ -157,14 +157,16 @@ void postscript(void)
   printshutdown();         /* function for clean exit of sa.c program  */
   printmainloops();        /* loops for instr execution: writemain.c   */
   printmaincontrol();      /* loops for table, tempo and control cmds  */
-  makerobust();            /* signal-robust file primitives            */
 
   /* print the actual main() for sa.c, from lib/csrc library */
 
   active = (ainflow == ACTIVE_FLOW) || (aoutflow == ACTIVE_FLOW);
 
   if (active)
-    makecallback();
+    {
+      if (!nomain)
+	makecallback();
+    }
   else
     {
       switch (makeaudiotypeout(aout)) {
@@ -203,10 +205,11 @@ void ipassmake(tnode * tbranch)
   currblockrate = IRATETYPE;
 
   if (currinstance == NULL)
-    fprintf(outfile,"void %s_ipass(struct ninstr_types * nstate)\n{\n",
+    fprintf(outfile,"void %s_ipass("
+	    "ENGINE_PTR_DECLARE_COMMA struct ninstr_types * nstate)\n{\n",
 	    currinstancename);
   else
-    fprintf(outfile,"void %s_ipass(void)\n{\n", currinstancename);
+    fprintf(outfile,"void %s_ipass(ENGINE_PTR_DECLARE)\n{\n", currinstancename);
 
 
   fprintf(outfile,"   int i;\n");
@@ -227,12 +230,12 @@ void ipassmake(tnode * tbranch)
       ptr1 = ptr1->next;
     }
   fprintf(outfile,"\n");
-  fprintf(outfile,"memset(&(NV(0)), 0, %s_ENDVAR*sizeof(float));\n",
+  fprintf(outfile,"memset(&(NVU(0)), 0, %s_ENDVAR*sizeof(NVU(0)));\n",
 	  currinstancename);
 
   /* later reclaim pointer memory */
 
-  fprintf(outfile,"memset(&(NT(0)), 0, %s_ENDTBL*sizeof(struct tableinfo));\n",
+  fprintf(outfile,"memset(&(NT(0)), 0, %s_ENDTBL*sizeof(NT(0)));\n",
 	  currinstancename);
 
   printdurassign();
@@ -269,7 +272,7 @@ void ipassmake(tnode * tbranch)
 		  }
 		if (ptr1->tref->mirror != GLOBALMIRROR)
 		  fprintf(outfile,
-		"   memcpy(&(NV(%s_%s)), &(NG(GBL_%s)), %i*sizeof(float));\n",
+		"   memcpy(&(NVU(%s_%s)), &(NGU(GBL_%s)), %i*sizeof(NGU(0)));\n",
 			currinstancename,ptr1->val,ptr1->val,
 			truewidth(ptr1->width));
 	      }
@@ -280,7 +283,7 @@ void ipassmake(tnode * tbranch)
 		((ptr1->tref->assigntot == 0) || 
 		 (ptr1->tref->varstate)))
 	      fprintf(outfile,
-		"   memset(&(NG(GBL_%s)), 0, %i*sizeof(float));\n",
+		"   memset(&(NGU(GBL_%s)), 0, %i*sizeof(NGU(0)));\n",
 			ptr1->val, truewidth(ptr1->width));
 	  default:
 	    break;
@@ -324,7 +327,7 @@ void ipassmake(tnode * tbranch)
 	  if ((ptr1->vartype != TABLETYPE) &&
 	      (ptr1->tref->mirror != GLOBALMIRROR))
 	    fprintf(outfile,
-	     "   memcpy(&(NG(GBL_%s)), &(NV(%s_%s)), %i*sizeof(float));\n",
+	     "   memcpy(&(NGU(GBL_%s)), &(NVU(%s_%s)), %i*sizeof(NGU(0)));\n",
 		    ptr1->val,currinstancename,ptr1->val,
 		    truewidth(ptr1->width));
 	}
@@ -350,16 +353,17 @@ void kpassmake(tnode * tbranch)
   currblockrate = KRATETYPE;
 
   if (currinstance == NULL)
-    fprintf(outfile,"void %s_kpass(struct ninstr_types * nstate)\n{\n\n",
+    fprintf(outfile,"void %s_kpass("
+	    "ENGINE_PTR_DECLARE_COMMA struct ninstr_types * nstate)\n{\n\n",
 	    currinstancename);
   else
-    fprintf(outfile,"void %s_kpass(void)\n{\n\n", currinstancename);
+    fprintf(outfile,"void %s_kpass(ENGINE_PTR_DECLARE)\n{\n\n", currinstancename);
 
   fprintf(outfile,"   int i;\n\n");
 
   if (currinstrument->cref->itime)
     fprintf(outfile,
-	    "   NS(iline->itime) = ((float)(kcycleidx - NS(iline->kbirth)))*KTIME;\n\n");
+	    "   NS(iline->itime) = ((float)(EV(kcycleidx) - NS(iline->kbirth)))*EV(KTIME);\n\n");
 
   printdurassign();
 
@@ -382,7 +386,7 @@ void kpassmake(tnode * tbranch)
 		}
 	      if (ptr1->tref->mirror != GLOBALMIRROR)
 		fprintf(outfile,
-	      "   memcpy(&(NV(%s_%s)), &(NG(GBL_%s)), %i*sizeof(float));\n",
+	      "   memcpy(&(NVU(%s_%s)), &(NGU(GBL_%s)), %i*sizeof(NGU(0)));\n",
 		      currinstancename,ptr1->val,ptr1->val,
 		      truewidth(ptr1->width));
 	    }
@@ -414,7 +418,7 @@ void kpassmake(tnode * tbranch)
 	    }
 	  if (ptr1->tref->mirror != GLOBALMIRROR)
 	    fprintf(outfile,
-	     "   memcpy(&(NG(GBL_%s)), &(NV(%s_%s)), %i*sizeof(float));\n",
+	     "   memcpy(&(NGU(GBL_%s)), &(NVU(%s_%s)), %i*sizeof(NGU(0)));\n",
 		    ptr1->val,currinstancename,ptr1->val,
 		    truewidth(ptr1->width));
 	}
@@ -437,12 +441,12 @@ void apassmake(tnode * tbranch)
 
   currblockrate = ARATETYPE;
   if (currinstance == NULL)
-    fprintf(outfile,
-	    "void %s_apass(struct ninstr_types * nstate)\n{\n\n",
+    fprintf(outfile, "void %s_apass(" 
+	    "ENGINE_PTR_DECLARE_COMMA struct ninstr_types * nstate)\n{\n\n",
 	    currinstancename);
   else
     {
-      fprintf(outfile, "void %s_apass(void)\n{\n\n", currinstancename);
+      fprintf(outfile, "void %s_apass(ENGINE_PTR_DECLARE)\n{\n\n", currinstancename);
 
       if (shadowcheck())
 	{
@@ -564,8 +568,12 @@ void printsystemsinit(void)
 
   redefglobal();
 
-  fprintf(outfile,"\n\nvoid system_init(int argc, char **argv)\n");
-  fprintf(outfile,"{\n\n   int i;\n\n");
+  fprintf(outfile,"\n\nENGINE_PTR_TYPE system_init(int argc, char **argv,"
+	  " float sample_rate)\n");
+
+  fprintf(outfile,"{\n");
+  fprintf(outfile,"   int i;\n");
+  fprintf(outfile,"   ENGINE_PTR_CREATE_SEMICOLON\n\n");
 
   iptr = globalsymtable;
   while (iptr != NULL)
@@ -582,18 +590,21 @@ void printsystemsinit(void)
       iptr = iptr->next;
     }
 
+  fprintf(outfile,"\n   ENGINE_PTR_NULLRETURN_SEMICOLON\n\n");
+
+  fprintf(outfile,"   engine_init(ENGINE_PTR_COMMA sample_rate);\n");
   if (fixedseed)
-    fprintf(outfile,"\n   srand(9753193L);\n");
+    fprintf(outfile,"\n   srand(9753193);\n");
   else
     fprintf(outfile,"\n   srand(((unsigned int)time(0))|1);\n");
     
-  fprintf(outfile,"   asys_argc = argc;\n");
-  fprintf(outfile,"   asys_argv = argv;\n\n");
+  fprintf(outfile,"   EV(asys_argc) = argc;\n");
+  fprintf(outfile,"   EV(asys_argv) = argv;\n\n");
 
   if (cin)
     {
-      fprintf(outfile,"   csys_argc = argc;\n");
-      fprintf(outfile,"   csys_argv = argv;\n\n");     
+      fprintf(outfile,"   EV(csys_argc) = argc;\n");
+      fprintf(outfile,"   EV(csys_argv) = argv;\n\n");     
     }
 
   fprintf(outfile,"\n");
@@ -634,34 +645,34 @@ void printsystemsinit(void)
 
   printmidiglobals();
 
-  fprintf(outfile,"   memset(&(NV(GBL_STARTVAR)), 0, \n");
-  fprintf(outfile,"          (GBL_ENDVAR-GBL_STARTVAR)*sizeof(float));\n");
+  fprintf(outfile,"   memset(&(NVU(GBL_STARTVAR)), 0, \n");
+  fprintf(outfile,"          (GBL_ENDVAR-GBL_STARTVAR)*sizeof(NVU(0)));\n");
 
   /* later reclaim tables */
 
-  fprintf(outfile,"   memset(&(NT(0)), 0, GBL_ENDTBL*sizeof(struct tableinfo));\n");
+  fprintf(outfile,"   memset(&(NT(0)), 0, GBL_ENDTBL*sizeof(NT(0)));\n");
 
   if (startupinstr != NULL)
     {
-      fprintf(outfile,"   u_startup[0].starttime = 0.0F;\n");
-      fprintf(outfile,"   u_startup[0].endtime = MAXENDTIME;\n");
-      fprintf(outfile,"   u_startup[0].abstime = 0.0F;\n");
-      fprintf(outfile,"   u_startup[0].released = 0;\n");
-      fprintf(outfile,"   u_startup[0].turnoff = 0;\n");
-      fprintf(outfile,"   u_startup[0].time = 0.0F;\n");
-      fprintf(outfile,"   u_startup[0].itime = 0.0F;\n");
-      fprintf(outfile,"   u_startup[0].sdur = -1.0F;\n");
-      fprintf(outfile,"   u_startup[0].kbirth = kbase;\n\n");
+      fprintf(outfile,"   EV(u_startup)[0].starttime = 0.0F;\n");
+      fprintf(outfile,"   EV(u_startup)[0].endtime = MAXENDTIME;\n");
+      fprintf(outfile,"   EV(u_startup)[0].abstime = 0.0F;\n");
+      fprintf(outfile,"   EV(u_startup)[0].released = 0;\n");
+      fprintf(outfile,"   EV(u_startup)[0].turnoff = 0;\n");
+      fprintf(outfile,"   EV(u_startup)[0].time = 0.0F;\n");
+      fprintf(outfile,"   EV(u_startup)[0].itime = 0.0F;\n");
+      fprintf(outfile,"   EV(u_startup)[0].sdur = -1.0F;\n");
+      fprintf(outfile,"   EV(u_startup)[0].kbirth = EV(kbase);\n\n");
 
       if (totmidichan)
-	fprintf(outfile,"   u_startup[0].numchan = midimasterchannel;\n\n");
+	fprintf(outfile,"   EV(u_startup)[0].numchan = EV(midimasterchannel);\n\n");
 
-      fprintf(outfile,"   u_startup[0].noteon = PLAYING;\n");
-      fprintf(outfile,"   u_startup[0].notestate = nextstate;\n");
-      fprintf(outfile,"   u_startup[0].nstate = &ninstr[nextstate];\n");
-      fprintf(outfile,"   ninstr[nextstate].iline = &u_startup[0];\n");
-      fprintf(outfile,"   nextstate++;\n");
-      fprintf(outfile,"   startup_ipass(u_startup[0].nstate);\n");
+      fprintf(outfile,"   EV(u_startup)[0].noteon = PLAYING;\n");
+      fprintf(outfile,"   EV(u_startup)[0].notestate = EV(nextstate);\n");
+      fprintf(outfile,"   EV(u_startup)[0].nstate = &(EV(ninstr)[EV(nextstate)]);\n");
+      fprintf(outfile,"   EV(ninstr)[EV(nextstate)].iline = &EV(u_startup)[0];\n");
+      fprintf(outfile,"   EV(nextstate)++;\n");
+      fprintf(outfile,"   startup_ipass(ENGINE_PTR_COMMA EV(u_startup)[0].nstate);\n");
     }
   iptr = globalsymtable;
   currinputwidth = inchannels;
@@ -683,10 +694,10 @@ void printsystemsinit(void)
 
   redefnormal();
 
-  fprintf(outfile,"   for (busidx=0; busidx<ENDBUS;busidx++)\n");
-  fprintf(outfile,"      TB(busidx)=0.0F;\n\n");
+  fprintf(outfile,"      memset(&(TB(0)), 0, ENDBUS*sizeof(TB(0)));\n\n");
 
-  fprintf(outfile,"\n}\n\n");
+  fprintf(outfile,"\n  ENGINE_PTR_RETURN_SEMICOLON\n");
+  fprintf(outfile,"}\n\n");
 
 }
 
@@ -706,7 +717,7 @@ void printeffectsinit(void)
   /* print effects_init */
 
   redefglobal();
-  fprintf(outfile,"\n\nvoid effects_init(void)\n{\n\n");
+  fprintf(outfile,"\n\nvoid effects_init(ENGINE_PTR_DECLARE)\n{\n\n");
 
   sptr = instrnametable;
   while (sptr != NULL)
@@ -735,7 +746,7 @@ void printeffectsinit(void)
 			  showerrorplace(instptr->down->down->linenum, 
 					 instptr->down->down->filename);
 			}
-		      fprintf(outfile,"e_%s[%i].p[%s_%s] = ",sptr->val,i,
+		      fprintf(outfile,"EV(e_%s)[%i].p[%s_%s] = ",sptr->val,i,
 			      instptr->val, pptr->val);
 		      currinputwidth = inchannels;
 		      currinstrwidth = outchannels;
@@ -775,24 +786,24 @@ void printeffectsinit(void)
 			pvalptr = pvalptr->next;
 		    }
 
-		  fprintf(outfile,"e_%s[%i].noteon = TOBEPLAYED;\n",sptr->val,i);
+		  fprintf(outfile,"EV(e_%s)[%i].noteon = TOBEPLAYED;\n",sptr->val,i);
 
 		  /* internal variables */
 
-		  fprintf(outfile,"e_%s[%i].starttime = 0.0F;\n",sptr->val,i);
-		  fprintf(outfile,"e_%s[%i].abstime = 0.0F;\n",sptr->val,i);
-		  fprintf(outfile,"e_%s[%i].released = 0;\n",sptr->val,i);
-		  fprintf(outfile,"e_%s[%i].turnoff = 0;\n",sptr->val,i);
+		  fprintf(outfile,"EV(e_%s)[%i].starttime = 0.0F;\n",sptr->val,i);
+		  fprintf(outfile,"EV(e_%s)[%i].abstime = 0.0F;\n",sptr->val,i);
+		  fprintf(outfile,"EV(e_%s)[%i].released = 0;\n",sptr->val,i);
+		  fprintf(outfile,"EV(e_%s)[%i].turnoff = 0;\n",sptr->val,i);
 
 		  /* standard names */
 
-		  fprintf(outfile,"e_%s[%i].time = 0.0F;\n",sptr->val,i);
-		  fprintf(outfile,"e_%s[%i].itime = 0.0F;\n",sptr->val,i);
-		  fprintf(outfile,"e_%s[%i].sdur = -1.0F;\n",sptr->val,i);
-		  fprintf(outfile,"e_%s[%i].kbirth = kbase;\n",sptr->val,i);
+		  fprintf(outfile,"EV(e_%s)[%i].time = 0.0F;\n",sptr->val,i);
+		  fprintf(outfile,"EV(e_%s)[%i].itime = 0.0F;\n",sptr->val,i);
+		  fprintf(outfile,"EV(e_%s)[%i].sdur = -1.0F;\n",sptr->val,i);
+		  fprintf(outfile,"EV(e_%s)[%i].kbirth = EV(kbase);\n",sptr->val,i);
 
 		  if (totmidichan)
-		    fprintf(outfile,"e_%s[%i].numchan = midimasterchannel;\n",sptr->val,i);
+		    fprintf(outfile,"EV(e_%s)[%i].numchan = EV(midimasterchannel);\n",sptr->val,i);
 		  
 		}
 	      instptr = instptr->next;
@@ -820,8 +831,8 @@ void printshutdown(void)
 
   iptr = getvsym(&busnametable,"input_bus");
 
-  fprintf(outfile,"\n\nvoid shut_down(void)\n   {\n\n");
-  fprintf(outfile,"  if (graceful_exit)\n");
+  fprintf(outfile,"\n\nvoid shut_down(ENGINE_PTR_DECLARE)\n   {\n\n");
+  fprintf(outfile,"  if (EV(graceful_exit))\n");
   fprintf(outfile,"    {\n");
   fprintf(outfile,"      fprintf(stderr, \"\\nShutting down system ... please wait.\\n\");\n");
   fprintf(outfile,"      fprintf(stderr, \"If no termination in 10 seconds, use Ctrl-C or Ctrl-\\\\ to force exit.\\n\");\n");
@@ -829,7 +840,7 @@ void printshutdown(void)
   fprintf(outfile,"    }\n");
 
   if ((ainflow == PASSIVE_FLOW) && (aoutflow == PASSIVE_FLOW))
-    fprintf(outfile,"   asys_putbuf(&asys_obuf, &obusidx);\n");
+    fprintf(outfile,"   asys_putbuf(&EV(asys_obuf), &EV(obusidx));\n");
 
   if ((ain == aout) && (iptr != NULL) && (inchannels > 0))
     fprintf(outfile,"   asys_ioshutdown();\n");
@@ -841,21 +852,22 @@ void printshutdown(void)
     }
 
   if (cin)
-    fprintf(outfile,"\n   csys_shutdown();\n");
+    fprintf(outfile,"\n   csys_shutdown(ENGINE_PTR);\n");
 
   if (session)
     fprintf(outfile,"   nsys_shutdown();\n");
 
-  fprintf(outfile,"\n   }\n\n");
+  fprintf(outfile,"\n   ENGINE_PTR_DESTROY_SEMICOLON\n");
+  fprintf(outfile,"   }\n\n");
 
   if (session)
     {
       fprintf(outfile,"\n");
       fprintf(outfile,"void sigint_handler(int signum)\n {\n");
       fprintf(outfile,"\n");
-      fprintf(outfile,"  if (graceful_exit)\n");
+      fprintf(outfile,"  if (EV(graceful_exit))\n");
       fprintf(outfile,"   exit(130);\n");
-      fprintf(outfile,"  graceful_exit = 1;\n");
+      fprintf(outfile,"  EV(graceful_exit) = 1;\n");
       fprintf(outfile," }\n\n");
     }
 
@@ -915,7 +927,7 @@ void printmaincontrol(void)
 
 {
 
-  fprintf(outfile,"void main_control(void)\n");
+  fprintf(outfile,"void main_control(ENGINE_PTR_DECLARE)\n");
   fprintf(outfile,"\n");
   fprintf(outfile,"{\n");
 
@@ -923,6 +935,8 @@ void printmaincontrol(void)
     fprintf(outfile,"   int i;\n");
   if (allsasl->numtable || abssasl->numtable)
     fprintf(outfile,"   int len;\n");
+  if (csasl && ((allsasl->numcontrol) || (abssasl->numcontrol)))
+    fprintf(outfile,"instr_line * sysidx;\n");  /* later, a typedef */
 
   fprintf(outfile,"\n");
 
@@ -981,7 +995,7 @@ void updatedynamictables(tnode * iptr, char * prefix)
 	  if ((sptr->tref->assigntot || gptr->tref->assigntot) && 
 	      ((strlen(sptr->val) <= 5) || strncmp(sptr->val, "_sym_", 5)))
 	    {
-	      fprintf(outfile, "   if (gtables[TBL_GBL_%s].stamp > ",
+	      fprintf(outfile, "   if (EV(gtables)[TBL_GBL_%s].stamp > ",
 		      sptr->val);
 	      fprintf(outfile, "NT(TBL_%s_%s).stamp)\n",
 		      prefix, sptr->val);
@@ -1036,7 +1050,7 @@ void printmidiglobals(void)
       for (j = MIDIVOLUMEPOS; j < totmidichan*MIDIFRAMELEN; 
 	   j = j + MIDIFRAMELEN)
 	{
-	  fprintf(outfile, "global[%i].f = ", j);
+	  fprintf(outfile, "EV(global)[%i].f = ", j);
 	  if ((i++) == 3)
 	    {
 	      fprintf(outfile, "\n   ");
@@ -1055,7 +1069,7 @@ void printmidiglobals(void)
       for (j = MIDIPANPOS; j < totmidichan*MIDIFRAMELEN; 
 	   j = j + MIDIFRAMELEN)
 	{
-	  fprintf(outfile, "global[%i].f = ", j);
+	  fprintf(outfile, "EV(global)[%i].f = ", j);
 	  if ((i++) == 3)
 	    {
 	      fprintf(outfile, "\n   ");
@@ -1074,7 +1088,7 @@ void printmidiglobals(void)
       for (j = MIDIEXPRPOS; j < totmidichan*MIDIFRAMELEN; 
 	   j = j + MIDIFRAMELEN)
 	{
-	  fprintf(outfile, "global[%i].f = ", j);
+	  fprintf(outfile, "EV(global)[%i].f = ", j);
 	  if ((i++) == 3)
 	    {
 	      fprintf(outfile, "\n   ");
@@ -1093,7 +1107,7 @@ void printmidiglobals(void)
       for (j = MIDIBENDPOS; j < totmidichan*MIDIFRAMELEN; 
 	   j = j + MIDIFRAMELEN)
 	{
-	  fprintf(outfile, "global[%i].f = ", j);
+	  fprintf(outfile, "EV(global)[%i].f = ", j);
 	  if ((i++) == 3)
 	    {
 	      fprintf(outfile, "\n   ");
@@ -1110,7 +1124,7 @@ void printmidiglobals(void)
       i = 0;
       for (j = 0; j < totmidichan; j++)
 	{
-	  fprintf(outfile, "global[%i].f = ", 
+	  fprintf(outfile, "EV(global)[%i].f = ", 
 		  MIDIEXTPOS + j*MIDIFRAMELEN);
 	  if (j < confmidi->midinumchan)
 	    {
@@ -1168,34 +1182,34 @@ void printmidiglobals(void)
 void printtempoloop(char * prefix)
 
 {
-  fprintf(outfile,"   while ((%stempoidx <=end%stempo)&&\n",
+  fprintf(outfile,"   while ((EV(%stempoidx) <= EV(end%stempo))&&\n",
 	  prefix, prefix);
 
   if (strcmp("sa", prefix))
-    fprintf(outfile,"        (stempo[stempoidx].t <= scorebeats))\n");
+    fprintf(outfile,"        (stempo[EV(stempoidx)].t <= EV(scorebeats)))\n");
   else
-    fprintf(outfile,"        (satempo[satempoidx].t <= absolutetime))\n");
+    fprintf(outfile,"        (satempo[EV(satempoidx)].t <= EV(absolutetime)))\n");
 
   fprintf(outfile,"   {\n");  
-  fprintf(outfile,"    kbase = kcycleidx;\n");
-  fprintf(outfile,"    scorebase = scorebeats;\n");
-  fprintf(outfile,"    tempo = %stempo[%stempoidx].newtempo;\n",
+  fprintf(outfile,"    EV(kbase) = EV(kcycleidx);\n");
+  fprintf(outfile,"    EV(scorebase) = EV(scorebeats);\n");
+  fprintf(outfile,"    EV(tempo) = %stempo[EV(%stempoidx)].newtempo;\n",
 	  prefix, prefix);
-  fprintf(outfile,"    scoremult = 1.666667e-02F*KTIME*tempo;\n");
+  fprintf(outfile,"    EV(scoremult) = 1.666667e-02F*EV(KTIME)*EV(tempo);\n");
   if (allsasl->endtimeval)
     {
-      fprintf(outfile,"    endkcycle = kbase + (int)\n");
+      fprintf(outfile,"    EV(endkcycle) = EV(kbase) + (int)\n");
       fprintf(outfile,
-	      "      (KRATE*(endtime - scorebase)*(60.0F/tempo));\n");
+	      "      (EV(KRATE)*(EV(endtime) - EV(scorebase))*(60.0F/EV(tempo)));\n");
       if (abssasl->endtimeval)
 	{
 	  fprintf(outfile, 
-		  "     endkcycle = (endkinit > endkcycle) ?\n");
+		  "     EV(endkcycle) = (EV(endkinit) > EV(endkcycle)) ?\n");
 	  fprintf(outfile, 
-		  "                  endkinit : endkcycle;\n\n");
+		  "                  EV(endkinit) : EV(endkcycle);\n\n");
 	}
     }
-  fprintf(outfile,"    %stempoidx++;\n", prefix);
+  fprintf(outfile,"    EV(%stempoidx)++;\n", prefix);
   fprintf(outfile,"    }\n\n");
 
 }
@@ -1212,22 +1226,22 @@ void printtableloop(char * prefix)
 
   /* add table free(), but be sure not to free() static memory.*/
 
-  z[lc++]="while ((%stableidx <=end%stable)&&"; 
+  z[lc++]="while ((EV(%stableidx) <= EV(end%stable)) &&"; 
 
   if (strcmp("sa", prefix))
-    z[lc++]="     (%stable[%stableidx].t <= scorebeats))";
+    z[lc++]="     (%stable[EV(%stableidx)].t <= EV(scorebeats)))";
   else
-    z[lc++]="     (%stable[%stableidx].t <= absolutetime))";  
+    z[lc++]="     (%stable[EV(%stableidx)].t <= EV(absolutetime)))";  
 
   z[lc++]="   {";  
-  z[lc++]="     if (NT((i = %stable[%stableidx].gindex)).llmem)";
+  z[lc++]="     if (NT((i = %stable[EV(%stableidx)].gindex)).llmem)";
   z[lc++]="      free(NT(i).t);";
-  z[lc++]="     memset(&(NT(i)), 0, sizeof(struct tableinfo));";
-  z[lc++]="     if ((len = %stable[%stableidx].size) < 0)"; 
-  z[lc++]="       (*%stable[%stableidx].tmake) ();";
+  z[lc++]="     memset(&(NT(i)), 0, sizeof(NT(0)));";
+  z[lc++]="     if ((len = %stable[EV(%stableidx)].size) < 0)"; 
+  z[lc++]="       (*%stable[EV(%stableidx)].tmake) (ENGINE_PTR);";
   z[lc++]="     else"; 
   z[lc++]="      {"; 
-  z[lc++]="        NT(i).stamp = scorebeats;"; 
+  z[lc++]="        NT(i).stamp = EV(scorebeats);"; 
   if (interp == INTERP_SINC)
     {
       z[lc++]="        NT(i).sffl = 1.0F;";
@@ -1235,11 +1249,11 @@ void printtableloop(char * prefix)
       z[lc++]="        NT(i).dsincr = SINC_PILEN;";
     }
   z[lc++]="        NT(i).lenf= (float)(NT(i).len = len);";
-  z[lc++]="        NT(i).oconst= NT(i).lenf*ATIME;";
+  z[lc++]="        NT(i).oconst= NT(i).lenf*EV(ATIME);";
   z[lc++]="        NT(i).tend = len - 1;";
-  z[lc++]="        NT(i).t = (float *)(%stable[%stableidx].data);";
+  z[lc++]="        NT(i).t = (float *)(%stable[EV(%stableidx)].data);";
   z[lc++]="      }"; 
-  z[lc++]="     %stableidx++;";
+  z[lc++]="     EV(%stableidx)++;";
   z[lc++]="   }";
 
   printcontrolblock(lc, prefix);
@@ -1253,25 +1267,25 @@ void printtableloop(char * prefix)
 void printcontrolloop(char * prefix)
 
 {
-  fprintf(outfile,"  while (%scontrolidx && (%scontrolidx <=end%scontrol)&&\n",
+  fprintf(outfile,"  while (EV(%scontrolidx) && (EV(%scontrolidx) <= EV(end%scontrol)) &&\n",
 	  prefix, prefix, prefix);
 
   if (strcmp("sa", prefix))
-    fprintf(outfile,"	 (scontrolidx->t <= scorebeats))\n");
+    fprintf(outfile,"	 (EV(scontrolidx)->t <= EV(scorebeats)))\n");
   else
-    fprintf(outfile,"	 (sacontrolidx->t <= absolutetime))\n");
+    fprintf(outfile,"	 (EV(sacontrolidx)->t <= EV(absolutetime)))\n");
 
   fprintf(outfile,"  {\n");
-  fprintf(outfile,"    if (%scontrolidx->siptr < 0)\n", prefix);
-  fprintf(outfile,"	global[%scontrolidx->imptr].f = %scontrolidx->imval;\n"
+  fprintf(outfile,"    if (EV(%scontrolidx)->siptr < 0)\n", prefix);
+  fprintf(outfile,"	EV(global)[EV(%scontrolidx)->imptr].f = EV(%scontrolidx)->imval;\n"
 	  ,prefix, prefix);
   fprintf(outfile,"    else\n");
   fprintf(outfile,"	{\n");
-  fprintf(outfile,"	  if ( (%scontrolidx->iline != NULL) &&\n", prefix);
-  fprintf(outfile,"	       (%scontrolidx->iline->noteon == PLAYING) )\n",
+  fprintf(outfile,"	  if ( (EV(%scontrolidx)->iline != NULL) &&\n", prefix);
+  fprintf(outfile,"	       (EV(%scontrolidx)->iline->noteon == PLAYING) )\n",
 	  prefix);
-  fprintf(outfile,"          %scontrolidx->iline->nstate->v[%scontrolidx->imptr].f\n", prefix, prefix);
-  fprintf(outfile,"	      = %scontrolidx->imval;\n", prefix);
+  fprintf(outfile,"          EV(%scontrolidx)->iline->nstate->v[EV(%scontrolidx)->imptr].f\n", prefix, prefix);
+  fprintf(outfile,"	      = EV(%scontrolidx)->imval;\n", prefix);
 
   if (csasl)
     makesaslcrosscontrol( prefix);
@@ -1279,7 +1293,7 @@ void printcontrolloop(char * prefix)
   fprintf(outfile,"	}\n");
 
 
-  fprintf(outfile,"    %scontrolidx++;\n", prefix);
+  fprintf(outfile,"    EV(%scontrolidx)++;\n", prefix);
   fprintf(outfile,"  }\n\n");
 
 }
