@@ -99,7 +99,7 @@ float * wavereduceconstants(tnode * defnode, tnode * nsl)
 
   if (sizeptr->vol == CONSTANT)
     {
-      if ((size = (int) make_long(sizeptr->down)) < 0)
+      if ((size = make_int(sizeptr->down)) < 0)
 	size = -1;
 
       if (sizeptr->down->ttype == S_NUMBER)
@@ -305,7 +305,7 @@ void createconstanttable(sigsym * ident, char * prefix, int mode)
 		  prefix,ident->val, size -1);
 
   mz(lc); sprintf(z[lc++], 
-		  "NT(%s_%s).oconst = %i.0F*ATIME;",
+		  "NT(%s_%s).oconst = %i.0F*EV(ATIME);",
 		   prefix,ident->val, size);
 
   if (interp == INTERP_SINC)
@@ -486,7 +486,7 @@ int buzzconstcheck(tnode * tptr, tnode  *nsl, int size, float ** ret)
     {
       switch (i) {
       case 1:
-	if ((nharm = (int) make_long(tptr->down)) < 0)
+	if ((nharm = make_int(tptr->down)) < 0)
 	  nharm = -1;
 	if (tptr->down->ttype == S_NUMBER)
 	  {
@@ -495,7 +495,7 @@ int buzzconstcheck(tnode * tptr, tnode  *nsl, int size, float ** ret)
 	  }
 	break;
       case 2:
-	if ((loharm = (int) make_long(tptr->down)) < 0)
+	if ((loharm = make_int(tptr->down)) < 0)
 	  loharm = -1;
 	if (tptr->down->ttype == S_NUMBER)
 	  {
@@ -622,7 +622,7 @@ int cubicconstcheck(tnode * tptr, tnode * nsl, int size, float ** ret)
       case 1:
 	oldinfl = infl;
 	oldinfl_f = (float) oldinfl;
-	infl = (int) make_long(tptr->down);
+	infl = make_int(tptr->down);
 	infl_f = (float) infl;
 
 	if (tptr->down->ttype == S_NUMBER)
@@ -674,7 +674,7 @@ int cubicconstcheck(tnode * tptr, tnode * nsl, int size, float ** ret)
       case 3:
 	oldx = x;
 	oldx_f = (float) oldx;
-	x = (int) make_long(tptr->down);
+	x = make_int(tptr->down);
 	x_f = (float) x;
 	if (tptr->down->ttype == S_NUMBER)
 	  {
@@ -873,7 +873,7 @@ int expsegconstcheck(tnode * tptr, tnode * nsl, int size, float ** ret)
       switch (i & 1) {
       case 1:
 	oldx = x;
-	x = (int) make_long(tptr->down);
+	x = make_int(tptr->down);
 	if (tptr->down->ttype == S_NUMBER)
 	  {
 	    tptr->res = tptr->down->res = ASINT;
@@ -1086,7 +1086,7 @@ int linesegconstcheck(tnode * tptr, tnode * nsl, int size, float ** ret)
       switch (i & 1) {
       case 1:
 	oldx = x;
-	x = (int) make_long(tptr->down);
+	x = make_int(tptr->down);
 	if (tptr->down->ttype == S_NUMBER)
 	  {
 	    tptr->res = tptr->down->res = ASINT;
@@ -1332,7 +1332,7 @@ void randomconstcheck(tnode * tptr, tnode * nsl)
     {
       switch (i) {
       case 1:
-	dist = (int) make_long(tptr->down);
+	dist = make_int(tptr->down);
 	if (tptr->down->ttype == S_NUMBER)
 	  {
 	    tptr->res = tptr->down->res = ASINT;
@@ -1456,7 +1456,7 @@ void sampleconstcheck(tnode * tptr, tnode * nsl)
 
       if (tptr->vol == CONSTANT)
 	{
-	  if ((skip = make_long(tptr->down)) < 0)
+	  if ((skip = make_int(tptr->down)) < 0)
 	    skip = 0;
 	  if (tptr->down->ttype == S_NUMBER)
 	    {	  
@@ -1496,7 +1496,7 @@ int splineconstcheck(tnode * tptr, tnode * nsl, int size, float ** ret)
       switch (i % 3) {
       case 1:
 	oldx = x;
-	x = (int) make_long(tptr->down);
+	x = make_int(tptr->down);
 	if (tptr->down->ttype == S_NUMBER)
 	  {
 	    tptr->res = tptr->down->res = ASINT;
@@ -1665,7 +1665,7 @@ int stepconstcheck(tnode * tptr, tnode * nsl, int size, float ** ret)
       switch (i & 1) {
       case 1:
 	oldx = x;
-	x = (int) make_long(tptr->down);
+	x = make_int(tptr->down);
 	if (tptr->down->ttype == S_NUMBER)
 	  {
 	    tptr->res = tptr->down->res = ASINT;
@@ -1764,7 +1764,7 @@ void windowconstcheck(tnode * tptr, tnode * nsl, int size, float ** ret)
     {
       switch (i) {
       case 1:
-	type = (int) make_long(tptr->down);
+	type = make_int(tptr->down);
 	if (tptr->down->ttype == S_NUMBER)
 	  {
 	    tptr->res = tptr->down->res = ASINT;
@@ -1926,15 +1926,15 @@ char * wavetablenameprefix(sigsym * opstack, char * prefix)
 
 
 extern void wt_bitsounderror(tnode *, tnode *);
-extern void wt_getsoundbytes(unsigned char *, int, unsigned long *,
+extern void wt_getsoundbytes(unsigned char *, int, unsigned int *,
 			     tnode *, tnode *);
-extern void wt_getsoundsbytes(char *, int, unsigned long *,
+extern void wt_getsoundsbytes(char *, int, unsigned int *,
 			      tnode *, tnode *);
-extern int wt_getnextcookie(unsigned char *, unsigned long *);
-extern void wt_flushsoundbytes(int, unsigned long *, tnode *, tnode * );
-extern unsigned long wt_wavefileintval(int, unsigned long *, tnode *, tnode *);
-extern unsigned long wt_aiffileintval(int, unsigned long *, tnode *, tnode *);
-extern int wt_soundtypecheck(char *, unsigned long *);
+extern int wt_getnextcookie(unsigned char *, unsigned int *);
+extern void wt_flushsoundbytes(int, unsigned int *, tnode *, tnode * );
+extern unsigned int wt_wavefileintval(int, unsigned int *, tnode *, tnode *);
+extern unsigned int wt_aiffileintval(int, unsigned int *, tnode *, tnode *);
+extern int wt_soundtypecheck(char *, unsigned int *);
  
 
 
@@ -1945,14 +1945,14 @@ extern int wt_soundtypecheck(char *, unsigned long *);
 void wavefileconstcheck(tnode * tptr, tnode * nsl)
 
 {
-  long i;
+  int i;
   sampleinfo * sinfo;
-  unsigned long count = 0;
+  unsigned int count = 0;
   unsigned char cookie[4];
-  long unity = 0;
-  long fract = 0;
+  int unity = 0;
+  int fract = 0;
   int dataflag = 0;
-  long channels = 0;
+  int channels = 0;
   char * suffix;
   char at_n = -1;
   int ntotal = 0;
@@ -2023,7 +2023,7 @@ void wavefileconstcheck(tnode * tptr, tnode * nsl)
 	  if (at_n > channels - 1)
 	    {
 	      printf("Error: Sample generator @%i filename syntax requests\n"
-		     "       the %i'th channel of an %li channel WAV file.\n", 
+		     "       the %i'th channel of an %i channel WAV file.\n", 
 		     at_n, at_n+1, channels);
 	      printtableproblem(tptr, nsl);
 	    }
@@ -2123,17 +2123,17 @@ void aiffileconstcheck(tnode * tptr, tnode * nsl)
 
 {
   sampleinfo * sinfo;
-  unsigned long i, j, m, e;
+  unsigned int i, j, m, e;
   unsigned char cookie[4];  
   int dataflag = 0;
-  unsigned long count = 0;
-  unsigned long chunksize;
-  long unity = 0;
-  long fract = 0;
+  unsigned int count = 0;
+  unsigned int chunksize;
+  int unity = 0;
+  int fract = 0;
   char c;
   struct aiffmark * mptr = NULL;
   struct aiffmark * mhead = NULL;
-  long channels = 0;
+  int channels = 0;
   char * suffix;
   char at_n = -1;
   int ntotal = 0;
@@ -2201,7 +2201,7 @@ void aiffileconstcheck(tnode * tptr, tnode * nsl)
 		  if (at_n > channels - 1)
 		    {
 		      printf("Error: Sample generator @%i filename syntax requests\n"
-			     "       the %i'th channel of an %li channel AIF file.\n", 
+			     "       the %i'th channel of an %i channel AIF file.\n", 
 			     at_n, at_n+1, channels);
 		      printtableproblem(tptr, nsl);
 		    }
@@ -2214,7 +2214,7 @@ void aiffileconstcheck(tnode * tptr, tnode * nsl)
 	  e = ((short)wt_aiffileintval(2, &count, tptr, nsl))&0x7FFF;
 	  m = wt_aiffileintval(4, &count, tptr, nsl);
 	  wt_flushsoundbytes(4, &count, tptr, nsl);
-	  sinfo->srate = (unsigned long) (0.5+(m*exp(log(2)*(e - 16414.0F))));
+	  sinfo->srate = (unsigned int) (0.5+(m*exp(log(2)*(e - 16414.0F))));
 	  if (chunksize > 18)  /* '% 2' flushes pad byte */
 	    wt_flushsoundbytes(chunksize - 18 + (chunksize % 2), &count, tptr, nsl);
 	  continue;
@@ -2299,7 +2299,7 @@ void aiffileconstcheck(tnode * tptr, tnode * nsl)
 	    {
 	      j = 1;
 	      sinfo->start = mptr->position;
-	      if ((unsigned long)(sinfo->start) == sinfo->len)
+	      if ((unsigned int)(sinfo->start) == sinfo->len)
 		sinfo->start=0;
 	      break;
 	    }
@@ -2315,7 +2315,7 @@ void aiffileconstcheck(tnode * tptr, tnode * nsl)
 	    {
 	      j = 1;
 	      sinfo->end = mptr->position;
-	      if ((unsigned long)(sinfo->end) == sinfo->len)
+	      if ((unsigned int)(sinfo->end) == sinfo->len)
 		sinfo->end=0;
 	      break;
 	    }
@@ -2392,7 +2392,7 @@ void wt_bitsounderror(tnode * tptr, tnode * nsl)
 /*********************************************************/
 
 void wt_getsoundbytes(unsigned char * c, int numbytes, 
-		      unsigned long * count, tnode * tptr, tnode * nsl)
+		      unsigned int * count, tnode * tptr, tnode * nsl)
 
 {
   (*count) += numbytes;
@@ -2406,7 +2406,7 @@ void wt_getsoundbytes(unsigned char * c, int numbytes,
 /*    gets next block of WAV/AIFF bytes -- signed        */
 /*********************************************************/
 
-void wt_getsoundsbytes(char * c, int numbytes, unsigned long * count,
+void wt_getsoundsbytes(char * c, int numbytes, unsigned int * count,
 		       tnode * tptr, tnode * nsl)
 
 {
@@ -2422,7 +2422,7 @@ void wt_getsoundsbytes(char * c, int numbytes, unsigned long * count,
 /*           gets next WAV/AIFF cookie -- 1 if EOF       */
 /*********************************************************/
 
-int wt_getnextcookie(unsigned char * c, unsigned long * count)
+int wt_getnextcookie(unsigned char * c, unsigned int * count)
 
 {
   (*count) += 4;
@@ -2439,7 +2439,7 @@ int wt_getnextcookie(unsigned char * c, unsigned long * count)
 /*        flushes next block of WAV/AIFF bytes           */
 /*********************************************************/
 
-void wt_flushsoundbytes(int numbytes, unsigned long * count,
+void wt_flushsoundbytes(int numbytes, unsigned int * count,
 			tnode * tptr, tnode * nsl)
 
 {
@@ -2452,14 +2452,14 @@ void wt_flushsoundbytes(int numbytes, unsigned long * count,
 }
 
 /*********************************************************/
-/*     converts byte stream to an unsigned long          */
+/*     converts byte stream to an unsigned int          */
 /*********************************************************/
 
-unsigned long wt_wavefileintval(int numbytes, unsigned long * count, 
+unsigned int wt_wavefileintval(int numbytes, unsigned int * count, 
 				tnode * tptr, tnode * nsl)
 
 {
-  unsigned long ret = 0;
+  unsigned int ret = 0;
   unsigned char c[4];
 
   if (numbytes > 4) 
@@ -2468,22 +2468,22 @@ unsigned long wt_wavefileintval(int numbytes, unsigned long * count,
   wt_getsoundbytes(&c[0],numbytes, count, tptr, nsl);
   switch (numbytes) {
   case 4:
-    ret  =  (unsigned long)c[0];
-    ret |=  (unsigned long)c[1] << 8;
-    ret |=  (unsigned long)c[2] << 16;
-    ret |=  (unsigned long)c[3] << 24;
+    ret  =  (unsigned int)c[0];
+    ret |=  (unsigned int)c[1] << 8;
+    ret |=  (unsigned int)c[2] << 16;
+    ret |=  (unsigned int)c[3] << 24;
     break;
   case 3:
-    ret  =  (unsigned long)c[0];
-    ret |=  (unsigned long)c[1] << 8;
-    ret |=  (unsigned long)c[2] << 16;
+    ret  =  (unsigned int)c[0];
+    ret |=  (unsigned int)c[1] << 8;
+    ret |=  (unsigned int)c[2] << 16;
     break;
   case 2:
-    ret  =  (unsigned long)c[0];
-    ret |=  (unsigned long)c[1] << 8;
+    ret  =  (unsigned int)c[0];
+    ret |=  (unsigned int)c[1] << 8;
     break;
   case 1:
-    ret = ((unsigned long)c[0]);
+    ret = ((unsigned int)c[0]);
     break;
   default:
     break;
@@ -2493,14 +2493,14 @@ unsigned long wt_wavefileintval(int numbytes, unsigned long * count,
 }
   
 /*********************************************************/
-/*     converts byte stream to an unsigned long          */
+/*     converts byte stream to an unsigned int          */
 /*********************************************************/
 
-unsigned long wt_aiffileintval(int numbytes, unsigned long * count, 
+unsigned int wt_aiffileintval(int numbytes, unsigned int * count, 
 			       tnode * tptr, tnode * nsl)
 
 {
-  unsigned long ret = 0;
+  unsigned int ret = 0;
   unsigned char c[4];
 
   if (numbytes > 4)
@@ -2509,22 +2509,22 @@ unsigned long wt_aiffileintval(int numbytes, unsigned long * count,
   wt_getsoundbytes(&c[0],numbytes, count, tptr, nsl);
   switch (numbytes) {
   case 4:
-    ret  =  (unsigned long)c[3];
-    ret |=  (unsigned long)c[2] << 8;
-    ret |=  (unsigned long)c[1] << 16;
-    ret |=  (unsigned long)c[0] << 24;
+    ret  =  (unsigned int)c[3];
+    ret |=  (unsigned int)c[2] << 8;
+    ret |=  (unsigned int)c[1] << 16;
+    ret |=  (unsigned int)c[0] << 24;
     break;
   case 3:
-    ret  =  (unsigned long)c[2];
-    ret |=  (unsigned long)c[1] << 8;
-    ret |=  (unsigned long)c[0] << 16;
+    ret  =  (unsigned int)c[2];
+    ret |=  (unsigned int)c[1] << 8;
+    ret |=  (unsigned int)c[0] << 16;
     break;
   case 2:
-    ret  =  (unsigned long)c[1];
-    ret |=  (unsigned long)c[0] << 8;
+    ret  =  (unsigned int)c[1];
+    ret |=  (unsigned int)c[0] << 8;
     break;
   case 1:
-    ret = ((unsigned long)c[0]);
+    ret = ((unsigned int)c[0]);
     break;
   default:
     break;
@@ -2539,7 +2539,7 @@ unsigned long wt_aiffileintval(int numbytes, unsigned long * count,
 /*    return 2 for EOF                                     */
 /***********************************************************/
 
-int wt_soundtypecheck(char * d, unsigned long * count) 
+int wt_soundtypecheck(char * d, unsigned int * count) 
 
 {
   int ret = 0;
